@@ -137,12 +137,6 @@ class TimeoutException : public Exception
     using Exception::Exception;
 };
 
-class BackendProfilingException : public Exception
-{
-public:
-    using Exception::Exception;
-};
-
 class PolymorphicDowncastException : public Exception
 {
 public:
@@ -155,6 +149,18 @@ public:
     using Exception::Exception;
 };
 
+class BackendCapabilityException : public Exception
+{
+public:
+    using Exception::Exception;
+};
+
+class MemoryValidationException : public Exception
+{
+public:
+    using Exception::Exception;
+};
+
 template <typename ExceptionType>
 void ConditionalThrow(bool condition, const std::string& message)
 {
