@@ -6,8 +6,10 @@
 
 namespace armnn
 {
+
 struct LstmInputParams;
 struct QuantizedLstmInputParams;
+
 class INetwork;
 class IOptimizedNetwork;
 class Graph;
@@ -15,4 +17,5 @@ class IInputSlot;
 class IOutputSlot;
 class IConnectableLayer;
 class IDataLayer;
-}
+
+} // end armnn namespace
