@@ -1,10 +1,10 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017,2022 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
 
-#include "armnn/TypesUtils.hpp"
+#include <string>
 
 namespace armnn
 {
@@ -35,4 +35,8 @@ void ConfigureLogging(bool printToStandardOutput, bool printToDebugOutput, LogSe
 #   define ARMNN_FALLTHROUGH ((void)0)
 #endif
 
+bool NeonDetected();
+
+const std::string GetVersion();
+
 } // namespace armnn
