@@ -4,6 +4,7 @@
 //
 #pragma once
 
+#include <armnn/BackendOptions.hpp>
 #include <armnn/IRuntime.hpp>
 #include <memory>
 
@@ -24,9 +25,18 @@ public:
     virtual bool BeforeUnloadNetwork(NetworkId networkId) = 0;
     virtual bool AfterUnloadNetwork(NetworkId networkId) = 0;
 
+    // After Enqueue workload events
+    virtual bool AfterEnqueueWorkload(NetworkId networkId) = 0;
+
     virtual ~IBackendContext() {}
 };
 
 using IBackendContextUniquePtr = std::unique_ptr<IBackendContext>;
 
+class IBackendModelContext
+{
+public:
+    virtual ~IBackendModelContext() {}
+};
+
 } // namespace armnn
\ No newline at end of file
