@@ -20,24 +20,42 @@ namespace pipe
 class SocketConnectionException : public std::exception
 {
 public:
-    explicit SocketConnectionException(const std::string &message, arm::pipe::Socket socket)
-        : m_Message(message), m_Socket(socket), m_ErrNo(-1) {};
+    explicit SocketConnectionException(const std::string& message
+#if !defined(ARMNN_DISABLE_SOCKETS)
+                                       , arm::pipe::Socket socket
+#endif
+        )
+        : m_Message(message),
+#if !defined(ARMNN_DISABLE_SOCKETS)
+          m_Socket(socket),
+#endif
+          m_ErrNo(-1) {};
 
-    explicit SocketConnectionException(const std::string &message, arm::pipe::Socket socket, int errNo)
-        : m_Message(message), m_Socket(socket), m_ErrNo(errNo) {};
+    explicit SocketConnectionException(const std::string& message,
+#if !defined(ARMNN_DISABLE_SOCKETS)
+                                       arm::pipe::Socket socket,
+#endif
+                                       int errNo)
+        : m_Message(message),
+#if !defined(ARMNN_DISABLE_SOCKETS)
+          m_Socket(socket),
+#endif
+          m_ErrNo(errNo) {};
 
     /// @return - Error message of  SocketProfilingConnection
-    virtual const char *what() const noexcept override
+    virtual const char* what() const noexcept override
     {
         return m_Message.c_str();
     }
 
     /// @return - Socket File Descriptor of SocketProfilingConnection
     ///           or '-1', an invalid file descriptor
+#if !defined(ARMNN_DISABLE_SOCKETS)
     arm::pipe::Socket GetSocketFd() const noexcept
     {
         return m_Socket;
     }
+#endif
 
     /// @return - errno of SocketProfilingConnection
     int GetErrorNo() const noexcept
@@ -47,7 +65,9 @@ public:
 
 private:
     std::string m_Message;
+#if !defined(ARMNN_DISABLE_SOCKETS)
     arm::pipe::Socket m_Socket;
+#endif
     int m_ErrNo;
 };
 } // namespace pipe
