@@ -1,18 +1,18 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "armnn/Descriptors.hpp"
 #include "armnn/Logging.hpp"
 
 #include <armnn/utility/Assert.hpp>
+#include <armnn/utility/NumericCast.hpp>
 
 #include <algorithm>
 #include <array>
 #include <vector>
 
-#include <boost/format.hpp>
-#include <boost/numeric/conversion/cast.hpp>
+#include <fmt/format.h>
 
 namespace armnn
 {
@@ -23,9 +23,11 @@ PermutationVector::PermutationVector(const ValueType *dimMappings, const SizeTyp
 
     if (numDimMappings > MaxNumOfTensorDimensions)
     {
-        boost::format fmt("The number of mappings (%1%) cannot be greater "
-                          "than the maximum number of dimensions supported (%2%)");
-        throw InvalidArgumentException(boost::str(fmt % numDimMappings % MaxNumOfTensorDimensions));
+        throw InvalidArgumentException(
+            fmt::format("The number of mappings ({0}) cannot be greater "
+                        "than the maximum number of dimensions supported ({1})",
+                        numDimMappings,
+                        MaxNumOfTensorDimensions));
     }
 
     if ((dimMappings == nullptr) && (numDimMappings != 0))
@@ -38,8 +40,12 @@ PermutationVector::PermutationVector(const ValueType *dimMappings, const SizeTyp
         const ValueType dstIndex = dimMappings[i];
         if (dstIndex >= numDimMappings)
         {
-            boost::format fmt("Dimension mapping at index %1% is invalid: %2% is outside of the valid range [0,%3%]");
-            throw InvalidArgumentException(boost::str(fmt % i % dstIndex % (numDimMappings - 1)));
+            throw InvalidArgumentException(
+                fmt::format("Dimension mapping at index {0} is invalid: "
+                            "{1} is outside of the valid range [0,{2}]",
+                            i,
+                            dstIndex,
+                            (numDimMappings - 1)));
         }
     }
 
@@ -69,7 +75,7 @@ PermutationVector::PermutationVector(const ValueType *dimMappings, const SizeTyp
 }
 
 PermutationVector::PermutationVector(std::initializer_list<ValueType> dimMappings)
-    : PermutationVector(dimMappings.begin(), boost::numeric_cast<SizeType>(dimMappings.size()))
+    : PermutationVector(dimMappings.begin(), armnn::numeric_cast<SizeType>(dimMappings.size()))
 {
 }
 
@@ -357,6 +363,24 @@ void swap(ViewsDescriptor& first, ViewsDescriptor& second)
     swap(first.m_ViewSizes, second.m_ViewSizes);
 }
 
+void ViewsDescriptor::SetAxis(int32_t axis)
+{
+    m_Axis = axis;
+    m_IsAxisSet = true;
+}
+
+/// Get the axis value.
+int32_t ViewsDescriptor::GetAxis() const
+{
+    return m_Axis;
+}
+
+/// Returns true if an axis has been set.
+bool ViewsDescriptor::HasAxis() const
+{
+    return m_IsAxisSet;
+}
+
 int StridedSliceDescriptor::GetStartForAxis(const TensorShape& inputShape,
                                             unsigned int axis) const
 {
@@ -374,7 +398,7 @@ int StridedSliceDescriptor::GetStartForAxis(const TensorShape& inputShape,
         }
     }
 
-    const int axisSize = boost::numeric_cast<int>(inputShape[axis]);
+    const int axisSize = armnn::numeric_cast<int>(inputShape[axis]);
     if (start < 0)
     {
         start += (axisSize);
@@ -408,7 +432,7 @@ int StridedSliceDescriptor::GetStopForAxis(const TensorShape& inputShape,
         }
     }
 
-    const int axisSize = boost::numeric_cast<int>(inputShape[axis]);
+    const int axisSize = armnn::numeric_cast<int>(inputShape[axis]);
     if (stop < 0)
     {
         stop += axisSize;
@@ -419,4 +443,97 @@ int StridedSliceDescriptor::GetStopForAxis(const TensorShape& inputShape,
 
 }
 
+uint32_t GetNumInputs(bool biasEnabled)
+{
+    unsigned int numInputs = 2;
+    if (biasEnabled)
+    {
+        numInputs = 3;
+    }
+    return numInputs;
+}
+
+uint32_t Convolution3dDescriptor::GetNumInputs() const
+{
+    return armnn::GetNumInputs(m_BiasEnabled);
+}
+
+uint32_t Convolution2dDescriptor::GetNumInputs() const
+{
+    return armnn::GetNumInputs(m_BiasEnabled);
+}
+
+uint32_t FullyConnectedDescriptor::GetNumInputs() const
+{
+    return armnn::GetNumInputs(m_BiasEnabled);
+}
+
+uint32_t DepthwiseConvolution2dDescriptor::GetNumInputs() const
+{
+    return armnn::GetNumInputs(m_BiasEnabled);
+}
+
+std::pair<unsigned int, unsigned int> BatchMatMulDescriptor::GetAxesToMul(
+    DataLayout dataLayout,
+    const TensorShape& tensorShape)
+{
+    auto numDims = tensorShape.GetNumDimensions();
+    std::pair<unsigned int, unsigned int> axes = { numDims-2, numDims-1 };
+    switch(dataLayout)
+    {
+        case DataLayout::NDHWC:
+        case DataLayout::NHWC:
+            axes.first -= 1;
+            axes.second -= 1;
+            break;
+        case DataLayout::NCDHW:
+        case DataLayout::NCHW:
+        default:
+            break;
+    }
+    return axes;
+}
+
+std::vector<unsigned int> BatchMatMulDescriptor::GetAxesNotMul(
+    DataLayout dataLayout,
+    const TensorShape& tensorShape)
+{
+    auto axesToMul = BatchMatMulDescriptor::GetAxesToMul(dataLayout, tensorShape);
+    std::vector<unsigned int> axesNotMul;
+    for(unsigned int i = 0; i < tensorShape.GetNumDimensions(); i++)
+    {
+        if(i == axesToMul.first || i == axesToMul.second)
+        {
+            continue;
+        }
+        axesNotMul.push_back(i);
+    }
+    return axesNotMul;
+}
+
+PermutationVector BatchMatMulDescriptor::GetPermuteVec(
+    DataLayout dataLayout,
+    const TensorShape& tensorShape)
+{
+    std::vector<unsigned int> vec;
+    auto axesToMul = BatchMatMulDescriptor::GetAxesToMul(dataLayout, tensorShape);
+    for(unsigned int i = 0; i < tensorShape.GetNumDimensions(); i++)
+    {
+        if(i == axesToMul.first)
+        {
+            vec.push_back(i+1);
+        }
+        else if(i == axesToMul.second)
+        {
+            vec.push_back(i-1);
+        }
+        else
+        {
+            vec.push_back(i);
+        }
+    }
+    return PermutationVector(vec.data(),
+                             static_cast<unsigned int>(vec.size()));
+}
+
 }
