@@ -1,22 +1,50 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "Layer.hpp"
 
 #include "Graph.hpp"
-#include <ProfilingService.hpp>
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
 
-#include <boost/cast.hpp>
-#include <boost/format.hpp>
+#include <armnn/backends/TensorHandle.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+
+#include <armnn/utility/NumericCast.hpp>
+
+#include <armnnUtils/TensorUtils.hpp>
+
+#include <client/include/IProfilingService.hpp>
+
+#include <fmt/format.h>
 
 #include <numeric>
 
 namespace armnn
 {
 
+// Instantiate the static member variable
+NullDescriptor Layer::m_NullDescriptor;
+
+void AssertNumberOfInputSlots(Layer& layer)
+{
+    switch (layer.GetType())
+    {
+        case LayerType::Convolution2d:
+        case LayerType::DepthwiseConvolution2d:
+        case LayerType::FullyConnected:
+        {
+            ARMNN_ASSERT(layer.GetNumInputSlots() == 2 ||
+                         layer.GetNumInputSlots() == 3);
+            break;
+        }
+        default:
+        {
+            ARMNN_ASSERT(layer.GetNumInputSlots() == 1);
+            break;
+        }
+    }
+}
+
 void InputSlot::Insert(Layer& layer)
 {
     ARMNN_ASSERT(layer.GetNumOutputSlots() == 1);
@@ -28,10 +56,11 @@ void InputSlot::Insert(Layer& layer)
         // Disconnects parent from this.
         prevSlot->Disconnect(*this);
 
+        AssertNumberOfInputSlots(layer);
+
         // Connects inserted layer to parent.
-        ARMNN_ASSERT(layer.GetNumInputSlots() == 1);
         int idx = prevSlot->Connect(layer.GetInputSlot(0));
-        prevSlot->SetEdgeStrategy(boost::numeric_cast<unsigned int>(idx), EdgeStrategy::Undefined);
+        prevSlot->SetEdgeStrategy(armnn::numeric_cast<unsigned int>(idx), EdgeStrategy::Undefined);
 
         // Sets tensor info for inserted layer.
         const TensorInfo& tensorInfo = prevSlot->GetTensorInfo();
@@ -85,7 +114,7 @@ int OutputSlot::Connect(InputSlot& destination)
     destination.SetConnection(this);
     m_Connections.push_back(&destination);
     m_EdgeStrategies.push_back(EdgeStrategy::Undefined);
-    return boost::numeric_cast<int>(m_Connections.size() - 1);
+    return armnn::numeric_cast<int>(m_Connections.size() - 1);
 }
 
 void OutputSlot::Disconnect(InputSlot& slot)
@@ -157,10 +186,9 @@ bool OutputSlot::operator==(const OutputSlot& other) const
 
 void OutputSlot::ValidateConnectionIndex(unsigned int index) const
 {
-    if (boost::numeric_cast<std::size_t>(index) >= m_Connections.size())
+    if (armnn::numeric_cast<std::size_t>(index) >= m_Connections.size())
     {
-        throw InvalidArgumentException(
-            boost::str(boost::format("GetConnection: Invalid index %1% provided") % index));
+        throw InvalidArgumentException((fmt::format("GetConnection: Invalid index {} provided", index)));
     }
 }
 
@@ -200,7 +228,7 @@ Layer::Layer(unsigned int numInputSlots,
 , m_Type(type)
 , m_BackendId()
 , m_BackendHint(EmptyOptional())
-, m_Guid(profiling::ProfilingService::GetNextGuid())
+, m_Guid(arm::pipe::IProfilingService::GetNextGuid())
 {
     IgnoreUnused(layout);
     m_InputSlots.reserve(numInputSlots);
@@ -231,7 +259,20 @@ void Layer::CollectWorkloadInputs(WorkloadDataCollector& dataCollector) const
         // The graph must be well-formed at this point.
         ARMNN_ASSERT(inputSlot.GetConnection());
         const OutputHandler& outputHandler = inputSlot.GetConnectedOutputSlot()->GetOutputHandler();
-        dataCollector.Push(outputHandler.GetData(), outputHandler.GetTensorInfo());
+
+        if (inputSlot.IsTensorInfoOverridden() && outputHandler.GetData())
+        {
+            auto handler = outputHandler.GetData()->DecorateTensorHandle(inputSlot.GetTensorInfo());
+
+            if (handler)
+            {
+                // Add overridden TensorHandle
+                dataCollector.Push(handler.get(), inputSlot.GetTensorInfo());
+                continue;
+            }
+        }
+        // Add default TensorHandle
+        dataCollector.Push(outputHandler.GetData(), inputSlot.GetTensorInfo());
     }
 }
 
@@ -243,6 +284,11 @@ void Layer::CollectWorkloadOutputs(WorkloadDataCollector& dataCollector) const
     }
 }
 
+void Layer::SetAdditionalInfo(QueueDescriptor& descriptor) const
+{
+    descriptor.m_AdditionalInfoObject = m_AdditionalInfoObject.get();
+}
+
 void Layer::CreateTensorHandles(const TensorHandleFactoryRegistry& registry,
                                 const IWorkloadFactory& workloadFactory,
                                 const bool IsMemoryManaged)
@@ -260,7 +306,8 @@ void Layer::CreateTensorHandles(const TensorHandleFactoryRegistry& registry,
         }
         else
         {
-            ITensorHandleFactory* handleFactory = registry.GetFactory(factoryId);
+            ITensorHandleFactory* handleFactory;
+            handleFactory = registry.GetFactory(factoryId);
             ARMNN_ASSERT(handleFactory);
             handler.CreateTensorHandles(*handleFactory, IsMemoryManaged);
         }
@@ -270,9 +317,9 @@ void Layer::CreateTensorHandles(const TensorHandleFactoryRegistry& registry,
 void Layer::ReleaseConstantData()
 {
     // Now free up the static data.
-    OperateOnConstantTensors([](std::unique_ptr<ScopedCpuTensorHandle>& handle)
+    OperateOnConstantTensors([](std::shared_ptr<ConstTensorHandle>& handle)
                                  {
-                                     handle.reset(nullptr);
+                                     handle.reset();
                                  });
 }
 
@@ -280,7 +327,7 @@ DataType Layer::GetDataType() const
 {
     if (GetNumInputSlots() > 0) // Ignore the input layer.
     {
-        return GetInputSlot(0).GetConnection()->GetTensorInfo().GetDataType();
+        return GetInputSlot(0).GetTensorInfo().GetDataType();
     }
     return GetOutputSlot(0).GetTensorInfo().GetDataType();
 }
@@ -350,14 +397,12 @@ void Layer::VerifyLayerConnections(unsigned int expectedConnections, const Check
         if (GetInputSlot(i).GetConnection() == nullptr)
         {
             throw LayerValidationException(
-                boost::str(
-                    boost::format(
-                        "Input connection #%1% must be connected "
-                        "for %2% layer %3% %4%")
-                        % i
-                        % GetLayerTypeAsCString(this->GetType())
-                        % GetNameStr()
-                        % location.AsString()));
+                    fmt::format("Input connection #{0} must be connected "
+                                "for {1} layer {2} {3}",
+                                i,
+                                GetLayerTypeAsCString(this->GetType()),
+                                GetNameStr(),
+                                location.AsString()));
         }
     }
 }
@@ -375,16 +420,14 @@ std::vector<TensorShape> Layer::InferOutputShapes(const std::vector<TensorShape>
     if (GetNumInputSlots() != GetNumOutputSlots())
     {
         throw UnimplementedException(
-            boost::str(
-                boost::format(
-                    "Default implementation for InferOutputShapes can only be used for "
-                    "layers with the same number of input and output slots. This doesn't "
-                    "hold for %1% layer %2% (#inputs=%3% #outputs=%4%) %5%")
-                    % GetLayerTypeAsCString(this->GetType())
-                    % GetNameStr()
-                    % GetNumInputSlots()
-                    % GetNumOutputSlots()
-                    % CHECK_LOCATION().AsString()));
+                fmt::format("Default implementation for InferOutputShapes can only be used for "
+                            "layers with the same number of input and output slots. This doesn't "
+                            "hold for {0} layer {1} (#inputs={2} #outputs={3}) {4}",
+                            GetLayerTypeAsCString(this->GetType()),
+                            GetNameStr(),
+                            GetNumInputSlots(),
+                            GetNumOutputSlots(),
+                            CHECK_LOCATION().AsString()));
     }
     return inputShapes;
 }
@@ -397,11 +440,40 @@ void Layer::ValidateAndCopyShape(const TensorShape& outputShape,
 {
     if (shapeInferenceMethod == ShapeInferenceMethod::ValidateOnly)
     {
-        ConditionalThrowIfNotEqual<LayerValidationException>(
-                layerName + ": TensorShape set on OutputSlot[0] does not match the inferred shape.",
-                outputShape,
-                inferredShape);
-        return;
+        if (m_AllowExpandedDims)
+        {
+            std::vector<unsigned int> outputDims = armnnUtils::SqueezeDims(outputShape);
+            std::vector<unsigned int> inferredDims = armnnUtils::SqueezeDims(inferredShape);
+
+            if (outputDims.size() != inferredDims.size())
+            {
+                std::stringstream ss;
+                ss << layerName << ": TensorShape set on OutputSlot[" << outputSlotIndex <<
+                   "] does not match the inferred shape. ";
+                ss << outputShape << " != " << inferredShape;
+                throw LayerValidationException(ss.str());
+            }
+            for (unsigned int i = 0; i < outputDims.size(); ++i)
+            {
+                if (outputDims[i] != inferredDims[i])
+                {
+                    std::stringstream ss;
+                    ss << layerName << ": TensorShape set on OutputSlot[" << outputSlotIndex <<
+                       "] does not match the inferred shape at dimension index [";
+                    ss << i << "] " << outputShape << " != " << inferredShape;
+                    throw LayerValidationException(ss.str());
+                }
+            }
+            return;
+        }
+        else
+        {
+            ConditionalThrowIfNotEqual<LayerValidationException>(
+                    layerName + ": TensorShape set on OutputSlot[0] does not match the inferred shape.",
+                    outputShape,
+                    inferredShape);
+            return;
+        }
     }
 
     if (outputShape.GetDimensionality() == Dimensionality::Specified)
@@ -445,8 +517,13 @@ void Layer::VerifyShapeInferenceType(const TensorShape& outputShape, ShapeInfere
 
 void Layer::SerializeLayerParameters(ParameterStringifyFunction& fn) const
 {
+    std::string guid = std::to_string(m_Guid);
     std::string layerType = GetLayerTypeAsCString(m_Type);
     std::string backendId = std::string(m_BackendId);
+    if (!(guid.compare("") == 0) && !guid.empty())
+    {
+        fn("Guid", guid);
+    }
     if(!(m_LayerName.compare("") == 0) && !m_LayerName.empty())
     {
         fn("LayerName",m_LayerName);
@@ -459,6 +536,79 @@ void Layer::SerializeLayerParameters(ParameterStringifyFunction& fn) const
     {
         fn("BackendID",backendId);
     }
+    std::shared_ptr<ActivationDescriptor>
+            activationDescPtr = GetAdditionalInformation<ActivationDescriptor>();
+
+    if (activationDescPtr)
+    {
+        StringifyLayerParameters<ActivationDescriptor>::Serialize(fn, *activationDescPtr.get());
+    }
+}
+
+// default implementation of ExecuteStrategy
+void Layer::ExecuteStrategy(IStrategy& strategy) const
+{
+    strategy.ExecuteStrategy(this, BaseDescriptor(), {}, GetName());
+}
+
+Layer::ConstantTensors Layer::GetConstantTensorsByRef()
+{
+    const Layer *constThis = const_cast<const Layer*>(this);
+    ConstantTensors res;
+
+    ImmutableConstantTensors immutableData = constThis->GetConstantTensorsByRef();
+    for (auto i : immutableData)
+    {
+        res.push_back(const_cast<std::shared_ptr<ConstTensorHandle>&>(i.get()));
+    }
+    return res;
+}
+
+const IConnectableLayer& OutputSlot::GetOwningIConnectableLayer() const
+{
+    return m_OwningLayer;
+}
+
+IConnectableLayer& OutputSlot::GetOwningIConnectableLayer()
+{
+    return m_OwningLayer;
+}
+
+const IConnectableLayer& InputSlot::GetOwningIConnectableLayer() const
+{
+    return m_OwningLayer;
+}
+
+IConnectableLayer& InputSlot::GetOwningIConnectableLayer()
+{
+    return m_OwningLayer;
+}
+
+void InputSlot::SetTensorInfo(const TensorInfo tensorInfo)
+{
+    m_OverriddenTensorInfo = Optional<TensorInfo>(tensorInfo);
+}
+
+const TensorInfo& InputSlot::GetTensorInfo() const
+{
+    if (m_OverriddenTensorInfo.has_value())
+    {
+        return m_OverriddenTensorInfo.value();
+    }
+    else
+    {
+        return GetConnection()->GetTensorInfo();
+    }
+}
+
+bool InputSlot::IsTensorInfoSet() const
+{
+    return m_OverriddenTensorInfo.has_value() || (GetConnection() && GetConnection()->IsTensorInfoSet());
+}
+
+bool InputSlot::IsTensorInfoOverridden() const
+{
+    return m_OverriddenTensorInfo.has_value();
 }
 
 } // namespace armnn
