@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
@@ -10,14 +10,16 @@
 #include <OutputHandler.hpp>
 #include <backendsCommon/TensorHandleFactoryRegistry.hpp>
 #include <backendsCommon/WorkloadDataCollector.hpp>
-#include <backendsCommon/WorkloadInfo.hpp>
+#include <armnn/backends/WorkloadInfo.hpp>
 #include "InternalTypes.hpp"
 #include "SerializeLayerParameters.hpp"
+#include "DllExport.hpp"
 
 #include <armnn/Types.hpp>
 #include <armnn/Tensor.hpp>
 #include <armnn/INetwork.hpp>
 #include <armnn/utility/IgnoreUnused.hpp>
+#include <armnn/utility/NumericCast.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
 
 #include <algorithm>
@@ -27,8 +29,7 @@
 #include <memory>
 #include <string>
 #include <vector>
-
-#include <boost/cast.hpp>
+#include <armnn/backends/WorkloadData.hpp>
 
 namespace armnn
 {
@@ -50,11 +51,14 @@ public:
     ~InputSlot();
 
     Layer& GetOwningLayer() const { return m_OwningLayer; }
-    unsigned int GetSlotIndex() const { return m_SlotIndex; }
+    unsigned int GetSlotIndex() const override { return m_SlotIndex; }
 
     const OutputSlot* GetConnectedOutputSlot() const { return m_Connection; }
     OutputSlot* GetConnectedOutputSlot() { return m_Connection; }
 
+    const IConnectableLayer& GetOwningIConnectableLayer() const override;
+    IConnectableLayer& GetOwningIConnectableLayer() override;
+
     /// Links the slot to an output slot or breaks an existing link if passing nullptr.
     void SetConnection(OutputSlot* source)
     {
@@ -69,14 +73,27 @@ public:
     // Inserts single-output existing layer at this point in the graph.
     void Insert(Layer& layer);
 
-    // IInputSlot
+    // InputSlot
 
     const IOutputSlot* GetConnection() const override;
     IOutputSlot* GetConnection() override;
 
+    /// Sets the TensorInfo for this InputSlot. This can be used to override the TensorInfo and if set will be returned
+    /// instead of the TensorInfo for the Connected OutputSlot.
+    void SetTensorInfo(const TensorInfo tensorInfo) override;
+    /// Gets the TensorInfo for this InputSlot. If the InputSlot's TensorInfo has not been set then this will get the
+    /// TensorInfo from the Connected TensorInfo.
+    const TensorInfo& GetTensorInfo() const override;
+    /// Returns true if this InputSlot either has an overridden TensorInfo for this InputSlot that was set through a
+    /// call to SetTensorInfo() or is Connected to an OutputSlot that has its TensorInfo set.
+    bool IsTensorInfoSet() const override;
+    /// Returns true if this InputSlot has an overridden TensorInfo that was set through a call to SetTensorInfo().
+    bool IsTensorInfoOverridden() const override;
+
 private:
     Layer& m_OwningLayer;
     OutputSlot* m_Connection;
+    Optional<TensorInfo> m_OverriddenTensorInfo;
     const unsigned int m_SlotIndex;
 };
 
@@ -114,6 +131,9 @@ public:
 
     Layer& GetOwningLayer() const { return m_OwningLayer; }
 
+    const IConnectableLayer& GetOwningIConnectableLayer() const override;
+    IConnectableLayer& GetOwningIConnectableLayer() override;
+
     LayerGuid GetOwningLayerGuid() const override;
 
     const OutputHandler& GetOutputHandler() const { return m_OutputHandler; }
@@ -135,7 +155,7 @@ public:
 
     // IOutputSlot
 
-    unsigned int GetNumConnections() const override { return boost::numeric_cast<unsigned int>(m_Connections.size()); }
+    unsigned int GetNumConnections() const override { return armnn::numeric_cast<unsigned int>(m_Connections.size()); }
     const InputSlot* GetConnection(unsigned int index) const override;
     InputSlot* GetConnection(unsigned int index) override;
 
@@ -200,11 +220,12 @@ inline const IOutputSlot* InputSlot::GetConnection() const { return GetConnected
 inline IOutputSlot* InputSlot::GetConnection() { return GetConnectedOutputSlot(); }
 
 
-class ScopedCpuTensorHandle;
+class ScopedTensorHandle;
 
 // Base layer class
 
 using LayerPriority = unsigned int;
+using AdditionalInfoObjectPtr = std::shared_ptr<void>;
 
 class Layer : public IConnectableLayer
 {
@@ -213,6 +234,9 @@ public:
     Layer(unsigned int numInputSlots, unsigned int numOutputSlots, LayerType type, const char* name);
     Layer(unsigned int numInputSlots, unsigned int numOutputSlots, LayerType type, DataLayout layout, const char* name);
 
+    void ExecuteStrategy(IStrategy& strategy) const override;
+
+
     const std::string& GetNameStr() const
     {
         return m_LayerName;
@@ -229,6 +253,7 @@ public:
     }
 
     ShapeInferenceMethod GetShapeInferenceMethod() const { return m_ShapeInferenceMethod; };
+    bool GetAllowExpandedDims() const { return m_AllowExpandedDims; };
 
     const std::vector<InputSlot>& GetInputSlots() const { return m_InputSlots; }
     const std::vector<OutputSlot>& GetOutputSlots() const { return m_OutputSlots; }
@@ -258,12 +283,12 @@ public:
     void ResetPriority() const;
     LayerPriority GetPriority() const;
 
-    LayerType GetType() const { return m_Type; }
+    LayerType GetType() const override { return m_Type; }
 
     DataType GetDataType() const;
 
     const BackendId& GetBackendId() const { return m_BackendId; }
-    void SetBackendId(const BackendId& id) { m_BackendId = id; }
+    void SetBackendId(const BackendId& id) override { m_BackendId = id; }
 
     // Virtuals
 
@@ -334,6 +359,24 @@ public:
         m_ShapeInferenceMethod = shapeInferenceMethod;
     }
 
+    void SetAllowExpandedDims(bool allowExpandedDims)
+    {
+        m_AllowExpandedDims = allowExpandedDims;
+    }
+
+    template<typename T>
+    std::shared_ptr<T> GetAdditionalInformation() const
+    {
+        return std::static_pointer_cast<T>(m_AdditionalInfoObject);
+    }
+
+    void SetAdditionalInfoForObject(const AdditionalInfoObjectPtr& additionalInfo)
+    {
+        m_AdditionalInfoObject = additionalInfo;
+    }
+
+    virtual const BaseDescriptor& GetParameters() const override { return m_NullDescriptor; }
+
 protected:
     // Graph needs access to the virtual destructor.
     friend class Graph;
@@ -368,6 +411,7 @@ protected:
         WorkloadInfo info;
         CollectQueueDescriptorInputs(descriptor, info);
         CollectQueueDescriptorOutputs(descriptor, info);
+        info.m_Name = GetName();
         return info;
     }
 
@@ -375,8 +419,18 @@ protected:
     LayerType* CloneBase(Graph& graph, Params&& ... params) const;
 
     // Retrieve the Handles to the constants
-    using ConstantTensors = std::vector<std::reference_wrapper<std::unique_ptr<ScopedCpuTensorHandle>>>;
-    virtual ConstantTensors GetConstantTensorsByRef() {return ConstantTensors(); };
+    // Marking this as override and having this here keeps IConnectable abstract with only pure virtual function
+    virtual ConstantTensors GetConstantTensorsByRef() override final;
+
+    // Retrieve the Handles to the constants
+    // Marking this as override and having this here keeps IConnectable abstract with only pure virtual function
+    virtual ImmutableConstantTensors GetConstantTensorsByRef() const override { return ImmutableConstantTensors(); };
+
+    // "Blob"
+    AdditionalInfoObjectPtr m_AdditionalInfoObject;
+
+    // Utility method to set a pointer in the queueDescriptor to the "blob" location in the layer
+    void SetAdditionalInfo(QueueDescriptor& descriptor) const;
 
 private:
     void CollectWorkloadInputs(WorkloadDataCollector& dataCollector) const;
@@ -400,10 +454,16 @@ private:
     mutable LayerPriority m_Priority = 0;
     mutable bool m_Visiting = false;
 
+    bool m_AllowExpandedDims = false;
+
     LayerGuid m_Guid;
 
     std::list<std::string> m_RelatedLayerNames;
 
+    /// returned by layers which have no parameters associated with them.
+    /// has to be a member as it is returned as a const reference
+    /// declared static so that there is only ever one of them in memory
+    ARMNN_DLLEXPORT static NullDescriptor m_NullDescriptor;
 };
 
 // A layer user-provided data can be bound to (e.g. inputs, outputs).
@@ -422,6 +482,11 @@ public:
 
     LayerBindingId GetBindingId() const { return m_Id; };
 
+    void ExecuteStrategy(IStrategy& strategy) const override
+    {
+        strategy.ExecuteStrategy(this, BaseDescriptor(), {}, GetName(), GetBindingId());
+    }
+
 protected:
     ~BindableLayer() = default;
 
@@ -429,4 +494,4 @@ private:
     LayerBindingId m_Id;
 };
 
-}
+} //namespace armnn
