@@ -7,7 +7,7 @@
 
 #include <armnn/backends/ITensorHandle.hpp>
 #include <backendsCommon/WorkloadDataCollector.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 namespace armnn
 {
@@ -35,4 +35,13 @@ void OutputHandler::CollectWorkloadOutputs(WorkloadDataCollector& dataCollector)
     dataCollector.Push(m_TensorHandle.get(), m_TensorInfo);
 }
 
+void OutputHandler::SetAllocatedData()
+{
+    // Set allocated data only once
+    if (!m_AllocatedTensorHandle)
+    {
+       m_AllocatedTensorHandle = std::move(m_TensorHandle);
+    }
+}
+
 } // namespace armnn
