@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017,2022-2023 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
@@ -25,74 +25,19 @@ struct StringifyLayerParameters
     static void Serialize(ParameterStringifyFunction&, const LayerParameter&) {}
 };
 
-template <> struct StringifyLayerParameters<PermuteDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const PermuteDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<ReshapeDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const ReshapeDescriptor& desc);
-};
-
 template <> struct StringifyLayerParameters<ActivationDescriptor>
 {
     static void Serialize(ParameterStringifyFunction& fn, const ActivationDescriptor& desc);
 };
 
-template <> struct StringifyLayerParameters<Convolution2dDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const Convolution2dDescriptor& desc);
-};
-
 template <> struct StringifyLayerParameters<BatchNormalizationDescriptor>
 {
     static void Serialize(ParameterStringifyFunction& fn, const BatchNormalizationDescriptor& desc);
 };
 
-template <> struct StringifyLayerParameters<DepthwiseConvolution2dDescriptor>
+template <> struct StringifyLayerParameters<BatchMatMulDescriptor>
 {
-    static void Serialize(ParameterStringifyFunction& fn, const DepthwiseConvolution2dDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<Pooling2dDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const Pooling2dDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<SoftmaxDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const SoftmaxDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<FullyConnectedDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const FullyConnectedDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<OriginsDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const OriginsDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<ViewsDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const ViewsDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<DetectionPostProcessDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const DetectionPostProcessDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<NormalizationDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const NormalizationDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<L2NormalizationDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const L2NormalizationDescriptor& desc);
+    static void Serialize(ParameterStringifyFunction& fn, const BatchMatMulDescriptor& desc);
 };
 
 template <> struct StringifyLayerParameters<BatchToSpaceNdDescriptor>
@@ -100,14 +45,118 @@ template <> struct StringifyLayerParameters<BatchToSpaceNdDescriptor>
     static void Serialize(ParameterStringifyFunction& fn, const BatchToSpaceNdDescriptor& desc);
 };
 
+template <> struct StringifyLayerParameters<ChannelShuffleDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ChannelShuffleDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<ComparisonDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ComparisonDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<Convolution2dDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const Convolution2dDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<Convolution3dDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const Convolution3dDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<DetectionPostProcessDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const DetectionPostProcessDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<DepthwiseConvolution2dDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const DepthwiseConvolution2dDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<ElementwiseBinaryDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ElementwiseBinaryDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<ElementwiseUnaryDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ElementwiseUnaryDescriptor& desc);
+};
+
 template <> struct StringifyLayerParameters<FakeQuantizationDescriptor>
 {
     static void Serialize(ParameterStringifyFunction& fn, const FakeQuantizationDescriptor& desc);
 };
 
-template <> struct StringifyLayerParameters<ResizeBilinearDescriptor>
+template <> struct StringifyLayerParameters<FullyConnectedDescriptor>
 {
-    static void Serialize(ParameterStringifyFunction& fn, const ResizeBilinearDescriptor& desc);
+    static void Serialize(ParameterStringifyFunction& fn, const FullyConnectedDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<GatherDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const GatherDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<L2NormalizationDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const L2NormalizationDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<LstmDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const LstmDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<MeanDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const MeanDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<NormalizationDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const NormalizationDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<OriginsDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const OriginsDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<PadDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const PadDescriptor& desc);
+};
+template <> struct StringifyLayerParameters<PermuteDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const PermuteDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<Pooling2dDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const Pooling2dDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<Pooling3dDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const Pooling3dDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<PreCompiledDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const PreCompiledDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<ReduceDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ReduceDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<ReshapeDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ReshapeDescriptor& desc);
 };
 
 template <> struct StringifyLayerParameters<ResizeDescriptor>
@@ -125,21 +174,6 @@ template <> struct StringifyLayerParameters<SpaceToDepthDescriptor>
     static void Serialize(ParameterStringifyFunction& fn, const SpaceToDepthDescriptor& desc);
 };
 
-template <> struct StringifyLayerParameters<LstmDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const LstmDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<MeanDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const MeanDescriptor& desc);
-};
-
-template <> struct StringifyLayerParameters<PadDescriptor>
-{
-    static void Serialize(ParameterStringifyFunction& fn, const PadDescriptor& desc);
-};
-
 template <> struct StringifyLayerParameters<StackDescriptor>
 {
     static void Serialize(ParameterStringifyFunction& fn, const StackDescriptor& desc);
@@ -150,9 +184,14 @@ template <> struct StringifyLayerParameters<StridedSliceDescriptor>
     static void Serialize(ParameterStringifyFunction& fn, const StridedSliceDescriptor& desc);
 };
 
-template <> struct StringifyLayerParameters<PreCompiledDescriptor>
+template <> struct StringifyLayerParameters<SoftmaxDescriptor>
 {
-    static void Serialize(ParameterStringifyFunction& fn, const PreCompiledDescriptor& desc);
+    static void Serialize(ParameterStringifyFunction& fn, const SoftmaxDescriptor& desc);
+};
+
+template <> struct StringifyLayerParameters<TileDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const TileDescriptor& desc);
 };
 
 template <> struct StringifyLayerParameters<TransposeConvolution2dDescriptor>
@@ -165,4 +204,9 @@ template <> struct StringifyLayerParameters<TransposeDescriptor>
     static void Serialize(ParameterStringifyFunction& fn, const TransposeDescriptor& desc);
 };
 
+template <> struct StringifyLayerParameters<ViewsDescriptor>
+{
+    static void Serialize(ParameterStringifyFunction& fn, const ViewsDescriptor& desc);
+};
+
 } // namespace armnn
\ No newline at end of file
