@@ -26,8 +26,7 @@ public:
     /// @param [in] shapeInferenceMethod Indicates if output shape shall be overwritten or just validated.
     void ValidateTensorShapesFromInputs() override;
 
-    void Accept(ILayerVisitor& visitor) const override;
-
+    void ExecuteStrategy(IStrategy& strategy) const override;
 
 protected:
     /// Constructor to create an ActivationLayer.
