@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "ConcatLayer.hpp"
@@ -7,8 +7,8 @@
 
 #include <armnn/TypesUtils.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 #include <queue>
 
@@ -31,8 +31,9 @@ std::unique_ptr<IWorkload> ConcatLayer::CreateWorkload(const IWorkloadFactory& f
         descriptor.m_ViewOrigins.emplace_back(
             std::vector<unsigned int>(m_Param.GetViewOrigin(i), m_Param.GetViewOrigin(i) + m_Param.GetNumDimensions()));
     }
+    SetAdditionalInfo(descriptor);
 
-    return factory.CreateConcat(descriptor, PrepInfoAndDesc(descriptor));
+    return factory.CreateWorkload(LayerType::Concat, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 template<typename FactoryType>
@@ -89,20 +90,27 @@ void ConcatLayer::CreateTensors(const TensorHandleFactoryRegistry& registry,
                         }
                     }
 
+                    // Splitter layer outputs are subtensors on the inputs whereas concat inputs are subtensors on
+                    // the output. If the parent is a Splitter layer we cannot use subtensors.
+                    if ((PolymorphicDowncast<const Layer*>(&(slot->GetOwningLayer())))->GetType() == LayerType::Splitter
+                        && (PolymorphicDowncast<const Layer*>(currentLayer))->GetType() == LayerType::Concat)
+                    {
+                        canUseSubTensorOnXorY = false;
+                    }
+
                     if (!canUseSubTensorOnXorY)
                     {
                         break;
                     }
                 }
             }
-
             // First go through all the input slots and verify that we can sub-tensor all the inputs.
             std::vector<std::unique_ptr<ITensorHandle>> subTensors(0);
             subTensors.reserve(numInputSlots);
             for (unsigned int i = 0; i < numInputSlots; ++i)
             {
                 OutputSlot* slot = currentLayer->GetInputSlot(i).GetConnectedOutputSlot();
-                const TensorInfo& info = slot->GetTensorInfo();
+                const TensorInfo& info = currentLayer->GetInputSlot(i).GetTensorInfo();
 
                 auto CreateSubTensor = [&]()
                 {
@@ -112,13 +120,16 @@ void ConcatLayer::CreateTensors(const TensorHandleFactoryRegistry& registry,
                     // 3) the input does not come from a Constant layer or input layer
                     // 4) the input is only read by this concat layer
                     // 5) if concat along x or y (2 innermost dimensions) and the previous layers do not require padding
+                    // 6) neither the inputs nor the output have an Overridden TensorInfo
                     if (slot &&
                         parentInfo.IsTypeSpaceMatch(info) && //(1)
                         factoryId == slot->GetTensorHandleFactoryId() && //(2)
                         slot->GetOwningLayer().GetType() != LayerType::Constant && //(3)
                         slot->GetOwningLayer().GetType() != LayerType::Input && //(3)
                         slot->GetNumConnections() == 1 &&
-                        canUseSubTensorOnXorY) //(5)
+                        canUseSubTensorOnXorY && //(5)
+                        !GetOutputSlot(0).GetConnection(0)->IsTensorInfoOverridden() && //(6)
+                        !currentLayer->GetInputSlot(i).IsTensorInfoOverridden()) //(6)
                     {
                         ARMNN_NO_DEPRECATE_WARN_BEGIN
                         return factory.CreateSubTensorHandle(*parentTensor,
@@ -299,7 +310,7 @@ void ConcatLayer::ValidateTensorShapesFromInputs()
     std::vector<TensorShape> inputShapes;
     for (unsigned int i = 0; i < GetNumInputSlots(); ++i)
     {
-        inputShapes.push_back(GetInputSlot(i).GetConnection()->GetTensorInfo().GetShape());
+        inputShapes.push_back(GetInputSlot(i).GetTensorInfo().GetShape());
     }
 
     auto inferredShapes = InferOutputShapes(inputShapes);
@@ -309,9 +320,9 @@ void ConcatLayer::ValidateTensorShapesFromInputs()
     ValidateAndCopyShape(outputShape, inferredShapes[0], m_ShapeInferenceMethod, "ConcatLayer");
 }
 
-void ConcatLayer::Accept(ILayerVisitor& visitor) const
+void ConcatLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    visitor.VisitConcatLayer(this, GetParameters(), GetName());
+    strategy.ExecuteStrategy(this, GetParameters(), {}, GetName());
 }
 
 } // namespace armnn armnn
