@@ -1,14 +1,14 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "ConstantLayer.hpp"
 #include "LayerCloneBase.hpp"
 
 #include <armnn/TypesUtils.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/TensorHandle.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 namespace armnn
 {
@@ -22,7 +22,9 @@ std::unique_ptr<IWorkload> ConstantLayer::CreateWorkload(const IWorkloadFactory&
 {
     ConstantQueueDescriptor descriptor;
     descriptor.m_LayerOutput = m_LayerOutput.get();
-    return factory.CreateConstant(descriptor, PrepInfoAndDesc(descriptor));
+    SetAdditionalInfo(descriptor);
+
+    return factory.CreateWorkload(LayerType::Constant, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 ConstantLayer* ConstantLayer::Clone(Graph& graph) const
@@ -30,7 +32,7 @@ ConstantLayer* ConstantLayer::Clone(Graph& graph) const
     // Cloned layers share the same layer output object.
     auto layer = CloneBase<ConstantLayer>(graph, GetName());
 
-    layer->m_LayerOutput = m_LayerOutput ? std::make_unique<ScopedCpuTensorHandle>(*m_LayerOutput) : nullptr;
+    layer->m_LayerOutput = m_LayerOutput ? m_LayerOutput : nullptr;
 
     return std::move(layer);
 }
@@ -60,10 +62,17 @@ void ConstantLayer::ValidateTensorShapesFromInputs()
                outShape);
 }
 
-void ConstantLayer::Accept(ILayerVisitor& visitor) const
+void ConstantLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    ConstTensor layerOutputTensor(m_LayerOutput->GetTensorInfo(), m_LayerOutput->Map(true)) ;
-    visitor.VisitConstantLayer(this, layerOutputTensor, GetName());
+    ManagedConstTensorHandle managedLayerOutput(m_LayerOutput);
+    ConstTensor layerOutputTensor(managedLayerOutput.GetTensorInfo(), managedLayerOutput.Map());
+    strategy.ExecuteStrategy(this, BaseDescriptor(), { layerOutputTensor }, GetName());
+}
+
+void ConstantLayer::SerializeLayerParameters(ParameterStringifyFunction& fn) const
+{
+    fn("DataType",GetDataTypeName(m_LayerOutput->GetTensorInfo().GetDataType()));
+    Layer::SerializeLayerParameters(fn);
 }
 
 } // namespace armnn
