@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017, 2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
@@ -9,7 +9,7 @@
 namespace armnn
 {
 
-class ScopedCpuTensorHandle;
+class ScopedTensorHandle;
 
 /// A layer that the constant data can be bound to.
 class ConstantLayer : public Layer
@@ -39,9 +39,11 @@ public:
     /// Free up the constant source data stored by the layer.
     void ReleaseConstantData() override {}
 
-    void Accept(ILayerVisitor& visitor) const override;
+    void ExecuteStrategy(IStrategy& strategy) const override;
 
-    std::unique_ptr<ScopedCpuTensorHandle> m_LayerOutput;
+    void SerializeLayerParameters(ParameterStringifyFunction &fn) const override;
+
+    std::shared_ptr<ConstTensorHandle> m_LayerOutput;
 
 protected:
     /// Constructor to create a ConstantLayer.
@@ -52,7 +54,8 @@ protected:
     ~ConstantLayer() = default;
 
     /// Retrieve the handles to the constant values stored by the layer.
-    ConstantTensors GetConstantTensorsByRef() override { return {m_LayerOutput}; }
+    // For API stability DO NOT ALTER order and add new members to the end of vector
+    ImmutableConstantTensors GetConstantTensorsByRef() const override { return {m_LayerOutput}; }
 };
 
 } // namespace
