@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017-2018,2020-2021,2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -13,37 +13,48 @@
 namespace armnn
 {
 
-ElementwiseBaseLayer::ElementwiseBaseLayer(unsigned int numInputSlots, unsigned int numOutputSlots,
-                                           LayerType type, const char* name)
+ElementwiseBaseLayer::ElementwiseBaseLayer(unsigned int numInputSlots,
+                                           unsigned int numOutputSlots,
+                                           LayerType type,
+                                           const char* name)
     : Layer(numInputSlots, numOutputSlots, type, name)
-{
-}
+{}
 
 std::vector<TensorShape> ElementwiseBaseLayer::InferOutputShapes(const std::vector<TensorShape>& inputShapes) const
 {
     ARMNN_ASSERT(inputShapes.size() == 2);
-    auto& input0 = inputShapes[0];
-    auto& input1 = inputShapes[1];
+    TensorShape input0 = inputShapes[0];
+    TensorShape input1 = inputShapes[1];
+
+    if (inputShapes[0].GetNumDimensions() < inputShapes[1].GetNumDimensions())
+    {
+        input1 = inputShapes[0];
+        input0 = inputShapes[1];
+    }
+
+    unsigned int numDims     = input0.GetNumDimensions();
+    unsigned int shiftedDims = input0.GetNumDimensions() - input1.GetNumDimensions();
 
     // Get the max of the inputs.
-    ARMNN_ASSERT(input0.GetNumDimensions() == input1.GetNumDimensions());
-    unsigned int numDims = input0.GetNumDimensions();
     std::vector<unsigned int> dims(numDims);
-
-    for (unsigned int i = 0; i < numDims; i++)
+    for (unsigned int i = shiftedDims; i < numDims; i++)
     {
         unsigned int dim0 = input0[i];
-        unsigned int dim1 = input1[i];
+        unsigned int dim1 = input1[i - shiftedDims];
 
-#if !NDEBUG
         // Validate inputs are broadcast compatible.
         ARMNN_ASSERT_MSG(dim0 == dim1 || dim0 == 1 || dim1 == 1,
                          "Dimensions should either match or one should be of size 1.");
-#endif
 
         dims[i] = std::max(dim0, dim1);
     }
 
+    // Fill in the rest of the shifted dimensions.
+    for (unsigned int i = 0; i < shiftedDims; i++)
+    {
+        dims[i] = input0[i];
+    }
+
     return std::vector<TensorShape>({ TensorShape(numDims, dims.data()) });
 }
 
@@ -55,14 +66,17 @@ void ElementwiseBaseLayer::ValidateTensorShapesFromInputs()
 
     VerifyShapeInferenceType(outputShape, m_ShapeInferenceMethod);
 
-    auto inferredShapes = InferOutputShapes({
-        GetInputSlot(0).GetConnection()->GetTensorInfo().GetShape(),
-        GetInputSlot(1).GetConnection()->GetTensorInfo().GetShape()
-    });
+    auto inferredShapes = InferOutputShapes({ GetInputSlot(0).GetTensorInfo().GetShape(),
+                                              GetInputSlot(1).GetTensorInfo().GetShape() });
 
     ARMNN_ASSERT(inferredShapes.size() == 1);
 
     ValidateAndCopyShape(outputShape, inferredShapes[0], m_ShapeInferenceMethod, GetLayerTypeAsCString(GetType()));
 }
 
-} // namespace armnn
+void ElementwiseBaseLayer::ExecuteStrategy(IStrategy& strategy) const
+{
+    strategy.ExecuteStrategy(this, BaseDescriptor(), {}, GetName());
+}
+
+}    // namespace armnn
