@@ -15,9 +15,11 @@ LayerType* Layer::CloneBase(Graph& graph, Params&& ... params) const
 {
     LayerType* const layer = graph.AddLayer<LayerType>(std::forward<Params>(params)...);
 
+    layer->BackendSelectionHint(GetBackendHint());
     layer->SetBackendId(GetBackendId());
     layer->SetGuid(GetGuid());
     layer->SetShapeInferenceMethod(m_ShapeInferenceMethod);
+    layer->SetAllowExpandedDims(m_AllowExpandedDims);
 
     return layer;
 }
