@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017,2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -7,9 +7,11 @@
 
 #include "LayerCloneBase.hpp"
 
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/utility/NumericCast.hpp>
+
+#include <armnn/backends/TensorHandle.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 namespace armnn
 {
@@ -21,8 +23,9 @@ PreluLayer::PreluLayer(const char* name)
 std::unique_ptr<IWorkload> PreluLayer::CreateWorkload(const IWorkloadFactory& factory) const
 {
     PreluQueueDescriptor descriptor;
+    SetAdditionalInfo(descriptor);
 
-    return factory.CreatePrelu(descriptor, PrepInfoAndDesc(descriptor));
+    return factory.CreateWorkload(LayerType::Prelu, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 PreluLayer* PreluLayer::Clone(Graph& graph) const
@@ -52,15 +55,15 @@ std::vector<TensorShape> PreluLayer::InferOutputShapes(const std::vector<TensorS
 
     TensorShape outputShape(outputDimensions);
 
-    int inputShapeIndex = boost::numeric_cast<int>(inputShapeDimensions) - 1;
-    int alphaShapeIndex = boost::numeric_cast<int>(alphaShapeDimensions) - 1;
+    int inputShapeIndex = armnn::numeric_cast<int>(inputShapeDimensions) - 1;
+    int alphaShapeIndex = armnn::numeric_cast<int>(alphaShapeDimensions) - 1;
     unsigned int outputShapeIndex = outputDimensions - 1;
 
     // Loop backwards through the common part of the shapes
     while (inputShapeIndex >= 0 && alphaShapeIndex >= 0)
     {
-        unsigned int inputDimension = inputShape[boost::numeric_cast<unsigned int>(inputShapeIndex)];
-        unsigned int alphaDimension = alphaShape[boost::numeric_cast<unsigned int>(alphaShapeIndex)];
+        unsigned int inputDimension = inputShape[armnn::numeric_cast<unsigned int>(inputShapeIndex)];
+        unsigned int alphaDimension = alphaShape[armnn::numeric_cast<unsigned int>(alphaShapeIndex)];
 
         // Check that the inputs are broadcast compatible
         ARMNN_ASSERT_MSG(inputDimension == alphaDimension || inputDimension == 1 || alphaDimension == 1,
@@ -76,7 +79,7 @@ std::vector<TensorShape> PreluLayer::InferOutputShapes(const std::vector<TensorS
     // Loop backwards through the remaing part of the input shape (if any)
     while (inputShapeIndex >= 0)
     {
-        outputShape[outputShapeIndex] = inputShape[boost::numeric_cast<unsigned int>(inputShapeIndex)];
+        outputShape[outputShapeIndex] = inputShape[armnn::numeric_cast<unsigned int>(inputShapeIndex)];
 
         inputShapeIndex--;
         outputShapeIndex--;
@@ -85,7 +88,7 @@ std::vector<TensorShape> PreluLayer::InferOutputShapes(const std::vector<TensorS
     // Loop backwards through the remaing part of the alpha shape (if any)
     while (alphaShapeIndex >= 0)
     {
-        outputShape[outputShapeIndex] = alphaShape[boost::numeric_cast<unsigned int>(alphaShapeIndex)];
+        outputShape[outputShapeIndex] = alphaShape[armnn::numeric_cast<unsigned int>(alphaShapeIndex)];
 
         alphaShapeIndex--;
         outputShapeIndex--;
@@ -104,8 +107,8 @@ void PreluLayer::ValidateTensorShapesFromInputs()
 
     std::vector<TensorShape> inferredShapes = InferOutputShapes(
     {
-        GetInputSlot(0).GetConnection()->GetTensorInfo().GetShape(),
-        GetInputSlot(1).GetConnection()->GetTensorInfo().GetShape()
+        GetInputSlot(0).GetTensorInfo().GetShape(),
+        GetInputSlot(1).GetTensorInfo().GetShape()
     });
 
     ARMNN_ASSERT(inferredShapes.size() == 1);
@@ -113,9 +116,9 @@ void PreluLayer::ValidateTensorShapesFromInputs()
     ValidateAndCopyShape(outputShape, inferredShapes[0], m_ShapeInferenceMethod, "PreluLayer");
 }
 
-void PreluLayer::Accept(ILayerVisitor& visitor) const
+void PreluLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    visitor.VisitPreluLayer(this, GetName());
+    strategy.ExecuteStrategy(this, GetParameters(), {}, GetName());
 }
 
 } // namespace armnn
