@@ -1,5 +1,5 @@
 //
-// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2020-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -7,8 +7,8 @@
 
 #include "LayerCloneBase.hpp"
 
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 namespace armnn
 {
@@ -20,7 +20,9 @@ RankLayer::RankLayer(const char* name)
 std::unique_ptr<IWorkload> RankLayer::CreateWorkload(const IWorkloadFactory& factory) const
 {
     RankQueueDescriptor descriptor;
-    return factory.CreateRank(descriptor, PrepInfoAndDesc(descriptor));
+    SetAdditionalInfo(descriptor);
+
+    return factory.CreateWorkload(LayerType::Rank, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 Layer* RankLayer::Clone(Graph& graph) const
@@ -29,6 +31,11 @@ Layer* RankLayer::Clone(Graph& graph) const
     return clone;
 }
 
+std::vector<TensorShape> RankLayer::InferOutputShapes(const std::vector<TensorShape>&) const
+{
+    return std::vector<TensorShape>({ TensorShape(Dimensionality::Scalar) });
+}
+
 void RankLayer::ValidateTensorShapesFromInputs()
 {
     VerifyLayerConnections(1, CHECK_LOCATION());
@@ -39,9 +46,10 @@ void RankLayer::ValidateTensorShapesFromInputs()
     VerifyShapeInferenceType(outputShape, m_ShapeInferenceMethod);
     ValidateAndCopyShape(outputShape, inferredShape, m_ShapeInferenceMethod, "RankLayer");
 }
-void RankLayer::Accept(ILayerVisitor& visitor) const
+
+void RankLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    visitor.VisitRankLayer(this, GetName());
+    strategy.ExecuteStrategy(this, BaseDescriptor(), {}, GetName());
 }
 
 } //namespace armnn
\ No newline at end of file
