@@ -35,9 +35,8 @@ public:
     /// @return Does not return anything. Throws Exception if called.
     std::vector<TensorShape> InferOutputShapes(const std::vector<TensorShape>& inputShapes) const override;
 
-    /// Accepts a visitor object and calls VisitStandInLayer() method.
-    /// @param visitor The visitor on which to call VisitStandInLayer() method.
-    void Accept(ILayerVisitor& visitor) const override;
+    void ExecuteStrategy(IStrategy& strategy) const override;
+
 
 protected:
     /// Constructor to create a StandInLayer.
