@@ -1,15 +1,15 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2018-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "StridedSliceLayer.hpp"
 
 #include "LayerCloneBase.hpp"
 
-#include <backendsCommon/WorkloadData.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/utility/NumericCast.hpp>
 
-#include <boost/numeric/conversion/cast.hpp>
+#include <armnn/backends/WorkloadData.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 namespace armnn
 {
@@ -34,7 +34,9 @@ std::unique_ptr<IWorkload> StridedSliceLayer::CreateWorkload(const IWorkloadFact
     descriptor.m_Parameters.m_NewAxisMask    = m_Param.m_NewAxisMask;
     descriptor.m_Parameters.m_ShrinkAxisMask = m_Param.m_ShrinkAxisMask;
 
-    return factory.CreateStridedSlice(descriptor, PrepInfoAndDesc(descriptor));
+    SetAdditionalInfo(descriptor);
+
+    return factory.CreateWorkload(LayerType::StridedSlice, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 StridedSliceLayer* StridedSliceLayer::Clone(Graph& graph) const
@@ -82,7 +84,7 @@ std::vector<TensorShape> StridedSliceLayer::InferOutputShapes(
 
         newSize = std::max(0, newSize);
 
-        outputShape.push_back(boost::numeric_cast<unsigned int>(newSize));
+        outputShape.push_back(armnn::numeric_cast<unsigned int>(newSize));
     }
 
     if (outputShape.size() == 0 && (inputShape.GetNumDimensions() - amountDimShrunk) == 0)
@@ -91,7 +93,7 @@ std::vector<TensorShape> StridedSliceLayer::InferOutputShapes(
     }
 
     return std::vector<TensorShape>({
-        TensorShape(boost::numeric_cast<unsigned int>(outputShape.size()), &outputShape[0]) });
+        TensorShape(armnn::numeric_cast<unsigned int>(outputShape.size()), &outputShape[0]) });
 }
 
 void StridedSliceLayer::ValidateTensorShapesFromInputs()
@@ -102,16 +104,16 @@ void StridedSliceLayer::ValidateTensorShapesFromInputs()
 
     VerifyShapeInferenceType(outputShape, m_ShapeInferenceMethod);
 
-    auto inferredShapes = InferOutputShapes({GetInputSlot(0).GetConnection()->GetTensorInfo().GetShape()});
+    auto inferredShapes = InferOutputShapes({GetInputSlot(0).GetTensorInfo().GetShape()});
 
     ARMNN_ASSERT(inferredShapes.size() == 1);
 
     ValidateAndCopyShape(outputShape, inferredShapes[0], m_ShapeInferenceMethod, "StridedSliceLayer");
 }
 
-void StridedSliceLayer::Accept(ILayerVisitor& visitor) const
+void StridedSliceLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    visitor.VisitStridedSliceLayer(this, GetParameters(), GetName());
+    strategy.ExecuteStrategy(this, GetParameters(), {}, GetName());
 }
 
 } // namespace armnn
