@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -8,8 +8,8 @@
 
 #include <armnnUtils/DataLayoutIndexed.hpp>
 
-#include <backendsCommon/CpuTensorHandle.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/TensorHandle.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 using namespace armnnUtils;
 
@@ -35,18 +35,20 @@ std::unique_ptr<IWorkload> TransposeConvolution2dLayer::CreateWorkload(const IWo
         descriptor.m_Bias = m_Bias.get();
     }
 
-    return factory.CreateTransposeConvolution2d(descriptor, PrepInfoAndDesc(descriptor));
+    SetAdditionalInfo(descriptor);
+
+    return factory.CreateWorkload(LayerType::TransposeConvolution2d, descriptor, PrepInfoAndDesc(descriptor));
 }
 
 TransposeConvolution2dLayer* TransposeConvolution2dLayer::Clone(Graph& graph) const
 {
     auto layer = CloneBase<TransposeConvolution2dLayer>(graph, m_Param, GetName());
 
-    layer->m_Weight = m_Weight ? std::make_unique<ScopedCpuTensorHandle>(*m_Weight) : nullptr;
+    layer->m_Weight = m_Weight ? m_Weight : nullptr;
 
     if (layer->m_Param.m_BiasEnabled)
     {
-        layer->m_Bias = m_Bias ? std::make_unique<ScopedCpuTensorHandle>(*m_Bias) : nullptr;
+        layer->m_Bias = m_Bias ? m_Bias : nullptr;
     }
 
     return std::move(layer);
@@ -76,27 +78,11 @@ std::vector<TensorShape> TransposeConvolution2dLayer::InferOutputShapes(
 
     unsigned int wOutput = (wInput - 1) * m_Param.m_StrideX + wKernel - wPadding;
     unsigned int hOutput = (hInput - 1) * m_Param.m_StrideY + hKernel - hPadding;
-
-    unsigned int kernelElements = kernelShape[0] * kernelShape[dataLayoutIndex.GetChannelsIndex()];
-    unsigned int inputElements  = batches * inputShape[dataLayoutIndex.GetChannelsIndex()];
-
-    ARMNN_ASSERT_MSG(inputElements != 0, "Invalid number of input elements");
-
-    unsigned int channels;
-    if (kernelElements >= inputElements)
-    {
-        ARMNN_ASSERT_MSG(kernelElements % inputElements == 0 , "Invalid number of elements");
-        channels = kernelElements / inputElements;
-    }
-    else
-    {
-        ARMNN_ASSERT_MSG(inputElements % kernelElements == 0 , "Invalid number of elements");
-        channels = kernelShape[0];
-    }
+    unsigned int cOutput = kernelShape[0];
 
     TensorShape tensorShape = m_Param.m_DataLayout == armnn::DataLayout::NHWC ?
-         TensorShape( { batches, hOutput, wOutput, channels } ) :
-         TensorShape( { batches, channels, hOutput, wOutput });
+         TensorShape( { batches, hOutput, wOutput, cOutput } ) :
+         TensorShape( { batches, cOutput, hOutput, wOutput });
 
     return std::vector<TensorShape>({ tensorShape });
 }
@@ -112,41 +98,47 @@ void TransposeConvolution2dLayer::ValidateTensorShapesFromInputs()
     ARMNN_ASSERT_MSG(m_Weight != nullptr, "TransposeConvolution2dLayer: Weight data cannot be null.");
 
     std::vector<TensorShape> expectedOutputShape;
+    std::vector<TensorShape> outputShapeGivenAsInput;
+
+    expectedOutputShape = InferOutputShapes({GetInputSlot(0).GetTensorInfo().GetShape(),
+                                             m_Weight->GetTensorInfo().GetShape() });
+
+    ARMNN_ASSERT(expectedOutputShape.size() == 1);
+
     // If output_shape was specified then use it rather than calculate an inferred output shape.
     if (m_Param.m_OutputShapeEnabled)
     {
         TensorShape shapeAsTensorShape(static_cast<unsigned int>(m_Param.m_OutputShape.size()),
             m_Param.m_OutputShape.data());
-        expectedOutputShape.push_back(shapeAsTensorShape);
-    }
-    else
-    {
-        expectedOutputShape = InferOutputShapes({GetInputSlot(0).GetConnection()->GetTensorInfo().GetShape(),
-                                                 m_Weight->GetTensorInfo().GetShape() });
-    }
+        outputShapeGivenAsInput.push_back(shapeAsTensorShape);
 
-    ARMNN_ASSERT(expectedOutputShape.size() == 1);
+        ARMNN_ASSERT(outputShapeGivenAsInput.size() == 1);
+        ARMNN_ASSERT_MSG(expectedOutputShape == outputShapeGivenAsInput,
+                         "TransposeConvolution2dLayer: output calculated by InferOutputShapes and "
+                         "the output given as an input parameter to the layer are not matching");
+    }
 
     ValidateAndCopyShape(outputShape, expectedOutputShape[0], m_ShapeInferenceMethod, "TransposeConvolution2dLayer");
 }
 
-Layer::ConstantTensors TransposeConvolution2dLayer::GetConstantTensorsByRef()
+Layer::ImmutableConstantTensors TransposeConvolution2dLayer::GetConstantTensorsByRef() const
 {
+    // For API stability DO NOT ALTER order and add new members to the end of vector
     return {m_Weight, m_Bias};
 }
 
-void TransposeConvolution2dLayer::Accept(ILayerVisitor& visitor) const
+void TransposeConvolution2dLayer::ExecuteStrategy(IStrategy& strategy) const
 {
-    ConstTensor weightsTensor(m_Weight->GetTensorInfo(), m_Weight->Map(true)) ;
-    Optional<ConstTensor> optionalBiasTensor = EmptyOptional();
+    ManagedConstTensorHandle managedWeight(m_Weight);
+    std::vector<armnn::ConstTensor> constTensors { { managedWeight.GetTensorInfo(), managedWeight.Map() } };
 
+    ManagedConstTensorHandle managedBias(m_Bias);
     if (GetParameters().m_BiasEnabled)
     {
-        ConstTensor biasTensor(m_Bias->GetTensorInfo(), m_Bias->Map(true));
-        optionalBiasTensor = Optional<ConstTensor>(biasTensor);
+        constTensors.emplace_back(ConstTensor(managedBias.GetTensorInfo(), managedBias.Map()));
     }
 
-    visitor.VisitTransposeConvolution2dLayer(this, GetParameters(), weightsTensor, optionalBiasTensor, GetName());
+    strategy.ExecuteStrategy(this, GetParameters(), constTensors, GetName());
 }
 
 } // namespace armnn
