@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017, 2023 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -9,10 +9,10 @@
 #include <armnn/Types.hpp>
 #include <Runtime.hpp>
 
-#include <boost/test/unit_test.hpp>
-
-BOOST_AUTO_TEST_SUITE(DebugCallback)
+#include <doctest/doctest.h>
 
+TEST_SUITE("DebugCallback")
+{
 namespace
 {
 
@@ -39,7 +39,7 @@ INetworkPtr CreateSimpleNetwork()
     return net;
 }
 
-BOOST_AUTO_TEST_CASE(RuntimeRegisterDebugCallback)
+TEST_CASE("RuntimeRegisterDebugCallback")
 {
     INetworkPtr net = CreateSimpleNetwork();
 
@@ -47,12 +47,12 @@ BOOST_AUTO_TEST_CASE(RuntimeRegisterDebugCallback)
     IRuntimePtr runtime(IRuntime::Create(options));
 
     // Optimize the network with debug option
-    OptimizerOptions optimizerOptions(false, true);
+    OptimizerOptionsOpaque optimizerOptions(false, true);
     std::vector<BackendId> backends = { "CpuRef" };
     IOptimizedNetworkPtr optNet = Optimize(*net, backends, runtime->GetDeviceSpec(), optimizerOptions);
 
     NetworkId netId;
-    BOOST_TEST(runtime->LoadNetwork(netId, std::move(optNet)) == Status::Success);
+    CHECK(runtime->LoadNetwork(netId, std::move(optNet)) == Status::Success);
 
     // Set up callback function
     int callCount = 0;
@@ -60,7 +60,7 @@ BOOST_AUTO_TEST_CASE(RuntimeRegisterDebugCallback)
     std::vector<unsigned int> slotIndexes;
     auto mockCallback = [&](LayerGuid guid, unsigned int slotIndex, ITensorHandle* tensor)
     {
-        IgnoreUnused(guid);
+        armnn::IgnoreUnused(guid);
         slotIndexes.push_back(slotIndex);
         tensorShapes.push_back(tensor->GetShape());
         callCount++;
@@ -71,9 +71,11 @@ BOOST_AUTO_TEST_CASE(RuntimeRegisterDebugCallback)
     std::vector<float> inputData({-2, -1, 0, 1, 2});
     std::vector<float> outputData(5);
 
+    TensorInfo inputTensorInfo = runtime->GetInputTensorInfo(netId, 0);
+    inputTensorInfo.SetConstant(true);
     InputTensors inputTensors
     {
-        {0, ConstTensor(runtime->GetInputTensorInfo(netId, 0), inputData.data())}
+        {0, ConstTensor(inputTensorInfo, inputData.data())}
     };
     OutputTensors outputTensors
     {
@@ -83,17 +85,17 @@ BOOST_AUTO_TEST_CASE(RuntimeRegisterDebugCallback)
     runtime->EnqueueWorkload(netId, inputTensors, outputTensors);
 
     // Check that the callback was called twice
-    BOOST_TEST(callCount == 2);
+    CHECK(callCount == 2);
 
     // Check that tensor handles passed to callback have correct shapes
     const std::vector<TensorShape> expectedShapes({TensorShape({1, 1, 1, 5}), TensorShape({1, 1, 1, 5})});
-    BOOST_TEST(tensorShapes == expectedShapes);
+    CHECK(tensorShapes == expectedShapes);
 
     // Check that slot indexes passed to callback are correct
     const std::vector<unsigned int> expectedSlotIndexes({0, 0});
-    BOOST_TEST(slotIndexes == expectedSlotIndexes);
+    CHECK(slotIndexes == expectedSlotIndexes);
 }
 
 } // anonymous namespace
 
-BOOST_AUTO_TEST_SUITE_END()
+}
