@@ -5,49 +5,51 @@
 #include "TestInputOutputLayerVisitor.hpp"
 #include "Network.hpp"
 
+#include <doctest/doctest.h>
+
 namespace armnn
 {
 
-BOOST_AUTO_TEST_SUITE(TestInputOutputLayerVisitor)
-
-BOOST_AUTO_TEST_CASE(CheckInputLayerVisitorBindingIdAndName)
+TEST_SUITE("TestInputOutputLayerVisitor")
+{
+TEST_CASE("CheckInputLayerVisitorBindingIdAndName")
 {
     const char* layerName = "InputLayer";
     TestInputLayerVisitor visitor(1, layerName);
-    Network net;
+    NetworkImpl net;
 
     IConnectableLayer *const layer = net.AddInputLayer(1, layerName);
-    layer->Accept(visitor);
+    layer->ExecuteStrategy(visitor);
 }
 
-BOOST_AUTO_TEST_CASE(CheckInputLayerVisitorBindingIdAndNameNull)
+TEST_CASE("CheckInputLayerVisitorBindingIdAndNameNull")
 {
     TestInputLayerVisitor visitor(1);
-    Network net;
+    NetworkImpl net;
 
     IConnectableLayer *const layer = net.AddInputLayer(1);
-    layer->Accept(visitor);
+    layer->ExecuteStrategy(visitor);
 }
 
-BOOST_AUTO_TEST_CASE(CheckOutputLayerVisitorBindingIdAndName)
+TEST_CASE("CheckOutputLayerVisitorBindingIdAndName")
 {
     const char* layerName = "OutputLayer";
     TestOutputLayerVisitor visitor(1, layerName);
-    Network net;
+    NetworkImpl net;
 
     IConnectableLayer *const layer = net.AddOutputLayer(1, layerName);
-    layer->Accept(visitor);
+    layer->ExecuteStrategy(visitor);
 }
 
-BOOST_AUTO_TEST_CASE(CheckOutputLayerVisitorBindingIdAndNameNull)
+TEST_CASE("CheckOutputLayerVisitorBindingIdAndNameNull")
 {
     TestOutputLayerVisitor visitor(1);
-    Network net;
+    NetworkImpl net;
 
     IConnectableLayer *const layer = net.AddOutputLayer(1);
-    layer->Accept(visitor);
+    layer->ExecuteStrategy(visitor);
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
 
 } //namespace armnn
\ No newline at end of file
