@@ -3,15 +3,15 @@
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersSerializeFixture.hpp"
-#include "../Deserializer.hpp"
+#include <armnnDeserializer/IDeserializer.hpp>
+
+#include <doctest/doctest.h>
 
 #include <string>
-#include <iostream>
-
-BOOST_AUTO_TEST_SUITE(Deserializer)
 
+TEST_SUITE("Deserializer_Abs")
+{
     struct AbsFixture : public ParserFlatbuffersSerializeFixture
     {
         explicit AbsFixture(const std::string &inputShape,
@@ -109,7 +109,7 @@ BOOST_AUTO_TEST_SUITE(Deserializer)
         {}
     };
 
-    BOOST_FIXTURE_TEST_CASE(SimpleAbsTest, SimpleAbsFixture)
+    TEST_CASE_FIXTURE(SimpleAbsFixture, "SimpleAbsTest")
     {
         RunTest<4, armnn::DataType::Float32>(
                 0,
@@ -117,4 +117,4 @@ BOOST_AUTO_TEST_SUITE(Deserializer)
                 {{"OutputLayer", { 100.0f, 50.5f, 25.9999f, 0.5f , 0.0f, 1.5555f, 25.5f, 100.0f }}});
     }
 
-BOOST_AUTO_TEST_SUITE_END()
\ No newline at end of file
+}
\ No newline at end of file
