@@ -4,17 +4,15 @@
 //
 
 #include "ParserFlatbuffersSerializeFixture.hpp"
-#include "../Deserializer.hpp"
+#include <armnnDeserializer/IDeserializer.hpp>
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 #include <ResolveType.hpp>
 
-#include <boost/test/unit_test.hpp>
-
 #include <string>
 
-BOOST_AUTO_TEST_SUITE(Deserializer)
-
+TEST_SUITE("Deserializer_Comparison")
+{
 #define DECLARE_SIMPLE_COMPARISON_FIXTURE(operation, dataType) \
 struct Simple##operation##dataType##Fixture : public SimpleComparisonFixture \
 { \
@@ -24,7 +22,7 @@ struct Simple##operation##dataType##Fixture : public SimpleComparisonFixture \
 
 #define DECLARE_SIMPLE_COMPARISON_TEST_CASE(operation, dataType) \
 DECLARE_SIMPLE_COMPARISON_FIXTURE(operation, dataType) \
-BOOST_FIXTURE_TEST_CASE(operation##dataType, Simple##operation##dataType##Fixture) \
+TEST_CASE_FIXTURE(Simple##operation##dataType##Fixture, #operation#dataType) \
 { \
     using T = armnn::ResolveType<armnn::DataType::dataType>; \
     constexpr float   qScale  = 1.f; \
@@ -243,15 +241,6 @@ DECLARE_SIMPLE_COMPARISON_TEST_CASE(LessOrEqual,    Float32)
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(NotEqual,       Float32)
 
 
-ARMNN_NO_DEPRECATE_WARN_BEGIN
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(Equal,          QuantisedAsymm8)
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(Greater,        QuantisedAsymm8)
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(GreaterOrEqual, QuantisedAsymm8)
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(Less,           QuantisedAsymm8)
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(LessOrEqual,    QuantisedAsymm8)
-DECLARE_SIMPLE_COMPARISON_TEST_CASE(NotEqual,       QuantisedAsymm8)
-ARMNN_NO_DEPRECATE_WARN_END
-
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(Equal,          QAsymmU8)
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(Greater,        QAsymmU8)
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(GreaterOrEqual, QAsymmU8)
@@ -259,4 +248,4 @@ DECLARE_SIMPLE_COMPARISON_TEST_CASE(Less,           QAsymmU8)
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(LessOrEqual,    QAsymmU8)
 DECLARE_SIMPLE_COMPARISON_TEST_CASE(NotEqual,       QAsymmU8)
 
-BOOST_AUTO_TEST_SUITE_END()
+}
