@@ -3,15 +3,13 @@
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersSerializeFixture.hpp"
-#include "../Deserializer.hpp"
+#include <armnnDeserializer/IDeserializer.hpp>
 
 #include <string>
-#include <iostream>
-
-BOOST_AUTO_TEST_SUITE(Deserializer)
 
+TEST_SUITE("Deserializer_Gather")
+{
 struct GatherFixture : public ParserFlatbuffersSerializeFixture
 {
     explicit GatherFixture(const std::string& inputShape,
@@ -121,7 +119,10 @@ struct GatherFixture : public ParserFlatbuffersSerializeFixture
                                         },
                                 }],
                             }}},
-                }]
+                }],
+                featureVersions: {
+                    weightsLayoutScheme: 1,
+                }
                  } )";
 
         Setup();
@@ -134,7 +135,7 @@ struct SimpleGatherFixtureFloat32 : GatherFixture
                                                  "[ 2, 3, 2, 3 ]", "0", "Float32", "IntData") {}
 };
 
-BOOST_FIXTURE_TEST_CASE(GatherFloat32, SimpleGatherFixtureFloat32)
+TEST_CASE_FIXTURE(SimpleGatherFixtureFloat32, "GatherFloat32")
 {
     RunTest<4, armnn::DataType::Float32>(0,
                                          {{"InputLayer", {  1,  2,  3,
@@ -157,5 +158,5 @@ BOOST_FIXTURE_TEST_CASE(GatherFloat32, SimpleGatherFixtureFloat32)
                                                             4,  5,  6 }}});
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
 
