@@ -3,12 +3,11 @@
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "armnnOnnxParser/IOnnxParser.hpp"
 #include  "ParserPrototxtFixture.hpp"
 
-BOOST_AUTO_TEST_SUITE(OnnxParser)
-
+TEST_SUITE("OnnxParser_Addition")
+{
 struct AddMainFixture : public armnnUtils::ParserPrototxtFixture<armnnOnnxParser::IOnnxParser>
 {
     AddMainFixture(const std::string& dataType)
@@ -383,37 +382,37 @@ struct AddInvalidScalarFixture : AddScalarFixture
     AddInvalidScalarFixture() : AddScalarFixture("6") { }
 };
 
-BOOST_FIXTURE_TEST_CASE(ValidAddTest, AddValidFixture)
+TEST_CASE_FIXTURE(AddValidFixture, "ValidAddTest")
 {
     RunTest<4>({{"Input0", {1.0f, 2.0f, -3.0f, -4.0f}},
                 {"Input1", {1.0f, 2.0f, 3.0, 4.0f}}}, {{"Output", {2.0, 4.0, 0, 0.0}}});
 }
 
-BOOST_FIXTURE_TEST_CASE(IncorrectDataTypeAdd, AddInvalidFixture)
+TEST_CASE_FIXTURE(AddInvalidFixture, "IncorrectDataTypeAdd")
 {
-   BOOST_CHECK_THROW(Setup(), armnn::ParseException);
+   CHECK_THROWS_AS(Setup(), armnn::ParseException);
 }
 
-BOOST_FIXTURE_TEST_CASE(InvalidBroadcastAdd, AddInvalidBroadcastFixture)
+TEST_CASE_FIXTURE(AddInvalidBroadcastFixture, "InvalidBroadcastAdd")
 {
-   BOOST_CHECK_THROW(Setup(), armnn::ParseException);
+   CHECK_THROWS_AS(Setup(), armnn::ParseException);
 }
 
-BOOST_FIXTURE_TEST_CASE(ValidBroadcastAdd, AddValidBroadcastFixture)
+TEST_CASE_FIXTURE(AddValidBroadcastFixture, "ValidBroadcastAdd")
 {
     RunTest<4>({{"Input0", {1.0f, 2.0f, -3.0f, -4.0f}},
                 {"Input1", {1.0f, 2.0f, 3.0, 4.0f}}}, {{"Output", {2.0, 4.0, 0, 0.0}}});
 }
 
-BOOST_FIXTURE_TEST_CASE(ValidAddScalarTest, AddValidScalarFixture)
+TEST_CASE_FIXTURE(AddValidScalarFixture, "ValidAddScalarTest")
 {
     RunTest<4>({{"Input0", {1.0f, 2.0f, -3.0f, -4.0f}},
                 {"Input1", {-8.0f}}}, {{"Output", {-7.0, -6.0, -11.0, -12.0}}});
 }
 
-BOOST_FIXTURE_TEST_CASE(IncorrectDataTypeAddScalar, AddInvalidScalarFixture)
+TEST_CASE_FIXTURE(AddInvalidScalarFixture, "IncorrectDataTypeAddScalar")
 {
-    BOOST_CHECK_THROW(Setup(), armnn::ParseException);
+    CHECK_THROWS_AS(Setup(), armnn::ParseException);
 }
 
-BOOST_AUTO_TEST_SUITE_END()
\ No newline at end of file
+}
\ No newline at end of file
