@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017,2019-2021,2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -28,6 +28,20 @@ armnnSerializer::ComparisonOperation GetFlatBufferComparisonOperation(armnn::Com
     }
 }
 
+armnnSerializer::LogicalBinaryOperation GetFlatBufferLogicalBinaryOperation(
+    armnn::LogicalBinaryOperation logicalBinaryOperation)
+{
+    switch (logicalBinaryOperation)
+    {
+        case armnn::LogicalBinaryOperation::LogicalAnd:
+            return armnnSerializer::LogicalBinaryOperation::LogicalBinaryOperation_LogicalAnd;
+        case armnn::LogicalBinaryOperation::LogicalOr:
+            return armnnSerializer::LogicalBinaryOperation::LogicalBinaryOperation_LogicalOr;
+        default:
+            throw armnn::InvalidArgumentException("Logical Binary operation unknown");
+    }
+}
+
 armnnSerializer::ConstTensorData GetFlatBufferConstTensorData(armnn::DataType dataType)
 {
     switch (dataType)
@@ -38,10 +52,13 @@ armnnSerializer::ConstTensorData GetFlatBufferConstTensorData(armnn::DataType da
         case armnn::DataType::Float16:
         case armnn::DataType::QSymmS16:
             return armnnSerializer::ConstTensorData::ConstTensorData_ShortData;
+        case armnn::DataType::QAsymmS8:
         case armnn::DataType::QAsymmU8:
         case armnn::DataType::QSymmS8:
         case armnn::DataType::Boolean:
             return armnnSerializer::ConstTensorData::ConstTensorData_ByteData;
+        case armnn::DataType::Signed64:
+            return armnnSerializer::ConstTensorData::ConstTensorData_LongData;
         default:
             return armnnSerializer::ConstTensorData::ConstTensorData_NONE;
     }
@@ -57,6 +74,8 @@ armnnSerializer::DataType GetFlatBufferDataType(armnn::DataType dataType)
             return armnnSerializer::DataType::DataType_Float16;
         case armnn::DataType::Signed32:
             return armnnSerializer::DataType::DataType_Signed32;
+        case armnn::DataType::Signed64:
+            return armnnSerializer::DataType::DataType_Signed64;
         case armnn::DataType::QSymmS16:
             return armnnSerializer::DataType::DataType_QSymmS16;
         case armnn::DataType::QAsymmS8:
@@ -78,18 +97,49 @@ armnnSerializer::DataLayout GetFlatBufferDataLayout(armnn::DataLayout dataLayout
     {
         case armnn::DataLayout::NHWC:
             return armnnSerializer::DataLayout::DataLayout_NHWC;
+        case armnn::DataLayout::NDHWC:
+            return armnnSerializer::DataLayout::DataLayout_NDHWC;
+        case armnn::DataLayout::NCDHW:
+            return armnnSerializer::DataLayout::DataLayout_NCDHW;
         case armnn::DataLayout::NCHW:
         default:
             return armnnSerializer::DataLayout::DataLayout_NCHW;
     }
 }
 
-armnnSerializer::UnaryOperation GetFlatBufferUnaryOperation(armnn::UnaryOperation comparisonOperation)
+armnnSerializer::BinaryOperation GetFlatBufferBinaryOperation(armnn::BinaryOperation binaryOperation)
 {
-    switch (comparisonOperation)
+    switch (binaryOperation)
+    {
+        case armnn::BinaryOperation::Add:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Add;
+        case armnn::BinaryOperation::Div:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Div;
+        case armnn::BinaryOperation::Maximum:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Maximum;
+        case armnn::BinaryOperation::Minimum:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Minimum;
+        case armnn::BinaryOperation::Mul:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Mul;
+        case armnn::BinaryOperation::Sub:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Sub;
+        case armnn::BinaryOperation::SqDiff:
+            return armnnSerializer::BinaryOperation::BinaryOperation_SqDiff;
+        case armnn::BinaryOperation::Power:
+            return armnnSerializer::BinaryOperation::BinaryOperation_Power;
+        default:
+            throw armnn::InvalidArgumentException("Elementwise Binary operation unknown");
+    }
+}
+
+armnnSerializer::UnaryOperation GetFlatBufferUnaryOperation(armnn::UnaryOperation unaryOperation)
+{
+    switch (unaryOperation)
     {
         case armnn::UnaryOperation::Abs:
             return armnnSerializer::UnaryOperation::UnaryOperation_Abs;
+        case armnn::UnaryOperation::Ceil:
+            return armnnSerializer::UnaryOperation::UnaryOperation_Ceil;
         case armnn::UnaryOperation::Rsqrt:
             return armnnSerializer::UnaryOperation::UnaryOperation_Rsqrt;
         case armnn::UnaryOperation::Sqrt:
@@ -98,8 +148,14 @@ armnnSerializer::UnaryOperation GetFlatBufferUnaryOperation(armnn::UnaryOperatio
             return armnnSerializer::UnaryOperation::UnaryOperation_Exp;
         case armnn::UnaryOperation::Neg:
             return armnnSerializer::UnaryOperation::UnaryOperation_Neg;
+        case armnn::UnaryOperation::LogicalNot:
+            return armnnSerializer::UnaryOperation::UnaryOperation_LogicalNot;
+        case armnn::UnaryOperation::Log:
+            return armnnSerializer::UnaryOperation::UnaryOperation_Log;
+        case armnn::UnaryOperation::Sin:
+            return armnnSerializer::UnaryOperation::UnaryOperation_Sin;
         default:
-            throw armnn::InvalidArgumentException("Unary operation unknown");
+            throw armnn::InvalidArgumentException("Elementwise Unary operation unknown");
     }
 }
 
@@ -141,6 +197,19 @@ armnnSerializer::PaddingMethod GetFlatBufferPaddingMethod(armnn::PaddingMethod p
     }
 }
 
+armnnSerializer::PaddingMode GetFlatBufferPaddingMode(armnn::PaddingMode paddingMode)
+{
+    switch (paddingMode)
+    {
+        case armnn::PaddingMode::Reflect:
+            return armnnSerializer::PaddingMode::PaddingMode_Reflect;
+        case armnn::PaddingMode::Symmetric:
+            return armnnSerializer::PaddingMode::PaddingMode_Symmetric;
+        default:
+            return armnnSerializer::PaddingMode::PaddingMode_Constant;
+    }
+}
+
 armnnSerializer::NormalizationAlgorithmChannel GetFlatBufferNormalizationAlgorithmChannel(
     armnn::NormalizationAlgorithmChannel normalizationAlgorithmChannel)
 {
@@ -182,4 +251,23 @@ armnnSerializer::ResizeMethod GetFlatBufferResizeMethod(armnn::ResizeMethod meth
     }
 }
 
+armnnSerializer::ReduceOperation GetFlatBufferReduceOperation(armnn::ReduceOperation reduceOperation)
+{
+    switch (reduceOperation)
+    {
+        case armnn::ReduceOperation::Sum:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Sum;
+        case armnn::ReduceOperation::Max:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Max;
+        case armnn::ReduceOperation::Mean:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Mean;
+        case armnn::ReduceOperation::Min:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Min;
+        case armnn::ReduceOperation::Prod:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Prod;
+        default:
+            return armnnSerializer::ReduceOperation::ReduceOperation_Sum;
+    }
+}
+
 } // namespace armnnSerializer
