@@ -1,14 +1,14 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
+#include <doctest/doctest.h>
 
+TEST_SUITE("TensorflowLiteParser_Activations")
+{
 struct ActivationFixture : ParserFlatbuffersFixture
 {
 
@@ -68,7 +68,7 @@ struct ReLuFixture : ActivationFixture
 {
     ReLuFixture() : ActivationFixture("RELU", "FLOAT32") {}
 };
-BOOST_FIXTURE_TEST_CASE(ParseReLu, ReLuFixture)
+TEST_CASE_FIXTURE(ReLuFixture, "ParseReLu")
 {
     RunTest<2, armnn::DataType::Float32>(0, { -1.0f, -0.5f, 1.25f, -3.0f, 0.0f, 0.5f, -0.75f },
                                          { 0.0f, 0.0f, 1.25f, 0.0f, 0.0f, 0.5f, 0.0f });
@@ -78,7 +78,7 @@ struct ReLu6Fixture : ActivationFixture
 {
     ReLu6Fixture() : ActivationFixture("RELU6", "FLOAT32") {}
 };
-BOOST_FIXTURE_TEST_CASE(ParseReLu6, ReLu6Fixture)
+TEST_CASE_FIXTURE(ReLu6Fixture, "ParseReLu6")
 {
     RunTest<2, armnn::DataType::Float32>(0, { -1.0f, -0.5f, 7.25f, -3.0f, 0.0f, 0.5f, -0.75f },
                                          { 0.0f, 0.0f, 6.0f, 0.0f, 0.0f, 0.5f, 0.0f });
@@ -88,7 +88,7 @@ struct SigmoidFixture : ActivationFixture
 {
     SigmoidFixture() : ActivationFixture("LOGISTIC", "FLOAT32") {}
 };
-BOOST_FIXTURE_TEST_CASE(ParseLogistic, SigmoidFixture)
+TEST_CASE_FIXTURE(SigmoidFixture, "ParseLogistic")
 {
     RunTest<2, armnn::DataType::Float32>(0, { -1.0f,     -0.5f,      4.0f,       -4.0f,  0.0f,      0.5f,     -0.75f },
                                          {0.268941f, 0.377541f, 0.982013f,  0.0179862f,  0.5f, 0.622459f,  0.320821f });
@@ -99,22 +99,35 @@ struct TanHFixture : ActivationFixture
     TanHFixture() : ActivationFixture("TANH", "FLOAT32") {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseTanH, TanHFixture)
+TEST_CASE_FIXTURE(TanHFixture, "ParseTanH")
 {
     RunTest<2, armnn::DataType::Float32>(0,
         { -0.1f,       -0.2f,         -0.3f,       -0.4f,    0.1f,         0.2f,              0.3f },
         { -0.09966799f, -0.19737528f, -0.29131261f, -0.379949f, 0.09966799f, 0.19737528f, 0.29131261f });
 }
 
+struct EluFixture : ActivationFixture
+{
+    EluFixture() : ActivationFixture("ELU", "FLOAT32") {}
+};
+
+TEST_CASE_FIXTURE(EluFixture, "ParseElu")
+{
+    RunTest<2, armnn::DataType::Float32>(0,
+                                         { -2.0f,           -1.0f,           -0.0f, 0.0f, 1.0f, 2.0f, 3.0f },
+                                         { -0.86466471676f, -0.63212055882f, -0.0f, 0.0f, 1.0f, 2.0f, 3.0f });
+}
+
 struct HardSwishFixture : ActivationFixture
 {
     HardSwishFixture() : ActivationFixture("HARD_SWISH", "FLOAT32") {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseHardSwish, HardSwishFixture)
+TEST_CASE_FIXTURE(HardSwishFixture, "ParseHardSwish")
 {
     RunTest<2, armnn::DataType::Float32>(0,
                                          { -4.0f, -3.0f,        -2.9f,  1.2f,        2.2f, 3.0f, 4.0f },
                                          { -0.0f, -0.0f, -0.04833334f, 0.84f, 1.90666667f, 3.0f, 4.0f });
 }
-BOOST_AUTO_TEST_SUITE_END()
+
+}
