@@ -1,17 +1,13 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <string>
-#include <iostream>
-
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
 
+TEST_SUITE("TensorflowLiteParser_Concatenation")
+{
 struct ConcatenationFixture : public ParserFlatbuffersFixture
 {
     explicit ConcatenationFixture(const std::string & inputShape1,
@@ -98,7 +94,7 @@ struct ConcatenationFixtureNegativeDim : ConcatenationFixture
                                                              "-3" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenationNegativeDim, ConcatenationFixtureNegativeDim)
+TEST_CASE_FIXTURE(ConcatenationFixtureNegativeDim, "ParseConcatenationNegativeDim")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -112,7 +108,7 @@ struct ConcatenationFixtureNCHW : ConcatenationFixture
     ConcatenationFixtureNCHW() : ConcatenationFixture("[ 1, 1, 2, 2 ]", "[ 1, 1, 2, 2 ]", "[ 1, 2, 2, 2 ]", "1" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenationNCHW, ConcatenationFixtureNCHW)
+TEST_CASE_FIXTURE(ConcatenationFixtureNCHW, "ParseConcatenationNCHW")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -126,7 +122,7 @@ struct ConcatenationFixtureNHWC : ConcatenationFixture
     ConcatenationFixtureNHWC() : ConcatenationFixture("[ 1, 1, 2, 2 ]", "[ 1, 1, 2, 2 ]", "[ 1, 1, 2, 4 ]", "3" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenationNHWC, ConcatenationFixtureNHWC)
+TEST_CASE_FIXTURE(ConcatenationFixtureNHWC, "ParseConcatenationNHWC")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -140,7 +136,7 @@ struct ConcatenationFixtureDim1 : ConcatenationFixture
     ConcatenationFixtureDim1() : ConcatenationFixture("[ 1, 2, 3, 4 ]", "[ 1, 2, 3, 4 ]", "[ 1, 4, 3, 4 ]", "1" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenationDim1, ConcatenationFixtureDim1)
+TEST_CASE_FIXTURE(ConcatenationFixtureDim1, "ParseConcatenationDim1")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -159,7 +155,7 @@ struct ConcatenationFixtureDim3 : ConcatenationFixture
     ConcatenationFixtureDim3() : ConcatenationFixture("[ 1, 2, 3, 4 ]", "[ 1, 2, 3, 4 ]", "[ 1, 2, 3, 8 ]", "3" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenationDim3, ConcatenationFixtureDim3)
+TEST_CASE_FIXTURE(ConcatenationFixtureDim3, "ParseConcatenationDim3")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -194,7 +190,7 @@ struct ConcatenationFixture3DDim0 : ConcatenationFixture
     ConcatenationFixture3DDim0() : ConcatenationFixture("[ 1, 2, 3]", "[ 2, 2, 3]", "[ 3, 2, 3]", "0" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenation3DDim0, ConcatenationFixture3DDim0)
+TEST_CASE_FIXTURE(ConcatenationFixture3DDim0, "ParseConcatenation3DDim0")
 {
     RunTest<3, armnn::DataType::QAsymmU8>(
         0,
@@ -211,7 +207,7 @@ struct ConcatenationFixture3DDim1 : ConcatenationFixture
     ConcatenationFixture3DDim1() : ConcatenationFixture("[ 1, 2, 3]", "[ 1, 4, 3]", "[ 1, 6, 3]", "1" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenation3DDim1, ConcatenationFixture3DDim1)
+TEST_CASE_FIXTURE(ConcatenationFixture3DDim1, "ParseConcatenation3DDim1")
 {
     RunTest<3, armnn::DataType::QAsymmU8>(
         0,
@@ -228,7 +224,7 @@ struct ConcatenationFixture3DDim2 : ConcatenationFixture
     ConcatenationFixture3DDim2() : ConcatenationFixture("[ 1, 2, 3]", "[ 1, 2, 6]", "[ 1, 2, 9]", "2" ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseConcatenation3DDim2, ConcatenationFixture3DDim2)
+TEST_CASE_FIXTURE(ConcatenationFixture3DDim2, "ParseConcatenation3DDim2")
 {
     RunTest<3, armnn::DataType::QAsymmU8>(
         0,
@@ -240,4 +236,4 @@ BOOST_FIXTURE_TEST_CASE(ParseConcatenation3DDim2, ConcatenationFixture3DDim2)
                               3,  4,  5, 12, 13, 14, 15, 16, 17 } } });
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
