@@ -1,19 +1,15 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <string>
-#include <iostream>
 
-using armnnTfLiteParser::TfLiteParser;
-
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
+using armnnTfLiteParser::TfLiteParserImpl;
 
+TEST_SUITE("TensorflowLiteParser_Constant")
+{
 struct ConstantAddFixture : public ParserFlatbuffersFixture
 {
     explicit ConstantAddFixture(const std::string & inputShape,
@@ -101,7 +97,7 @@ struct SimpleConstantAddFixture : ConstantAddFixture
     {}
 };
 
-BOOST_FIXTURE_TEST_CASE(SimpleConstantAdd, SimpleConstantAddFixture)
+TEST_CASE_FIXTURE(SimpleConstantAddFixture, "SimpleConstantAdd")
 {
     RunTest<2, armnn::DataType::QAsymmU8>(
                 0,
@@ -110,4 +106,4 @@ BOOST_FIXTURE_TEST_CASE(SimpleConstantAdd, SimpleConstantAddFixture)
                 );
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
