@@ -1,17 +1,13 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <string>
-#include <iostream>
-
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
 
+TEST_SUITE("TensorflowLiteParser_Softmax")
+{
 struct SoftmaxFixture : public ParserFlatbuffersFixture
 {
     explicit SoftmaxFixture()
@@ -69,9 +65,9 @@ struct SoftmaxFixture : public ParserFlatbuffersFixture
     }
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseSoftmaxLite, SoftmaxFixture)
+TEST_CASE_FIXTURE(SoftmaxFixture, "ParseSoftmaxLite")
 {
     RunTest<2, armnn::DataType::QAsymmU8>(0, { 0, 0, 100, 0, 0, 0, 0 }, { 0, 0, 255, 0, 0, 0, 0 });
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
