@@ -1,17 +1,13 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <string>
-#include <iostream>
-
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
 
+TEST_SUITE("TensorflowLiteParser_Split")
+{
 struct SplitFixture : public ParserFlatbuffersFixture
 {
     explicit SplitFixture(const std::string& inputShape,
@@ -108,7 +104,7 @@ struct SimpleSplitFixtureFloat32 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseAxisOneSplitTwoFloat32, SimpleSplitFixtureFloat32)
+TEST_CASE_FIXTURE(SimpleSplitFixtureFloat32, "ParseAxisOneSplitTwoFloat32")
 {
 
     RunTest<4, armnn::DataType::Float32>(
@@ -126,7 +122,7 @@ struct SimpleSplitAxisThreeFixtureFloat32 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseAxisThreeSplitTwoFloat32, SimpleSplitAxisThreeFixtureFloat32)
+TEST_CASE_FIXTURE(SimpleSplitAxisThreeFixtureFloat32, "ParseAxisThreeSplitTwoFloat32")
 {
     RunTest<4, armnn::DataType::Float32>(
         0,
@@ -143,7 +139,7 @@ struct SimpleSplit2DFixtureFloat32 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(SimpleSplit2DFloat32, SimpleSplit2DFixtureFloat32)
+TEST_CASE_FIXTURE(SimpleSplit2DFixtureFloat32, "SimpleSplit2DFloat32")
 {
     RunTest<2, armnn::DataType::Float32>(
         0,
@@ -159,7 +155,7 @@ struct SimpleSplit3DFixtureFloat32 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(SimpleSplit3DFloat32, SimpleSplit3DFixtureFloat32)
+TEST_CASE_FIXTURE(SimpleSplit3DFixtureFloat32, "SimpleSplit3DFloat32")
 {
     RunTest<3, armnn::DataType::Float32>(
         0,
@@ -176,7 +172,7 @@ struct SimpleSplitFixtureUint8 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseAxisOneSplitTwoUint8, SimpleSplitFixtureUint8)
+TEST_CASE_FIXTURE(SimpleSplitFixtureUint8, "ParseAxisOneSplitTwoUint8")
 {
 
     RunTest<4, armnn::DataType::QAsymmU8>(
@@ -194,7 +190,7 @@ struct SimpleSplitAxisThreeFixtureUint8 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(ParseAxisThreeSplitTwoUint8, SimpleSplitAxisThreeFixtureUint8)
+TEST_CASE_FIXTURE(SimpleSplitAxisThreeFixtureUint8, "ParseAxisThreeSplitTwoUint8")
 {
     RunTest<4, armnn::DataType::QAsymmU8>(
         0,
@@ -211,7 +207,7 @@ struct SimpleSplit2DFixtureUint8 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(SimpleSplit2DUint8, SimpleSplit2DFixtureUint8)
+TEST_CASE_FIXTURE(SimpleSplit2DFixtureUint8, "SimpleSplit2DUint8")
 {
     RunTest<2, armnn::DataType::QAsymmU8>(
             0,
@@ -227,7 +223,7 @@ struct SimpleSplit3DFixtureUint8 : SplitFixture
         {}
 };
 
-BOOST_FIXTURE_TEST_CASE(SimpleSplit3DUint8, SimpleSplit3DFixtureUint8)
+TEST_CASE_FIXTURE(SimpleSplit3DFixtureUint8, "SimpleSplit3DUint8")
 {
     RunTest<3, armnn::DataType::QAsymmU8>(
         0,
@@ -237,4 +233,4 @@ BOOST_FIXTURE_TEST_CASE(SimpleSplit3DUint8, SimpleSplit3DFixtureUint8)
           {"outputTensor2", { 9, 10, 11, 12, 13, 14, 15, 16 } } } );
 }
 
-BOOST_AUTO_TEST_SUITE_END()
\ No newline at end of file
+}
\ No newline at end of file
