@@ -1,16 +1,13 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include <boost/test/unit_test.hpp>
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <string>
-
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
 
+TEST_SUITE("TensorflowLiteParser_StridedSlice")
+{
 struct StridedSliceFixture : public ParserFlatbuffersFixture
 {
     explicit StridedSliceFixture(const std::string & inputShape,
@@ -115,7 +112,7 @@ struct StridedSlice4DFixture : StridedSliceFixture
                                                  ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(StridedSlice4D, StridedSlice4DFixture)
+TEST_CASE_FIXTURE(StridedSlice4DFixture, "StridedSlice4D")
 {
   RunTest<4, armnn::DataType::Float32>(
       0,
@@ -147,7 +144,7 @@ struct StridedSlice4DReverseFixture : StridedSliceFixture
                                                         ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(StridedSlice4DReverse, StridedSlice4DReverseFixture)
+TEST_CASE_FIXTURE(StridedSlice4DReverseFixture, "StridedSlice4DReverse")
 {
   RunTest<4, armnn::DataType::Float32>(
       0,
@@ -170,7 +167,7 @@ struct StridedSliceSimpleStrideFixture : StridedSliceFixture
                                                  ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(StridedSliceSimpleStride, StridedSliceSimpleStrideFixture)
+TEST_CASE_FIXTURE(StridedSliceSimpleStrideFixture, "StridedSliceSimpleStride")
 {
   RunTest<4, armnn::DataType::Float32>(
       0,
@@ -197,7 +194,7 @@ struct StridedSliceSimpleRangeMaskFixture : StridedSliceFixture
                                                  ) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(StridedSliceSimpleRangeMask, StridedSliceSimpleRangeMaskFixture)
+TEST_CASE_FIXTURE(StridedSliceSimpleRangeMaskFixture, "StridedSliceSimpleRangeMask")
 {
   RunTest<4, armnn::DataType::Float32>(
       0,
@@ -214,4 +211,4 @@ BOOST_FIXTURE_TEST_CASE(StridedSliceSimpleRangeMask, StridedSliceSimpleRangeMask
                           5.0f, 5.0f, 5.0f, 6.0f, 6.0f, 6.0f }}});
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
