@@ -1,66 +1,73 @@
 //
-// Copyright © 2019 Arm Ltd. All rights reserved.
+// Copyright © 2019 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "ParserFlatbuffersFixture.hpp"
-#include "../TfLiteParser.hpp"
 
-#include <armnn/LayerVisitorBase.hpp>
+#include <armnn/StrategyBase.hpp>
 #include <armnn/utility/Assert.hpp>
+#include <armnn/utility/NumericCast.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
 
 #include <layers/StandInLayer.hpp>
 
-#include <boost/test/unit_test.hpp>
-
 #include <sstream>
-#include <string>
 #include <vector>
 
-BOOST_AUTO_TEST_SUITE(TensorflowLiteParser)
-
+TEST_SUITE("TensorflowLiteParser_Unsupported")
+{
 using namespace armnn;
 
-class StandInLayerVerifier : public LayerVisitorBase<VisitorThrowingPolicy>
+class StandInLayerVerifier : public StrategyBase<NoThrowStrategy>
 {
 public:
     StandInLayerVerifier(const std::vector<TensorInfo>& inputInfos,
                          const std::vector<TensorInfo>& outputInfos)
-        : LayerVisitorBase<VisitorThrowingPolicy>()
-        , m_InputInfos(inputInfos)
+        : m_InputInfos(inputInfos)
         , m_OutputInfos(outputInfos) {}
 
-    void VisitInputLayer(const IConnectableLayer*, LayerBindingId, const char*) override {}
-
-    void VisitOutputLayer(const IConnectableLayer*, LayerBindingId, const char*) override {}
-
-    void VisitStandInLayer(const IConnectableLayer* layer,
-                           const StandInDescriptor& descriptor,
-                           const char*) override
+    void ExecuteStrategy(const armnn::IConnectableLayer* layer,
+                         const armnn::BaseDescriptor& descriptor,
+                         const std::vector<armnn::ConstTensor>& constants,
+                         const char* name,
+                         const armnn::LayerBindingId id = 0) override
     {
-        unsigned int numInputs = boost::numeric_cast<unsigned int>(m_InputInfos.size());
-        BOOST_CHECK(descriptor.m_NumInputs    == numInputs);
-        BOOST_CHECK(layer->GetNumInputSlots() == numInputs);
-
-        unsigned int numOutputs = boost::numeric_cast<unsigned int>(m_OutputInfos.size());
-        BOOST_CHECK(descriptor.m_NumOutputs    == numOutputs);
-        BOOST_CHECK(layer->GetNumOutputSlots() == numOutputs);
-
-        const StandInLayer* standInLayer = PolymorphicDowncast<const StandInLayer*>(layer);
-        for (unsigned int i = 0u; i < numInputs; ++i)
+        armnn::IgnoreUnused(descriptor, constants, id);
+        switch (layer->GetType())
         {
-            const OutputSlot* connectedSlot = standInLayer->GetInputSlot(i).GetConnectedOutputSlot();
-            BOOST_CHECK(connectedSlot != nullptr);
+            case armnn::LayerType::StandIn:
+            {
+                auto standInDescriptor = static_cast<const armnn::StandInDescriptor&>(descriptor);
+                unsigned int numInputs = armnn::numeric_cast<unsigned int>(m_InputInfos.size());
+                        CHECK(standInDescriptor.m_NumInputs    == numInputs);
+                        CHECK(layer->GetNumInputSlots() == numInputs);
 
-            const TensorInfo& inputInfo = connectedSlot->GetTensorInfo();
-            BOOST_CHECK(inputInfo == m_InputInfos[i]);
-        }
+                unsigned int numOutputs = armnn::numeric_cast<unsigned int>(m_OutputInfos.size());
+                        CHECK(standInDescriptor.m_NumOutputs    == numOutputs);
+                        CHECK(layer->GetNumOutputSlots() == numOutputs);
 
-        for (unsigned int i = 0u; i < numOutputs; ++i)
-        {
-            const TensorInfo& outputInfo = layer->GetOutputSlot(i).GetTensorInfo();
-            BOOST_CHECK(outputInfo == m_OutputInfos[i]);
+                const StandInLayer* standInLayer = PolymorphicDowncast<const StandInLayer*>(layer);
+                for (unsigned int i = 0u; i < numInputs; ++i)
+                {
+                    const OutputSlot* connectedSlot = standInLayer->GetInputSlot(i).GetConnectedOutputSlot();
+                            CHECK(connectedSlot != nullptr);
+
+                    const TensorInfo& inputInfo = connectedSlot->GetTensorInfo();
+                            CHECK(inputInfo == m_InputInfos[i]);
+                }
+
+                for (unsigned int i = 0u; i < numOutputs; ++i)
+                {
+                    const TensorInfo& outputInfo = layer->GetOutputSlot(i).GetTensorInfo();
+                            CHECK(outputInfo == m_OutputInfos[i]);
+                }
+                break;
+            }
+            default:
+            {
+                m_DefaultStrategy.Apply(GetLayerTypeAsCString(layer->GetType()));
+            }
         }
     }
 
@@ -77,10 +84,10 @@ public:
         : ParserFlatbuffersFixture()
         , m_StandInLayerVerifier(inputInfos, outputInfos)
     {
-        const unsigned int numInputs = boost::numeric_cast<unsigned int>(inputInfos.size());
+        const unsigned int numInputs = armnn::numeric_cast<unsigned int>(inputInfos.size());
         ARMNN_ASSERT(numInputs > 0);
 
-        const unsigned int numOutputs = boost::numeric_cast<unsigned int>(outputInfos.size());
+        const unsigned int numOutputs = armnn::numeric_cast<unsigned int>(outputInfos.size());
         ARMNN_ASSERT(numOutputs > 0);
 
         m_JsonString = R"(
@@ -167,7 +174,7 @@ public:
     void RunTest()
     {
         INetworkPtr network = m_Parser->CreateNetworkFromBinary(m_GraphBinary);
-        network->Accept(m_StandInLayerVerifier);
+        network->ExecuteStrategy(m_StandInLayerVerifier);
     }
 
 private:
@@ -236,14 +243,14 @@ public:
                              { TensorInfo({ 3, 3 }, DataType::Float32) }) {}
 };
 
-BOOST_FIXTURE_TEST_CASE(UnsupportedCustomOperator1Input1Output, DummyCustom1Input1OutputFixture)
+TEST_CASE_FIXTURE(DummyCustom1Input1OutputFixture, "UnsupportedCustomOperator1Input1Output")
 {
     RunTest();
 }
 
-BOOST_FIXTURE_TEST_CASE(UnsupportedCustomOperator2Inputs1Output, DummyCustom2Inputs1OutputFixture)
+TEST_CASE_FIXTURE(DummyCustom2Inputs1OutputFixture, "UnsupportedCustomOperator2Inputs1Output")
 {
     RunTest();
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
