@@ -5,11 +5,17 @@
 
 #pragma once
 
-// Set style to round to nearest
-#define HALF_ROUND_STYLE 1
-
 #include <type_traits>
-#include <half/half.hpp>
+
+// Set style to round to nearest
+#ifndef HALF_ROUND_STYLE
+    #define HALF_ROUND_STYLE 1
+#endif
+#ifndef HALF_ROUND_TIES_TO_EVEN
+    #define HALF_ROUND_TIES_TO_EVEN 1
+#endif
+
+#include "half/half.hpp"
 
 namespace armnn
 {
@@ -35,4 +41,4 @@ struct is_floating_point<volatile armnn::Half>
     : integral_constant< bool, true >
 {};
 
-} //namespace std
\ No newline at end of file
+} //namespace std
