@@ -4,10 +4,10 @@
 //
 #pragma once
 
-#include <test/CreateWorkload.hpp>
-
+#include <CreateWorkload.hpp>
+#include <armnnTestUtils/PredicateResult.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
-#include <backendsCommon/MemCopyWorkload.hpp>
+#include <armnn/backends/MemCopyWorkload.hpp>
 #include <reference/RefWorkloadFactory.hpp>
 #include <reference/RefTensorHandle.hpp>
 
@@ -19,6 +19,8 @@
 #include <neon/NeonTensorHandle.hpp>
 #endif
 
+#include <doctest/doctest.h>
+
 using namespace armnn;
 
 namespace
@@ -27,8 +29,8 @@ namespace
 using namespace std;
 
 template<typename IComputeTensorHandle>
-boost::test_tools::predicate_result CompareTensorHandleShape(IComputeTensorHandle*               tensorHandle,
-                                                             std::initializer_list<unsigned int> expectedDimensions)
+PredicateResult CompareTensorHandleShape(IComputeTensorHandle* tensorHandle,
+                                         std::initializer_list<unsigned int> expectedDimensions)
 {
     arm_compute::ITensorInfo* info = tensorHandle->GetTensor().info();
 
@@ -36,8 +38,8 @@ boost::test_tools::predicate_result CompareTensorHandleShape(IComputeTensorHandl
     auto numExpectedDims = expectedDimensions.size();
     if (infoNumDims != numExpectedDims)
     {
-        boost::test_tools::predicate_result res(false);
-        res.message() << "Different number of dimensions [" << info->num_dimensions()
+        PredicateResult res(false);
+        res.Message() << "Different number of dimensions [" << info->num_dimensions()
                       << "!=" << expectedDimensions.size() << "]";
         return res;
     }
@@ -48,8 +50,8 @@ boost::test_tools::predicate_result CompareTensorHandleShape(IComputeTensorHandl
     {
         if (info->dimension(i) != expectedDimension)
         {
-            boost::test_tools::predicate_result res(false);
-            res.message() << "For dimension " << i <<
+            PredicateResult res(false);
+            res.Message() << "For dimension " << i <<
                              " expected size " << expectedDimension <<
                              " got " << info->dimension(i);
             return res;
@@ -58,7 +60,7 @@ boost::test_tools::predicate_result CompareTensorHandleShape(IComputeTensorHandl
         i--;
     }
 
-    return true;
+    return PredicateResult(true);
 }
 
 template<typename IComputeTensorHandle>
@@ -92,21 +94,23 @@ void CreateMemCopyWorkloads(IWorkloadFactory& factory)
     auto workload2 = MakeAndCheckWorkload<CopyMemGenericWorkload>(*layer2, refFactory);
 
     MemCopyQueueDescriptor queueDescriptor1 = workload1->GetData();
-    BOOST_TEST(queueDescriptor1.m_Inputs.size() == 1);
-    BOOST_TEST(queueDescriptor1.m_Outputs.size() == 1);
+    CHECK(queueDescriptor1.m_Inputs.size() == 1);
+    CHECK(queueDescriptor1.m_Outputs.size() == 1);
     auto inputHandle1  = PolymorphicDowncast<RefTensorHandle*>(queueDescriptor1.m_Inputs[0]);
     auto outputHandle1 = PolymorphicDowncast<IComputeTensorHandle*>(queueDescriptor1.m_Outputs[0]);
-    BOOST_TEST((inputHandle1->GetTensorInfo() == TensorInfo({2, 3}, DataType::Float32)));
-    BOOST_TEST(CompareTensorHandleShape<IComputeTensorHandle>(outputHandle1, {2, 3}));
+    CHECK((inputHandle1->GetTensorInfo() == TensorInfo({2, 3}, DataType::Float32)));
+    auto result = CompareTensorHandleShape<IComputeTensorHandle>(outputHandle1, {2, 3});
+    CHECK_MESSAGE(result.m_Result, result.m_Message.str());
 
 
     MemCopyQueueDescriptor queueDescriptor2 = workload2->GetData();
-    BOOST_TEST(queueDescriptor2.m_Inputs.size() == 1);
-    BOOST_TEST(queueDescriptor2.m_Outputs.size() == 1);
+    CHECK(queueDescriptor2.m_Inputs.size() == 1);
+    CHECK(queueDescriptor2.m_Outputs.size() == 1);
     auto inputHandle2  = PolymorphicDowncast<IComputeTensorHandle*>(queueDescriptor2.m_Inputs[0]);
     auto outputHandle2 = PolymorphicDowncast<RefTensorHandle*>(queueDescriptor2.m_Outputs[0]);
-    BOOST_TEST(CompareTensorHandleShape<IComputeTensorHandle>(inputHandle2, {2, 3}));
-    BOOST_TEST((outputHandle2->GetTensorInfo() == TensorInfo({2, 3}, DataType::Float32)));
+    result = CompareTensorHandleShape<IComputeTensorHandle>(inputHandle2, {2, 3});
+    CHECK_MESSAGE(result.m_Result, result.m_Message.str());
+    CHECK((outputHandle2->GetTensorInfo() == TensorInfo({2, 3}, DataType::Float32)));
 }
 
 } //namespace
