@@ -49,6 +49,32 @@ ITensorHandleFactory* TensorHandleFactoryRegistry::GetFactory(ITensorHandleFacto
     return nullptr;
 }
 
+ITensorHandleFactory* TensorHandleFactoryRegistry::GetFactory(ITensorHandleFactory::FactoryId id,
+                                                              MemorySource memSource) const
+{
+    for (auto& factory : m_Factories)
+    {
+        if (factory->GetId() == id && factory->GetImportFlags() == static_cast<MemorySourceFlags>(memSource))
+        {
+            return factory.get();
+        }
+    }
+
+    return nullptr;
+}
+
+void TensorHandleFactoryRegistry::RegisterCopyAndImportFactoryPair(ITensorHandleFactory::FactoryId copyFactoryId,
+                                                                   ITensorHandleFactory::FactoryId importFactoryId)
+{
+    m_FactoryMappings[copyFactoryId] = importFactoryId;
+}
+
+ITensorHandleFactory::FactoryId TensorHandleFactoryRegistry::GetMatchingImportFactoryId(
+    ITensorHandleFactory::FactoryId copyFactoryId)
+{
+    return m_FactoryMappings[copyFactoryId];
+}
+
 void TensorHandleFactoryRegistry::AquireMemory()
 {
     for (auto& mgr : m_MemoryManagers)
