@@ -4,17 +4,12 @@
 //
 #pragma once
 
-#include "QuantizeHelper.hpp"
-
-
 #include <armnnUtils/Permute.hpp>
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 #include <ResolveType.hpp>
 
-#include <backendsCommon/test/CommonTestUtils.hpp>
-
-#include <boost/test/unit_test.hpp>
+#include <CommonTestUtils.hpp>
 
 #include <map>
 #include <vector>
@@ -59,7 +54,7 @@ void ResizeEndToEnd(const std::vector<armnn::BackendId>& backends,
     const float   qScale  = IsQuantizedType<T>() ? 0.25f : 1.0f;
     const int32_t qOffset = IsQuantizedType<T>() ? 50    : 0;
 
-    TensorInfo inputInfo(inputShape, ArmnnType, qScale, qOffset);
+    TensorInfo inputInfo(inputShape, ArmnnType, qScale, qOffset, true);
     TensorInfo outputInfo(outputShape, ArmnnType, qScale, qOffset);
 
     std::vector<float> inputData =
