@@ -5,20 +5,21 @@
 
 #include "BatchNormalizationTestImpl.hpp"
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 #include <ResolveType.hpp>
 
 #include <armnn/utility/IgnoreUnused.hpp>
 #include <armnnUtils/DataLayoutIndexed.hpp>
 
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/backends/TensorHandle.hpp>
 #include <armnn/backends/IBackendInternal.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
+#include <reference/test/RefWorkloadFactoryHelper.hpp>
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
 namespace
 {
@@ -29,6 +30,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> BatchNormTestImpl(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::TensorShape& inputOutputTensorShape,
     const std::vector<float>& inputValues,
     const std::vector<float>& expectedOutputValues,
@@ -56,28 +58,24 @@ LayerTestResult<T, 4> BatchNormTestImpl(
         tensorInfo.SetQuantizationOffset(qOffset);
     }
 
-    auto inputTensor = MakeTensor<T, 4>(inputTensorInfo, QuantizedVector<T>(inputValues, qScale, qOffset));
+    auto inputTensor = QuantizedVector<T>(inputValues, qScale, qOffset);
 
     // These values are per-channel of the input.
-    auto mean     = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 3, -2 }, qScale, qOffset));
-    auto variance = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 4,  9 }, qScale, qOffset));
-    auto beta     = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 3,  2 }, qScale, qOffset));
-    auto gamma    = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 2,  1 }, qScale, qOffset));
+    auto mean     = QuantizedVector<T>({ 3, -2 }, qScale, qOffset);
+    auto variance = QuantizedVector<T>({ 4,  9 }, qScale, qOffset);
+    auto beta     = QuantizedVector<T>({ 3,  2 }, qScale, qOffset);
+    auto gamma    = QuantizedVector<T>({ 2,  1 }, qScale, qOffset);
 
-    LayerTestResult<T, 4> result(outputTensorInfo);
+    std::vector<T> actualOutput(outputTensorInfo.GetNumElements());
+    std::vector<T> expectedOutput = QuantizedVector<T>(expectedOutputValues, qScale, qOffset);
 
-    result.outputExpected = MakeTensor<T, 4>(inputTensorInfo,
-                                             QuantizedVector<T>(expectedOutputValues, qScale, qOffset));
+    std::unique_ptr<armnn::ITensorHandle> inputHandle = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
-
-    armnn::ScopedCpuTensorHandle meanTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle varianceTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle betaTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle gammaTensor(tensorInfo);
+    armnn::ScopedTensorHandle meanTensor(tensorInfo);
+    armnn::ScopedTensorHandle varianceTensor(tensorInfo);
+    armnn::ScopedTensorHandle betaTensor(tensorInfo);
+    armnn::ScopedTensorHandle gammaTensor(tensorInfo);
 
     armnn::BatchNormalizationQueueDescriptor descriptor;
     descriptor.m_Mean                    = &meanTensor;
@@ -88,32 +86,37 @@ LayerTestResult<T, 4> BatchNormTestImpl(
     descriptor.m_Parameters.m_DataLayout = dataLayout;
     armnn::WorkloadInfo info;
 
-    AllocateAndCopyDataToITensorHandle(&meanTensor, &mean[0]);
-    AllocateAndCopyDataToITensorHandle(&varianceTensor, &variance[0]);
-    AllocateAndCopyDataToITensorHandle(&betaTensor, &beta[0]);
-    AllocateAndCopyDataToITensorHandle(&gammaTensor, &gamma[0]);
+    AllocateAndCopyDataToITensorHandle(&meanTensor, mean.data());
+    AllocateAndCopyDataToITensorHandle(&varianceTensor, variance.data());
+    AllocateAndCopyDataToITensorHandle(&betaTensor, beta.data());
+    AllocateAndCopyDataToITensorHandle(&gammaTensor, gamma.data());
 
     AddInputToWorkload(descriptor, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(descriptor, info, outputTensorInfo, outputHandle.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateBatchNormalization(descriptor, info);
+    std::unique_ptr<armnn::IWorkload> workload
+            = workloadFactory.CreateWorkload(armnn::LayerType::BatchNormalization, descriptor, info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &inputTensor[0][0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), inputTensor.data());
 
     workload->Execute();
 
-    CopyDataFromITensorHandle(&result.output[0][0][0][0], outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return result;
+    return LayerTestResult<T, 4>(actualOutput,
+                                 expectedOutput,
+                                 outputHandle->GetShape(),
+                                 outputTensorInfo.GetShape());
 }
 
 template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T,4> BatchNormTestNhwcImpl(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     float qScale,
     int32_t qOffset)
 {
@@ -139,32 +142,29 @@ LayerTestResult<T,4> BatchNormTestNhwcImpl(
         tensorInfo.SetQuantizationOffset(qOffset);
     }
 
-    auto input = MakeTensor<T, 4>(inputTensorInfo,
-        QuantizedVector<T>(
+    auto input = QuantizedVector<T>(
         {
             1.f, 1.f, 4.f, 1.f,
             4.f, 4.f, 2.f, 1.f,
             1.f, -2.f, 6.f, 4.f
         },
-        qScale, qOffset));
-    // These values are per-channel of the input.
-    auto mean     = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 3, -2 }, qScale, qOffset));
-    auto variance = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 4,  9 }, qScale, qOffset));
-    auto beta     = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 3,  2 }, qScale, qOffset));
-    auto gamma    = MakeTensor<T, 1>(tensorInfo, QuantizedVector<T>({ 2,  1 }, qScale, qOffset));
-    LayerTestResult<T,4> ret(outputTensorInfo);
+        qScale, qOffset);
 
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+    // These values are per-channel of the input.
+    auto mean     = QuantizedVector<T>({ 3, -2 }, qScale, qOffset);
+    auto variance = QuantizedVector<T>({ 4,  9 }, qScale, qOffset);
+    auto beta     = QuantizedVector<T>({ 3,  2 }, qScale, qOffset);
+    auto gamma    = QuantizedVector<T>({ 2,  1 }, qScale, qOffset);
+
+    std::unique_ptr<armnn::ITensorHandle> inputHandle = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
     armnn::BatchNormalizationQueueDescriptor data;
     armnn::WorkloadInfo info;
-    armnn::ScopedCpuTensorHandle meanTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle varianceTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle betaTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle gammaTensor(tensorInfo);
+    armnn::ScopedTensorHandle meanTensor(tensorInfo);
+    armnn::ScopedTensorHandle varianceTensor(tensorInfo);
+    armnn::ScopedTensorHandle betaTensor(tensorInfo);
+    armnn::ScopedTensorHandle gammaTensor(tensorInfo);
 
     AllocateAndCopyDataToITensorHandle(&meanTensor, &mean[0]);
     AllocateAndCopyDataToITensorHandle(&varianceTensor, &variance[0]);
@@ -180,37 +180,43 @@ LayerTestResult<T,4> BatchNormTestNhwcImpl(
     data.m_Parameters.m_Eps = 0.0f;
     data.m_Parameters.m_DataLayout = armnn::DataLayout::NHWC;
 
+    std::vector<T> actualOutput(outputTensorInfo.GetNumElements());
+
     // For each channel:
     // substract mean, divide by standard deviation (with an epsilon to avoid div by 0),
     // multiply by gamma and add beta
-    ret.outputExpected = MakeTensor<T, 4>(outputTensorInfo,
-        QuantizedVector<T>(
+    std::vector<T> expectedOutput = QuantizedVector<T>(
         {
             1.f, 3.f, 4.f, 3.f,
             4.f, 4.f, 2.f, 3.f,
             1.f, 2.f, 6.f, 4.f
         },
-        qScale, qOffset));
+        qScale, qOffset);
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateBatchNormalization(data, info);
+    std::unique_ptr<armnn::IWorkload> workload
+            = workloadFactory.CreateWorkload(armnn::LayerType::BatchNormalization, data, info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), input.data());
 
     workload->Execute();
 
-    CopyDataFromITensorHandle(&ret.output[0][0][0][0], outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return ret;
+    return LayerTestResult<T, 4>(actualOutput,
+                                 expectedOutput,
+                                 outputHandle->GetShape(),
+                                 outputTensorInfo.GetShape());
 }
 
 } // anonymous namespace
 
 LayerTestResult<float, 4> BatchNormFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Channels: 2
@@ -246,6 +252,7 @@ LayerTestResult<float, 4> BatchNormFloat32Test(
     return BatchNormTestImpl<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -256,7 +263,8 @@ LayerTestResult<float, 4> BatchNormFloat32Test(
 
 LayerTestResult<float, 4> BatchNormFloat32NhwcTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Height: 3
@@ -296,6 +304,7 @@ LayerTestResult<float, 4> BatchNormFloat32NhwcTest(
     return BatchNormTestImpl<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -306,7 +315,8 @@ LayerTestResult<float, 4> BatchNormFloat32NhwcTest(
 
 LayerTestResult<armnn::Half, 4> BatchNormFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Channels: 2
@@ -342,6 +352,7 @@ LayerTestResult<armnn::Half, 4> BatchNormFloat16Test(
     return BatchNormTestImpl<armnn::DataType::Float16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -352,7 +363,8 @@ LayerTestResult<armnn::Half, 4> BatchNormFloat16Test(
 
 LayerTestResult<armnn::Half, 4> BatchNormFloat16NhwcTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Height: 3
@@ -392,6 +404,7 @@ LayerTestResult<armnn::Half, 4> BatchNormFloat16NhwcTest(
     return BatchNormTestImpl<armnn::DataType::Float16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -402,7 +415,8 @@ LayerTestResult<armnn::Half, 4> BatchNormFloat16NhwcTest(
 
 LayerTestResult<uint8_t, 4> BatchNormUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Channels: 2
@@ -438,6 +452,7 @@ LayerTestResult<uint8_t, 4> BatchNormUint8Test(
     return BatchNormTestImpl<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -448,7 +463,8 @@ LayerTestResult<uint8_t, 4> BatchNormUint8Test(
 
 LayerTestResult<uint8_t, 4> BatchNormUint8NhwcTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Height: 3
@@ -488,13 +504,15 @@ LayerTestResult<uint8_t, 4> BatchNormUint8NhwcTest(
     return BatchNormTestImpl<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape, inputValues, expectedOutputValues,
          1.f/20.f, 50, armnn::DataLayout::NHWC);
 }
 
 LayerTestResult<int16_t, 4> BatchNormInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Channels: 2
@@ -530,6 +548,7 @@ LayerTestResult<int16_t, 4> BatchNormInt16Test(
     return BatchNormTestImpl<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -540,7 +559,8 @@ LayerTestResult<int16_t, 4> BatchNormInt16Test(
 
 LayerTestResult<int16_t, 4> BatchNormInt16NhwcTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     // BatchSize: 1
     // Height: 3
@@ -580,6 +600,7 @@ LayerTestResult<int16_t, 4> BatchNormInt16NhwcTest(
     return BatchNormTestImpl<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         inputValues,
         expectedOutputValues,
@@ -591,7 +612,9 @@ LayerTestResult<int16_t, 4> BatchNormInt16NhwcTest(
 LayerTestResult<float,4> CompareBatchNormTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-    armnn::IWorkloadFactory& refWorkloadFactory)
+    armnn::IWorkloadFactory& refWorkloadFactory,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
+    const armnn::ITensorHandleFactory& refTensorHandleFactory)
 {
     IgnoreUnused(memoryManager);
     const unsigned int width     = 2;
@@ -610,29 +633,28 @@ LayerTestResult<float,4> CompareBatchNormTest(
     outputTensorInfo = armnn::TensorInfo(4, shape, armnn::DataType::Float32);
     tensorInfo = armnn::TensorInfo(1, tensorShape, armnn::DataType::Float32);
 
-    auto input = MakeRandomTensor<float, 4>(inputTensorInfo, 21312);
+    auto input = MakeRandomTensor<float>(inputTensorInfo, 21312);
 
-    auto mean     = MakeRandomTensor<float, 1>(tensorInfo, 123);
-    auto variance = MakeRandomTensor<float, 1>(tensorInfo, 234, 0.0f);
-    auto beta     = MakeRandomTensor<float, 1>(tensorInfo, 123);
-    auto gamma    = MakeRandomTensor<float, 1>(tensorInfo, 345);
+    auto mean     = MakeRandomTensor<float>(tensorInfo, 123);
+    auto variance = MakeRandomTensor<float>(tensorInfo, 234, 0.0f);
+    auto beta     = MakeRandomTensor<float>(tensorInfo, 123);
+    auto gamma    = MakeRandomTensor<float>(tensorInfo, 345);
 
-    LayerTestResult<float,4> ret(outputTensorInfo);
+    std::vector<float> actualOutput(outputTensorInfo.GetNumElements());
+    std::vector<float> expectedOutput(outputTensorInfo.GetNumElements());
 
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle  = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> inputHandle  = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
-    std::unique_ptr<armnn::ITensorHandle> inputHandleRef  = refWorkloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandleRef = refWorkloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+    std::unique_ptr<armnn::ITensorHandle> inputHandleRef  = refTensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandleRef = refTensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
     armnn::BatchNormalizationQueueDescriptor data;
     armnn::WorkloadInfo info;
-    armnn::ScopedCpuTensorHandle meanTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle varianceTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle betaTensor(tensorInfo);
-    armnn::ScopedCpuTensorHandle gammaTensor(tensorInfo);
+    armnn::ScopedTensorHandle meanTensor(tensorInfo);
+    armnn::ScopedTensorHandle varianceTensor(tensorInfo);
+    armnn::ScopedTensorHandle betaTensor(tensorInfo);
+    armnn::ScopedTensorHandle gammaTensor(tensorInfo);
 
     AllocateAndCopyDataToITensorHandle(&meanTensor, &mean[0]);
     AllocateAndCopyDataToITensorHandle(&varianceTensor, &variance[0]);
@@ -652,24 +674,29 @@ LayerTestResult<float,4> CompareBatchNormTest(
     SetWorkloadInput(refData, refInfo, 0, inputTensorInfo, inputHandleRef.get());
     SetWorkloadOutput(refData, refInfo, 0, outputTensorInfo, outputHandleRef.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateBatchNormalization(data, info);
-    std::unique_ptr<armnn::IWorkload> workloadRef = refWorkloadFactory.CreateBatchNormalization(refData, refInfo);
+    std::unique_ptr<armnn::IWorkload> workload
+            = workloadFactory.CreateWorkload(armnn::LayerType::BatchNormalization, data, info);
+    std::unique_ptr<armnn::IWorkload> workloadRef
+            = refWorkloadFactory.CreateWorkload(armnn::LayerType::BatchNormalization, refData, refInfo);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
     inputHandleRef->Allocate();
     outputHandleRef->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0][0]);
-    CopyDataToITensorHandle(inputHandleRef.get(), &input[0][0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), input.data());
+    CopyDataToITensorHandle(inputHandleRef.get(), input.data());
 
     workload->PostAllocationConfigure();
     workload->Execute();
     workloadRef->PostAllocationConfigure();
     workloadRef->Execute();
 
-    CopyDataFromITensorHandle(&ret.output[0][0][0][0], outputHandle.get());
-    CopyDataFromITensorHandle(&ret.outputExpected[0][0][0][0], outputHandleRef.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
+    CopyDataFromITensorHandle(expectedOutput.data(), outputHandleRef.get());
 
-    return ret;
+    return LayerTestResult<float, 4>(actualOutput,
+                                     expectedOutput,
+                                     outputHandle->GetShape(),
+                                     outputTensorInfo.GetShape());
 }
