@@ -1,18 +1,21 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017,2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "DebugTestImpl.hpp"
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
+#include <armnnUtils/Filesystem.hpp>
 #include <ResolveType.hpp>
 
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <doctest/doctest.h>
+#include <armnnUtils/Filesystem.hpp>
 
 namespace
 {
@@ -27,6 +30,8 @@ LayerTestResult<T, Dim> DebugTestImpl(
     std::vector<float>& outputExpectedData,
     armnn::DebugQueueDescriptor descriptor,
     const std::string expectedStringOutput,
+    const std::string& layerName,
+    bool toFile,
     const float qScale = 1.0f,
     const int32_t qOffset = 0)
 {
@@ -40,12 +45,10 @@ LayerTestResult<T, Dim> DebugTestImpl(
         outputTensorInfo.SetQuantizationOffset(qOffset);
     }
 
-    boost::multi_array<T, Dim> input =
-        MakeTensor<T, Dim>(inputTensorInfo, armnnUtils::QuantizedVector<T>(inputData, qScale, qOffset));
+    std::vector<T> input = armnnUtils::QuantizedVector<T>(inputData, qScale, qOffset);
 
-    LayerTestResult<T, Dim> ret(outputTensorInfo);
-    ret.outputExpected =
-        MakeTensor<T, Dim>(outputTensorInfo, armnnUtils::QuantizedVector<T>(outputExpectedData, qScale, qOffset));
+    std::vector<T> actualOutput(outputTensorInfo.GetNumElements());
+    std::vector<T> expectedOutput = armnnUtils::QuantizedVector<T>(outputExpectedData, qScale, qOffset);
 
     ARMNN_NO_DEPRECATE_WARN_BEGIN
     std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
@@ -56,32 +59,55 @@ LayerTestResult<T, Dim> DebugTestImpl(
     AddInputToWorkload(descriptor, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(descriptor, info, outputTensorInfo, outputHandle.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateDebug(descriptor, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::Debug,
+                                                                                descriptor,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
     CopyDataToITensorHandle(inputHandle.get(), input.data());
 
-    std::ostringstream oss;
-    std::streambuf* coutStreambuf = std::cout.rdbuf();
-    std::cout.rdbuf(oss.rdbuf());
+    if (toFile)
+    {
+        // Given that this is dependent on an ExNet switch, we need to explicitly set the directory that the
+        //  files are stored in as this happens within the ExNet flow
+        auto tmpDir = armnnUtils::Filesystem::CreateDirectory("/ArmNNIntermediateLayerOutputs");
+        std::string full_path = tmpDir + layerName + ".numpy";
 
-    ExecuteWorkload(*workload, memoryManager);
+        ExecuteWorkload(*workload, memoryManager);
 
-    std::cout.rdbuf(coutStreambuf);
+        armnnUtils::Filesystem::FileContents output = armnnUtils::Filesystem::ReadFileContentsIntoString(full_path);
+        CHECK((output == expectedStringOutput));
 
-    BOOST_TEST(oss.str() == expectedStringOutput);
+        // Clean up afterwards.
+        armnnUtils::Filesystem::RemoveDirectoryAndContents(tmpDir);
+    }
+    else
+    {
+        std::ostringstream oss;
+        std::streambuf* coutStreambuf = std::cout.rdbuf();
+        std::cout.rdbuf(oss.rdbuf());
 
-    CopyDataFromITensorHandle(ret.output.data(), outputHandle.get());
+        ExecuteWorkload(*workload, memoryManager);
 
-    return ret;
+        std::cout.rdbuf(coutStreambuf);
+        CHECK(oss.str() == expectedStringOutput);
+    }
+
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
+
+    return LayerTestResult<T, Dim>(actualOutput,
+                                   expectedOutput,
+                                   outputHandle->GetShape(),
+                                   outputTensorInfo.GetShape());
 }
 
 template <armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> Debug4dTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -93,6 +119,7 @@ LayerTestResult<T, 4> Debug4dTest(
     desc.m_Guid = 1;
     desc.m_LayerName = "TestOutput";
     desc.m_SlotIndex = 0;
+    desc.m_LayerOutputToFile = toFile;
 
     inputTensorInfo = armnn::TensorInfo(4, inputShape, ArmnnType);
     outputTensorInfo = armnn::TensorInfo(4, outputShape, ArmnnType);
@@ -128,13 +155,16 @@ LayerTestResult<T, 4> Debug4dTest(
                                input,
                                outputExpected,
                                desc,
-                               expectedStringOutput);
+                               expectedStringOutput,
+                               desc.m_LayerName,
+                               toFile);
 }
 
 template <armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 3> Debug3dTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -146,6 +176,7 @@ LayerTestResult<T, 3> Debug3dTest(
     desc.m_Guid = 1;
     desc.m_LayerName = "TestOutput";
     desc.m_SlotIndex = 0;
+    desc.m_LayerOutputToFile = toFile;
 
     inputTensorInfo = armnn::TensorInfo(3, inputShape, ArmnnType);
     outputTensorInfo = armnn::TensorInfo(3, outputShape, ArmnnType);
@@ -179,13 +210,16 @@ LayerTestResult<T, 3> Debug3dTest(
                                input,
                                outputExpected,
                                desc,
-                               expectedStringOutput);
+                               expectedStringOutput,
+                               desc.m_LayerName,
+                               toFile);
 }
 
 template <armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 2> Debug2dTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -197,6 +231,7 @@ LayerTestResult<T, 2> Debug2dTest(
     desc.m_Guid = 1;
     desc.m_LayerName = "TestOutput";
     desc.m_SlotIndex = 0;
+    desc.m_LayerOutputToFile = toFile;
 
     inputTensorInfo = armnn::TensorInfo(2, inputShape, ArmnnType);
     outputTensorInfo = armnn::TensorInfo(2, outputShape, ArmnnType);
@@ -228,13 +263,16 @@ LayerTestResult<T, 2> Debug2dTest(
                                input,
                                outputExpected,
                                desc,
-                               expectedStringOutput);
+                               expectedStringOutput,
+                               desc.m_LayerName,
+                               toFile);
 }
 
 template <armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 1> Debug1dTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -246,6 +284,7 @@ LayerTestResult<T, 1> Debug1dTest(
     desc.m_Guid = 1;
     desc.m_LayerName = "TestOutput";
     desc.m_SlotIndex = 0;
+    desc.m_LayerOutputToFile = toFile;
 
     inputTensorInfo = armnn::TensorInfo(1, inputShape, ArmnnType);
     outputTensorInfo = armnn::TensorInfo(1, outputShape, ArmnnType);
@@ -275,119 +314,137 @@ LayerTestResult<T, 1> Debug1dTest(
                                input,
                                outputExpected,
                                desc,
-                               expectedStringOutput);
+                               expectedStringOutput,
+                               desc.m_LayerName,
+                               toFile);
 }
 
 } // anonymous namespace
 
 LayerTestResult<float, 4> Debug4dFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug4dTest<armnn::DataType::Float32>(workloadFactory, memoryManager);
+    return Debug4dTest<armnn::DataType::Float32>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<float, 3> Debug3dFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug3dTest<armnn::DataType::Float32>(workloadFactory, memoryManager);
+    return Debug3dTest<armnn::DataType::Float32>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<float, 2> Debug2dFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug2dTest<armnn::DataType::Float32>(workloadFactory, memoryManager);
+    return Debug2dTest<armnn::DataType::Float32>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<float, 1> Debug1dFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug1dTest<armnn::DataType::Float32>(workloadFactory, memoryManager);
+    return Debug1dTest<armnn::DataType::Float32>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<armnn::BFloat16, 4> Debug4dBFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug4dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager);
+    return Debug4dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<armnn::BFloat16, 3> Debug3dBFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug3dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager);
+    return Debug3dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<armnn::BFloat16, 2> Debug2dBFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug2dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager);
+    return Debug2dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<armnn::BFloat16, 1> Debug1dBFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug1dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager);
+    return Debug1dTest<armnn::DataType::BFloat16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<uint8_t, 4> Debug4dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug4dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager);
+    return Debug4dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<uint8_t, 3> Debug3dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug3dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager);
+    return Debug3dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<uint8_t, 2> Debug2dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug2dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager);
+    return Debug2dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<uint8_t, 1> Debug1dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug1dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager);
+    return Debug1dTest<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<int16_t, 4> Debug4dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug4dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager);
+    return Debug4dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<int16_t, 3> Debug3dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug3dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager);
+    return Debug3dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<int16_t, 2> Debug2dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug2dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager);
+    return Debug2dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, toFile);
 }
 
 LayerTestResult<int16_t, 1> Debug1dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    bool toFile = false)
 {
-    return Debug1dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager);
+    return Debug1dTest<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, toFile);
 }
