@@ -8,10 +8,10 @@
 #include <ResolveType.hpp>
 
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
 namespace
 {
@@ -27,10 +27,8 @@ LayerTestResult<T1, Dim> DequantizeTestImpl(
         armnn::DequantizeQueueDescriptor descriptor)
 {
     IgnoreUnused(memoryManager);
-    boost::multi_array<T, Dim> input = MakeTensor<T, Dim>(inputTensorInfo, inputData);
 
-    LayerTestResult<T1, Dim> ret(outputTensorInfo);
-    ret.outputExpected = MakeTensor<T1, Dim>(outputTensorInfo, expectedOutputData);
+    std::vector<T1> actualOutput(outputTensorInfo.GetNumElements());
 
     ARMNN_NO_DEPRECATE_WARN_BEGIN
     std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
@@ -41,18 +39,23 @@ LayerTestResult<T1, Dim> DequantizeTestImpl(
     AddInputToWorkload(descriptor, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(descriptor, info, outputTensorInfo, outputHandle.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateDequantize(descriptor, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::Dequantize,
+                                                                                descriptor,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), input.data());
+    CopyDataToITensorHandle(inputHandle.get(), inputData.data());
 
     ExecuteWorkload(*workload, memoryManager);
 
-    CopyDataFromITensorHandle(ret.output.data(), outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return ret;
+    return LayerTestResult<T1, Dim>(actualOutput,
+                                    expectedOutputData,
+                                    outputHandle->GetShape(),
+                                    outputTensorInfo.GetShape());
 }
 
 template <armnn::DataType ArmnnInputType,
