@@ -1,20 +1,20 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017,2022-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "FullyConnectedTestImpl.hpp"
 
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/backends/TensorHandle.hpp>
 
-#include <backendsCommon/test/DataTypeUtils.hpp>
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <DataTypeUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
 //
 // Implementation templates
@@ -22,49 +22,64 @@
 
 template<typename T, typename B>
 LayerTestResult<T, 2> SimpleFullyConnectedTestImpl(
-        armnn::IWorkloadFactory& workloadFactory,
-        const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-        armnn::TensorInfo inputTensorInfo,
-        armnn::TensorInfo outputTensorInfo,
-        armnn::TensorInfo weightsDesc,
-        armnn::TensorInfo biasesDesc,
-        boost::multi_array<T, 2>& weights,
-        boost::multi_array<B, 1>& bias,
-        boost::multi_array<T, 4>& input,
-        bool biasEnabled,
-        bool transposeWeights)
+    armnn::IWorkloadFactory& workloadFactory,
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
+    armnn::TensorInfo inputTensorInfo,
+    armnn::TensorInfo outputTensorInfo,
+    armnn::TensorInfo weightsTensorInfo,
+    armnn::TensorInfo biasesTensorInfo,
+    std::vector<T>& weights,
+    std::vector<B>& bias,
+    std::vector<T>& input,
+    bool biasEnabled,
+    bool transposeWeights,
+    bool constantWeights)
 {
-    IgnoreUnused(memoryManager);
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+    std::unique_ptr<armnn::ITensorHandle> input0Handle = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> input1Handle = tensorHandleFactory.CreateTensorHandle(weightsTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
+
+    std::vector<T> actualOutput(outputTensorInfo.GetNumElements());
 
     armnn::FullyConnectedQueueDescriptor data;
     armnn::WorkloadInfo info;
-    armnn::ScopedCpuTensorHandle weightsTensor(weightsDesc);
-    armnn::ScopedCpuTensorHandle biasTensor(biasesDesc);
 
-    AllocateAndCopyDataToITensorHandle(&weightsTensor, &weights[0][0]);
-    AllocateAndCopyDataToITensorHandle(&biasTensor, &bias[0]);
-
-    AddInputToWorkload(data, info, inputTensorInfo, inputHandle.get());
+    AddInputToWorkload(data, info, inputTensorInfo, input0Handle.get());
+    AddInputToWorkload(data, info, weightsTensorInfo, input1Handle.get());
     AddOutputToWorkload(data, info, outputTensorInfo, outputHandle.get());
-    data.m_Weight = &weightsTensor;
-    data.m_Bias = &biasTensor;
+
     data.m_Parameters.m_BiasEnabled = biasEnabled;
     data.m_Parameters.m_TransposeWeightMatrix = transposeWeights;
+    data.m_Parameters.m_ConstantWeights = constantWeights;
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateFullyConnected(data, info);
+    std::unique_ptr<armnn::ITensorHandle> input2Handle = nullptr;
+    if (biasEnabled)
+    {
+        input2Handle = tensorHandleFactory.CreateTensorHandle(biasesTensorInfo);
+        AddInputToWorkload(data, info, biasesTensorInfo, input2Handle.get());
+    }
+
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::FullyConnected,
+                                                                                data,
+                                                                                info);
     LayerTestResult<T, 2> result(outputTensorInfo);
 
-    inputHandle->Allocate();
+    input0Handle->Allocate();
+    input1Handle->Allocate();
     outputHandle->Allocate();
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0][0]);
+    CopyDataToITensorHandle(input0Handle.get(), input.data());
+    CopyDataToITensorHandle(input1Handle.get(), weights.data());
+    if (biasEnabled)
+    {
+        input2Handle->Allocate();
+        CopyDataToITensorHandle(input2Handle.get(), bias.data());
+    }
 
     ExecuteWorkload(*workload, memoryManager);
 
-    CopyDataFromITensorHandle(&result.output[0][0], outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
+    result.m_ActualData = actualOutput;
 
     return result;
 }
@@ -73,7 +88,9 @@ template<armnn::DataType ArmnnType, typename T>
 LayerTestResult<T, 2> FullyConnectedTest(
         armnn::IWorkloadFactory& workloadFactory,
         const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-        bool biasEnabled)
+        const armnn::ITensorHandleFactory& tensorHandleFactory,
+        bool biasEnabled,
+        bool constantWeights)
 {
     constexpr static unsigned int inputWidth = 3u;
     constexpr static unsigned int inputHeight = 2u;
@@ -94,47 +111,52 @@ LayerTestResult<T, 2> FullyConnectedTest(
     armnn::TensorInfo weightsDesc({ outputChannels, inputSize }, ArmnnType);
     weightsDesc.SetQuantizationScale(0.2f);
     weightsDesc.SetQuantizationOffset(93);
+    weightsDesc.SetConstant(constantWeights);
 
     armnn::TensorInfo biasesDesc({ outputChannels }, GetBiasTypeFromWeightsType(weightsDesc.GetDataType()).value());
     biasesDesc.SetQuantizationScale(inputTensorInfo.GetQuantizationScale() * weightsDesc.GetQuantizationScale());
     biasesDesc.SetQuantizationOffset(0);
+    biasesDesc.SetConstant(true);
 
     LayerTestResult<T, 2> result(outputTensorInfo);
 
-    auto input = MakeTensor<T, 4>(inputTensorInfo, ConvertToDataType<ArmnnType>(
+    std::vector<T> input = ConvertToDataType<ArmnnType>(
         {
             -1.2f, 6.1f, -3.5f,
             18.8f, -5.5f, 2.9f
         },
-        inputTensorInfo));
+        inputTensorInfo);
 
-    auto weights = MakeTensor<T, 2>(weightsDesc, ConvertToDataType<ArmnnType>(
+    std::vector<T> weights = ConvertToDataType<ArmnnType>(
         {
             -8.4f, 20.0f, -10.4f, -8, 16.4f, -11.8f,
             23.4f, 10.4f, -14.0f, -3.8f, -11.8f, 11.4f
         },
-        weightsDesc));
+        weightsDesc);
 
-    auto bias = MakeTensor<int32_t, 1>(biasesDesc, std::vector<int32_t>{9250, 67500});
+    std::vector<int32_t> bias = {9250, 67500};
 
-    result = SimpleFullyConnectedTestImpl<T>(
-            workloadFactory,
-            memoryManager,
-            inputTensorInfo, outputTensorInfo,
-            weightsDesc, biasesDesc,
-            weights, bias, input,
-            biasEnabled, true
-    );
+    result = SimpleFullyConnectedTestImpl<T>(workloadFactory,
+                                             memoryManager,
+                                             tensorHandleFactory,
+                                             inputTensorInfo,
+                                             outputTensorInfo,
+                                             weightsDesc,
+                                             biasesDesc,
+                                             weights,
+                                             bias,
+                                             input,
+                                             biasEnabled,
+                                             true,
+                                             constantWeights);
 
     if (biasEnabled)
     {
-        result.outputExpected = MakeTensor<T, 2>(outputTensorInfo,
-                                                 ConvertToDataType<ArmnnType>({80.f, 1460.f}, outputTensorInfo));
+        result.m_ExpectedData = ConvertToDataType<ArmnnType>({80.f, 1460.f}, outputTensorInfo);
     }
     else
     {
-        result.outputExpected = MakeTensor<T, 2>(outputTensorInfo,
-                                                 ConvertToDataType<ArmnnType>({-107.04f, 110.f}, outputTensorInfo));
+        result.m_ExpectedData = ConvertToDataType<ArmnnType>({-107.04f, 110.f}, outputTensorInfo);
     }
 
     return result;
@@ -150,8 +172,9 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 2> FullyConnectedLargeTestCommon(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     bool transposeWeights,
-    float qScale = 0.0f,
+    float qScale = 1.0f,
     int32_t qOffset = 0)
 {
     unsigned int inputWidth = 1;
@@ -162,6 +185,9 @@ LayerTestResult<T, 2> FullyConnectedLargeTestCommon(
     unsigned int outputChannels = 1;
     unsigned int outputNum = 1;
 
+    bool isBiasEnabled = true;
+    bool isConstantWeights = true;
+
     // Define the tensor descriptors.
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -182,6 +208,8 @@ LayerTestResult<T, 2> FullyConnectedLargeTestCommon(
     outputTensorInfo = armnn::TensorInfo(2, outputShape, ArmnnType);
     weightsDesc = armnn::TensorInfo(2, weightsShape, ArmnnType);
     biasesDesc = armnn::TensorInfo(1, biasShape, ArmnnType);
+    weightsDesc.SetConstant(isConstantWeights);
+    biasesDesc.SetConstant(true);
 
     // Set quantization parameters if the requested type is a quantized type.
     if(armnn::IsQuantizedType<T>())
@@ -194,34 +222,31 @@ LayerTestResult<T, 2> FullyConnectedLargeTestCommon(
 
     LayerTestResult<T, 2> result(outputTensorInfo);
 
-    boost::multi_array<T, 4> input = MakeTensor<T, 4>(inputTensorInfo,
-        armnnUtils::QuantizedVector<T>({
+    std::vector<T> input = armnnUtils::QuantizedVector<T>(
+        {
             1.0f, 10.0f, 100.0f, 1000.0f, 10000.0f,
         },
-        qScale, qOffset)
-    );
+        qScale, qOffset);
 
-    boost::multi_array<T, 2> weights = MakeTensor<T, 2>(weightsDesc,
-        armnnUtils::QuantizedVector<T>({
+    std::vector<T> weights = armnnUtils::QuantizedVector<T>(
+        {
             2.0f, 3.0f, 4.0f, 5.0f, 6.0f
         },
-        qScale, qOffset)
-    );
+        qScale, qOffset);
 
     std::vector<T> biasValues({900000.f});
-    boost::multi_array<T, 1> bias = MakeTensor<T, 1>(biasesDesc, biasValues);
 
     result = SimpleFullyConnectedTestImpl<T>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputTensorInfo, outputTensorInfo,
         weightsDesc, biasesDesc,
-        weights, bias, input,
-        true, transposeWeights
+        weights, biasValues, input,
+        isBiasEnabled, transposeWeights, isConstantWeights
     );
 
-    result.outputExpected = MakeTensor<T, 2>(outputTensorInfo,
-                                             armnnUtils::QuantizedVector<T>({ 965432.0f }, qScale, qOffset));
+    result.m_ExpectedData = armnnUtils::QuantizedVector<T>({ 965432.0f }, qScale, qOffset);
 
     return result;
 }
@@ -234,13 +259,17 @@ template LayerTestResult<armnn::ResolveType<armnn::DataType::QAsymmU8>, 2>
 FullyConnectedTest<armnn::DataType::QAsymmU8>(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-    bool biasEnabled);
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
+    bool biasEnabled,
+    bool constWeights);
 
 template LayerTestResult<armnn::ResolveType<armnn::DataType::QSymmS16>, 2>
 FullyConnectedTest<armnn::DataType::QSymmS16>(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-    bool biasEnabled);
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
+    bool biasEnabled,
+    bool constWeights);
 
 //
 // Implementation functions
@@ -249,6 +278,7 @@ FullyConnectedTest<armnn::DataType::QSymmS16>(
 LayerTestResult<float, 2> FullyConnectedFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     bool biasEnabled,
     bool transposeWeights)
 {
@@ -260,6 +290,8 @@ LayerTestResult<float, 2> FullyConnectedFloat32Test(
     unsigned int outputChannels = 3;
     unsigned int outputNum = 2;
 
+    bool isConstantWeights = true;
+
     // Define the tensor descriptors.
     armnn::TensorInfo inputTensorInfo;
     armnn::TensorInfo outputTensorInfo;
@@ -281,64 +313,63 @@ LayerTestResult<float, 2> FullyConnectedFloat32Test(
     outputTensorInfo = armnn::TensorInfo(2, outputShape, armnn::DataType::Float32);
     weightsDesc = armnn::TensorInfo(2, weightsShape, armnn::DataType::Float32);
     biasesDesc = armnn::TensorInfo(1, biasShape, armnn::DataType::Float32);
+    weightsDesc.SetConstant(isConstantWeights);
+    biasesDesc.SetConstant(true);
 
     LayerTestResult<float, 2> result(outputTensorInfo);
 
-    boost::multi_array<float, 4> input = MakeTensor<float, 4>(inputTensorInfo, std::vector<float>(
-        {
-            1.0f, 2.0f, 3.0f, 4.0f, 5.0f,
+    std::vector<float> input =
+    {
+        1.0f, 2.0f, 3.0f, 4.0f, 5.0f,
+        5.0f, 4.0f, 3.0f, 2.0f, 1.0f
+    };
 
-            5.0f, 4.0f, 3.0f, 2.0f, 1.0f
-        })
-    );
-
-    boost::multi_array<float, 2> weights = MakeTensor<float, 2>(weightsDesc, std::vector<float>(
-        {
-            .5f, 2.f, .5f,
-            .5f, 2.f, 1.f,
-            .5f, 2.f, 2.f,
-            .5f, 2.f, 3.f,
-            .5f, 2.f, 4.f
-        }));
+    std::vector<float> weights =
+    {
+        .5f, 2.f, .5f,
+        .5f, 2.f, 1.f,
+        .5f, 2.f, 2.f,
+        .5f, 2.f, 3.f,
+        .5f, 2.f, 4.f
+    };
 
     if (transposeWeights)
     {
-        weights = MakeTensor<float, 2>(weightsDesc, std::vector<float>(
+        weights =
         {
             .5f, .5f, .5f, .5f, .5f,
             2.f, 2.f, 2.f, 2.f, 2.f,
             .5f, 1.f, 2.f, 3.f, 4.f
-        }));
+        };
     }
 
-
     std::vector<float> biasValues({0.f, 0.f, 0.f});
     if (biasEnabled)
     {
-        biasValues =  std::vector<float>({10.f, 20.f, 30.f});
+        biasValues = std::vector<float>({10.f, 20.f, 30.f});
     }
-    boost::multi_array<float, 1> bias = MakeTensor<float, 1>(biasesDesc, biasValues);
 
     result = SimpleFullyConnectedTestImpl<float>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputTensorInfo, outputTensorInfo,
         weightsDesc, biasesDesc,
-        weights, bias, input,
-        biasEnabled, transposeWeights
+        weights, biasValues, input,
+        biasEnabled, transposeWeights, isConstantWeights
     );
 
-    result.outputExpected = MakeTensor<float, 2>(outputTensorInfo, std::vector<float>(
-        {
-            0.5f + 1.0f + 1.5f + 2.0f + 2.5f + biasValues[0],
-            2.0f + 4.0f + 6.0f + 8.0f + 10.f + biasValues[1],
-            0.5f + 2.0f + 6.0f + 12.f + 20.f + biasValues[2],
+    std::vector<float> expectedOutput =
+    {
+        0.5f + 1.0f + 1.5f + 2.0f + 2.5f + biasValues[0],
+        2.0f + 4.0f + 6.0f + 8.0f + 10.f + biasValues[1],
+        0.5f + 2.0f + 6.0f + 12.f + 20.f + biasValues[2],
 
-            2.5f + 2.0f + 1.5f + 1.0f + 0.5f + biasValues[0],
-            10.0f + 8.0f + 6.0f + 4.0f + 2.f + biasValues[1],
-            2.5f + 4.0f + 6.0f + 6.f + 4.f   + biasValues[2]
-        })
-    );
+        2.5f + 2.0f + 1.5f + 1.0f + 0.5f + biasValues[0],
+        10.0f + 8.0f + 6.0f + 4.0f + 2.f + biasValues[1],
+        2.5f + 4.0f + 6.0f + 6.f + 4.f   + biasValues[2]
+    };
+    result.m_ExpectedData = expectedOutput;
 
     return result;
 }
@@ -346,7 +377,11 @@ LayerTestResult<float, 2> FullyConnectedFloat32Test(
 LayerTestResult<float, 2> FullyConnectedLargeTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     bool transposeWeights)
 {
-    return FullyConnectedLargeTestCommon<armnn::DataType::Float32>(workloadFactory, memoryManager, transposeWeights);
+    return FullyConnectedLargeTestCommon<armnn::DataType::Float32>(workloadFactory,
+                                                                   memoryManager,
+                                                                   tensorHandleFactory,
+                                                                   transposeWeights);
 }
