@@ -5,16 +5,18 @@
 
 #include "L2NormalizationTestImpl.hpp"
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 #include <ResolveType.hpp>
 
 #include <armnnUtils/TensorUtils.hpp>
 #include <armnnUtils/Permute.hpp>
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
+
+#include <numeric>
 
 namespace
 {
@@ -23,13 +25,14 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2NormalizationTestImpl(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::TensorShape& inputOutputTensorShape,
     float scale,
     int32_t offset,
     const std::vector<float>& inputValues,
     float outScale,
     int32_t outOffset,
-    const std::vector<float>& expectedOutputValues,
+    std::vector<float>& expectedOutputValues,
     const armnn::DataLayout layout,
     float epsilon = 1e-12f)
 {
@@ -47,31 +50,26 @@ LayerTestResult<T, 4> L2NormalizationTestImpl(
         inputData = tmp;
     }
 
-    auto inputTensor = MakeTensor<T, 4>(inputTensorInfo,
-                                        armnnUtils::QuantizedVector<T>(inputData,
-                                                                       inputTensorInfo.GetQuantizationScale(),
-                                                                       inputTensorInfo.GetQuantizationOffset()));
+    auto inputTensor = armnnUtils::QuantizedVector<T>(inputData,
+                                                      inputTensorInfo.GetQuantizationScale(),
+                                                      inputTensorInfo.GetQuantizationOffset());
+
+    std::vector<T> actualOutput(outputTensorInfo.GetNumElements());
 
-    std::vector<float> expectedOutputData = expectedOutputValues;
     if (layout == armnn::DataLayout::NHWC)
     {
-        std::vector<float> tmp(expectedOutputData.size());
-        armnnUtils::Permute(inputTensorInfo.GetShape(), NCHWToNHWC, expectedOutputData.data(), tmp.data(),
+        std::vector<float> tmp(expectedOutputValues.size());
+        armnnUtils::Permute(inputTensorInfo.GetShape(), NCHWToNHWC, expectedOutputValues.data(), tmp.data(),
                             sizeof(float));
-        expectedOutputData = tmp;
+        expectedOutputValues = tmp;
     }
 
-    LayerTestResult<T, 4> result(outputTensorInfo);
-    result.outputExpected =
-        MakeTensor<T, 4>(outputTensorInfo,
-                         armnnUtils::QuantizedVector<T>(expectedOutputData,
-                                                        outputTensorInfo.GetQuantizationScale(),
-                                                        outputTensorInfo.GetQuantizationOffset()));
+    std::vector<T> expectedOutputData = armnnUtils::QuantizedVector<T>(expectedOutputValues,
+                                                                       outputTensorInfo.GetQuantizationScale(),
+                                                                       outputTensorInfo.GetQuantizationOffset());
 
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+    std::unique_ptr<armnn::ITensorHandle> inputHandle = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
     armnn::L2NormalizationQueueDescriptor descriptor;
     descriptor.m_Parameters.m_Eps = epsilon;
@@ -81,19 +79,24 @@ LayerTestResult<T, 4> L2NormalizationTestImpl(
     AddInputToWorkload(descriptor, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(descriptor, info, outputTensorInfo, outputHandle.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateL2Normalization(descriptor, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::L2Normalization,
+                                                                                descriptor,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &inputTensor[0][0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), inputTensor.data());
 
     workload->PostAllocationConfigure();
     ExecuteWorkload(*workload, memoryManager);
 
-    CopyDataFromITensorHandle(&result.output[0][0][0][0], outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return result;
+    return LayerTestResult<T, 4>(actualOutput,
+                                 expectedOutputData,
+                                 outputHandle->GetShape(),
+                                 outputTensorInfo.GetShape());
 }
 
 float CalcInvL2Norm(std::initializer_list<float> elements)
@@ -107,6 +110,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2NormalizationEpsilonTestCommon(
         armnn::IWorkloadFactory& workloadFactory,
         const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+        const armnn::ITensorHandleFactory& tensorHandleFactory,
         float scale,
         int32_t offset,
         float outScale,
@@ -151,6 +155,7 @@ LayerTestResult<T, 4> L2NormalizationEpsilonTestCommon(
     return L2NormalizationTestImpl<ArmnnType>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         scale,
         offset,
@@ -167,6 +172,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2Normalization1dTestCommon(
         armnn::IWorkloadFactory& workloadFactory,
         const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+        const armnn::ITensorHandleFactory& tensorHandleFactory,
         float scale,
         int32_t offset,
         float outScale,
@@ -237,6 +243,7 @@ LayerTestResult<T, 4> L2Normalization1dTestCommon(
     return L2NormalizationTestImpl<ArmnnType>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         scale,
         offset,
@@ -251,6 +258,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2Normalization2dTestCommon(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     float scale,
     int32_t offset,
     float outScale,
@@ -296,6 +304,7 @@ LayerTestResult<T, 4> L2Normalization2dTestCommon(
     return L2NormalizationTestImpl<ArmnnType>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         scale,
         offset,
@@ -310,6 +319,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2Normalization3dTestCommon(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     float scale,
     int32_t offset,
     float outScale,
@@ -375,6 +385,7 @@ LayerTestResult<T, 4> L2Normalization3dTestCommon(
     return L2NormalizationTestImpl<ArmnnType>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         scale,
         offset,
@@ -389,6 +400,7 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 4> L2Normalization4dTestCommon(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     float scale,
     int32_t offset,
     float outScale,
@@ -534,6 +546,7 @@ LayerTestResult<T, 4> L2Normalization4dTestCommon(
     return L2NormalizationTestImpl<ArmnnType>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         inputOutputShape,
         scale,
         offset,
@@ -549,6 +562,7 @@ LayerTestResult<T, 4> L2Normalization4dTestCommon(
 LayerTestResult<float, 4> L2NormalizationDefaultEpsilonTest(
         armnn::IWorkloadFactory& workloadFactory,
         const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+        const armnn::ITensorHandleFactory& tensorHandleFactory,
         const armnn::DataLayout layout)
 {
     // Dummy descriptor to get the default value of epsilon.
@@ -557,6 +571,7 @@ LayerTestResult<float, 4> L2NormalizationDefaultEpsilonTest(
     return L2NormalizationEpsilonTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -568,11 +583,13 @@ LayerTestResult<float, 4> L2NormalizationDefaultEpsilonTest(
 LayerTestResult<float, 4> L2NormalizationNonDefaultEpsilonTest(
         armnn::IWorkloadFactory& workloadFactory,
         const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+        const armnn::ITensorHandleFactory& tensorHandleFactory,
         const armnn::DataLayout layout)
 {
     return L2NormalizationEpsilonTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -584,11 +601,13 @@ LayerTestResult<float, 4> L2NormalizationNonDefaultEpsilonTest(
 LayerTestResult<float, 4> L2Normalization1dTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -599,11 +618,13 @@ LayerTestResult<float, 4> L2Normalization1dTest(
 LayerTestResult<int16_t, 4> L2Normalization1dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f,
@@ -614,11 +635,13 @@ LayerTestResult<int16_t, 4> L2Normalization1dInt16Test(
 LayerTestResult<uint8_t, 4> L2Normalization1dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f / 128,
@@ -629,11 +652,13 @@ LayerTestResult<uint8_t, 4> L2Normalization1dUint8Test(
 LayerTestResult<float, 4> L2Normalization2dTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization2dTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -644,11 +669,13 @@ LayerTestResult<float, 4> L2Normalization2dTest(
 LayerTestResult<int16_t, 4> L2Normalization2dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f,
@@ -659,11 +686,13 @@ LayerTestResult<int16_t, 4> L2Normalization2dInt16Test(
 LayerTestResult<uint8_t, 4> L2Normalization2dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f / 128,
@@ -673,7 +702,8 @@ LayerTestResult<uint8_t, 4> L2Normalization2dUint8Test(
 
 LayerTestResult<float, 2> L2Normalization2dShapeTest(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
     const armnn::DataLayout layout = armnn::DataLayout::NHWC;
     const armnn::TensorShape inputOutputTensorShape = armnn::TensorShape({ 5, 2 });
@@ -699,15 +729,10 @@ LayerTestResult<float, 2> L2Normalization2dShapeTest(
     const armnn::TensorInfo inputTensorInfo(inputOutputTensorShape, armnn::DataType::Float32, 0.f, 0);
     const armnn::TensorInfo outputTensorInfo(inputOutputTensorShape, armnn::DataType::Float32, 0.f, 0);
 
-    auto inputTensor = MakeTensor<float, 2>(inputTensorInfo, inputData);
+    std::vector<float> actualOutput(outputTensorInfo.GetNumElements());
 
-    LayerTestResult<float, 2> result(outputTensorInfo);
-    result.outputExpected = MakeTensor<float, 2>(outputTensorInfo, expectedOutputData);
-
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
-    std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+    std::unique_ptr<armnn::ITensorHandle> inputHandle = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
+    std::unique_ptr<armnn::ITensorHandle> outputHandle = tensorHandleFactory.CreateTensorHandle(outputTensorInfo);
 
     armnn::L2NormalizationQueueDescriptor descriptor;
     descriptor.m_Parameters.m_Eps = 1e-12f;
@@ -717,29 +742,36 @@ LayerTestResult<float, 2> L2Normalization2dShapeTest(
     AddInputToWorkload(descriptor, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(descriptor, info, outputTensorInfo, outputHandle.get());
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateL2Normalization(descriptor, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::L2Normalization,
+                                                                                descriptor,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &inputTensor[0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), inputData.data());
 
     workload->PostAllocationConfigure();
     ExecuteWorkload(*workload, memoryManager);
 
-    CopyDataFromITensorHandle(&result.output[0][0], outputHandle.get());
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return result;
+    return LayerTestResult<float, 2>(actualOutput,
+                                     expectedOutputData,
+                                     outputHandle->GetShape(),
+                                     outputTensorInfo.GetShape());
 }
 
 LayerTestResult<float, 4> L2Normalization3dTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization3dTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -750,11 +782,13 @@ LayerTestResult<float, 4> L2Normalization3dTest(
 LayerTestResult<int16_t, 4> L2Normalization3dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f,
@@ -765,11 +799,13 @@ LayerTestResult<int16_t, 4> L2Normalization3dInt16Test(
 LayerTestResult<uint8_t, 4> L2Normalization3dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f / 128,
@@ -780,11 +816,13 @@ LayerTestResult<uint8_t, 4> L2Normalization3dUint8Test(
 LayerTestResult<float, 4> L2Normalization4dTest(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization4dTestCommon<armnn::DataType::Float32>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         0.f,
         0,
         0.f,
@@ -795,11 +833,13 @@ LayerTestResult<float, 4> L2Normalization4dTest(
 LayerTestResult<int16_t, 4> L2Normalization4dInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QSymmS16>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f,
@@ -810,11 +850,13 @@ LayerTestResult<int16_t, 4> L2Normalization4dInt16Test(
 LayerTestResult<uint8_t, 4> L2Normalization4dUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     const armnn::DataLayout layout)
 {
     return L2Normalization1dTestCommon<armnn::DataType::QAsymmU8>(
         workloadFactory,
         memoryManager,
+        tensorHandleFactory,
         1.f,
         0,
         1.f / 128,
