@@ -1,18 +1,18 @@
 //
-// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2017, 2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "SplitterTestImpl.hpp"
 
-#include <QuantizeHelper.hpp>
+#include <armnnUtils/QuantizeHelper.hpp>
 #include <ResolveType.hpp>
 
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
 namespace
 {
@@ -21,7 +21,8 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 std::vector<LayerTestResult<T,3>> SplitterTestCommon(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
-    float qScale = 0.0f,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
+    float qScale = 1.0f,
     int32_t qOffset = 0)
 {
     IgnoreUnused(memoryManager);
@@ -46,7 +47,6 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
     unsigned int outputHeight2 = inputHeight;
     unsigned int outputChannels2 = 2;
 
-
     // Define the tensor descriptors.
     armnn::TensorInfo inputTensorInfo({ inputChannels, inputHeight, inputWidth }, ArmnnType, qScale, qOffset);
 
@@ -74,13 +74,8 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
         outputTensorInfo4.SetQuantizationOffset(qOffset);
     }
 
-    LayerTestResult<T,3> ret1(outputTensorInfo1);
-    LayerTestResult<T,3> ret2(outputTensorInfo2);
-    LayerTestResult<T,3> ret3(outputTensorInfo3);
-    LayerTestResult<T,3> ret4(outputTensorInfo4);
-
-    auto input = MakeTensor<T, 3>(inputTensorInfo, std::vector<T>(
-        armnnUtils::QuantizedVector<T>({
+    auto input = armnnUtils::QuantizedVector<T>(
+        {
             1.0f, 2.0f, 3.0f, 4.0f, 5.0f,
             6.0f, 7.0f, 8.0f, 9.0f, 10.0f,
             11.0f, 12.0f, 13.0f, 14.0f, 15.0f,
@@ -102,12 +97,11 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
             81.0f, 82.0f, 83.0f, 84.0f, 85.0f,
             86.0f, 87.0f, 88.0f, 89.0f, 90.0f,
         },
-        qScale, qOffset)
-    ));
+        qScale, qOffset);
 
     // Channel 0 of the original input.
-    ret1.outputExpected = MakeTensor<T, 3>(outputTensorInfo1, std::vector<T>(
-        armnnUtils::QuantizedVector<T>({
+    auto expectedData1 = armnnUtils::QuantizedVector<T>(
+        {
             1.0f, 2.0f, 3.0f, 4.0f, 5.0f,
             6.0f, 7.0f, 8.0f, 9.0f, 10.0f,
             11.0f, 12.0f, 13.0f, 14.0f, 15.0f,
@@ -115,12 +109,11 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
             21.0f, 22.0f, 23.0f, 24.0f, 25.0f,
             26.0f, 27.0f, 28.0f, 29.0f, 30.0f,
         },
-        qScale, qOffset)
-    ));
+        qScale, qOffset);
 
     // Channel 1 & 2 of the original input.
-    ret2.outputExpected = MakeTensor<T, 3>(outputTensorInfo2, std::vector<T>(
-        armnnUtils::QuantizedVector<T>({
+    auto expectedData2 = armnnUtils::QuantizedVector<T>(
+        {
             31.0f, 32.0f, 33.0f, 34.0f, 35.0f,
             36.0f, 37.0f, 38.0f, 39.0f, 40.0f,
             41.0f, 42.0f, 43.0f, 44.0f, 45.0f,
@@ -135,12 +128,11 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
             81.0f, 82.0f, 83.0f, 84.0f, 85.0f,
             86.0f, 87.0f, 88.0f, 89.0f, 90.0f,
         },
-        qScale, qOffset)
-    ));
+        qScale, qOffset);
 
     // Channel 0 of return 2 (i.e. channels 1 and 2 of the original input).
-    ret3.outputExpected = MakeTensor<T, 3>(outputTensorInfo3, std::vector<T>(
-        armnnUtils::QuantizedVector<T>({
+    auto expectedData3 = armnnUtils::QuantizedVector<T>(
+        {
             31.0f, 32.0f, 33.0f, 34.0f, 35.0f,
             36.0f, 37.0f, 38.0f, 39.0f, 40.0f,
             41.0f, 42.0f, 43.0f, 44.0f, 45.0f,
@@ -148,12 +140,11 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
             51.0f, 52.0f, 53.0f, 54.0f, 55.0f,
             56.0f, 57.0f, 58.0f, 59.0f, 60.0f,
         },
-        qScale, qOffset)
-    ));
+        qScale, qOffset);
 
     // Channel 1 of return 2.
-    ret4.outputExpected = MakeTensor<T, 3>(outputTensorInfo4, std::vector<T>(
-        armnnUtils::QuantizedVector<T>({
+    auto expectedData4 = armnnUtils::QuantizedVector<T>(
+        {
             61.0f, 62.0f, 63.0f, 64.0f, 65.0f,
             66.0f, 67.0f, 68.0f, 69.0f, 70.0f,
             71.0f, 72.0f, 73.0f, 74.0f, 75.0f,
@@ -161,8 +152,12 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
             81.0f, 82.0f, 83.0f, 84.0f, 85.0f,
             86.0f, 87.0f, 88.0f, 89.0f, 90.0f,
         },
-        qScale, qOffset)
-    ));
+        qScale, qOffset);
+
+    std::vector<T> actualData1(outputTensorInfo1.GetNumElements());
+    std::vector<T> actualData2(outputTensorInfo2.GetNumElements());
+    std::vector<T> actualData3(outputTensorInfo3.GetNumElements());
+    std::vector<T> actualData4(outputTensorInfo4.GetNumElements());
 
     // NOTE: as a corollary of the splitting of x and y restriction the x and y values of the view origins
     //       have to be zero, the co-ordinates are as per the tensor info above channels, height/y, width/x
@@ -179,31 +174,28 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
     std::vector<unsigned int> wOrigin4 = {1, 0, 0}; //Extent of the window is defined by size of output[3].
     armnn::SplitterQueueDescriptor::ViewOrigin window4(wOrigin4);
 
-    bool subTensorsSupported = workloadFactory.SupportsSubTensors();
-
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle  = workloadFactory.CreateTensorHandle(inputTensorInfo);
+    bool subTensorsSupported = tensorHandleFactory.SupportsSubTensors();
+    std::unique_ptr<armnn::ITensorHandle> inputHandle  = tensorHandleFactory.CreateTensorHandle(inputTensorInfo);
 
     std::unique_ptr<armnn::ITensorHandle> outputHandle1 =
         subTensorsSupported ?
-            workloadFactory.CreateSubTensorHandle(*inputHandle, outputTensorInfo1.GetShape(), wOrigin1.data()) :
-            workloadFactory.CreateTensorHandle(outputTensorInfo1);
+        tensorHandleFactory.CreateSubTensorHandle(*inputHandle, outputTensorInfo1.GetShape(), wOrigin1.data()) :
+        tensorHandleFactory.CreateTensorHandle(outputTensorInfo1);
 
     std::unique_ptr<armnn::ITensorHandle> outputHandle2 =
         subTensorsSupported ?
-            workloadFactory.CreateSubTensorHandle(*inputHandle, outputTensorInfo2.GetShape(), wOrigin2.data()) :
-            workloadFactory.CreateTensorHandle(outputTensorInfo2);
+        tensorHandleFactory.CreateSubTensorHandle(*inputHandle, outputTensorInfo2.GetShape(), wOrigin2.data()) :
+        tensorHandleFactory.CreateTensorHandle(outputTensorInfo2);
 
     std::unique_ptr<armnn::ITensorHandle> outputHandle3 =
         subTensorsSupported ?
-            workloadFactory.CreateSubTensorHandle(*outputHandle2, outputTensorInfo3.GetShape(), wOrigin3.data()) :
-            workloadFactory.CreateTensorHandle(outputTensorInfo3);
+        tensorHandleFactory.CreateSubTensorHandle(*outputHandle2, outputTensorInfo3.GetShape(), wOrigin3.data()) :
+        tensorHandleFactory.CreateTensorHandle(outputTensorInfo3);
 
     std::unique_ptr<armnn::ITensorHandle> outputHandle4 =
         subTensorsSupported ?
-            workloadFactory.CreateSubTensorHandle(*outputHandle2, outputTensorInfo4.GetShape(), wOrigin4.data()) :
-            workloadFactory.CreateTensorHandle(outputTensorInfo4);
-    ARMNN_NO_DEPRECATE_WARN_END
+        tensorHandleFactory.CreateSubTensorHandle(*outputHandle2, outputTensorInfo4.GetShape(), wOrigin4.data()) :
+        tensorHandleFactory.CreateTensorHandle(outputTensorInfo4);
 
     // Do the first split
     armnn::SplitterQueueDescriptor data;
@@ -215,18 +207,20 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
     data.m_ViewOrigins.push_back(window1);
     data.m_ViewOrigins.push_back(window2);
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateSplitter(data, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::Splitter,
+                                                                                data,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle1->Allocate();
     outputHandle2->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), input.data());
 
     workload->Execute();
 
-    CopyDataFromITensorHandle(&ret1.output[0][0][0], outputHandle1.get());
-    CopyDataFromITensorHandle(&ret2.output[0][0][0], outputHandle2.get());
+    CopyDataFromITensorHandle(actualData1.data(), outputHandle1.get());
+    CopyDataFromITensorHandle(actualData2.data(), outputHandle2.get());
 
     // Do the second split.
     armnn::SplitterQueueDescriptor data2;
@@ -238,15 +232,22 @@ std::vector<LayerTestResult<T,3>> SplitterTestCommon(
     data2.m_ViewOrigins.push_back(window3);
     data2.m_ViewOrigins.push_back(window4);
 
-    std::unique_ptr<armnn::IWorkload> workload2 = workloadFactory.CreateSplitter(data2, info2);
+    std::unique_ptr<armnn::IWorkload> workload2 = workloadFactory.CreateWorkload(armnn::LayerType::Splitter,
+                                                                                 data2,
+                                                                                 info2);
 
     outputHandle3->Allocate();
     outputHandle4->Allocate();
 
     ExecuteWorkload(*workload2, memoryManager);
 
-    CopyDataFromITensorHandle(&ret3.output[0][0][0], outputHandle3.get());
-    CopyDataFromITensorHandle(&ret4.output[0][0][0], outputHandle4.get());
+    CopyDataFromITensorHandle(actualData3.data(), outputHandle3.get());
+    CopyDataFromITensorHandle(actualData4.data(), outputHandle4.get());
+
+    LayerTestResult<T,3> ret1(actualData1, expectedData1, outputHandle1->GetShape(), outputTensorInfo1.GetShape());
+    LayerTestResult<T,3> ret2(actualData2, expectedData2, outputHandle2->GetShape(), outputTensorInfo2.GetShape());
+    LayerTestResult<T,3> ret3(actualData3, expectedData3, outputHandle3->GetShape(), outputTensorInfo3.GetShape());
+    LayerTestResult<T,3> ret4(actualData4, expectedData4, outputHandle4->GetShape(), outputTensorInfo4.GetShape());
 
     std::vector<LayerTestResult<T,3>> ret = {ret1, ret2, ret3, ret4,};
 
@@ -257,13 +258,14 @@ template<armnn::DataType ArmnnType, typename T = armnn::ResolveType<ArmnnType>>
 LayerTestResult<T, 3> CopyViaSplitterTestImpl(
     armnn::IWorkloadFactory& workloadFactory,
     const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory,
     float qScale, int32_t qOffset)
 {
     IgnoreUnused(memoryManager);
+
     const armnn::TensorInfo tensorInfo({ 3, 6, 5 }, ArmnnType, qScale, qOffset);
-    auto input = MakeTensor<T, 3>(
-        tensorInfo,
-        armnnUtils::QuantizedVector<T>({
+    auto input = armnnUtils::QuantizedVector<T>(
+         {
              1.0f, 2.0f, 3.0f, 4.0f, 5.0f,
              6.0f, 7.0f, 8.0f, 9.0f, 10.0f,
             11.0f, 12.0f, 13.0f, 14.0f, 15.0f,
@@ -285,21 +287,20 @@ LayerTestResult<T, 3> CopyViaSplitterTestImpl(
             81.0f, 82.0f, 83.0f, 84.0f, 85.0f,
             86.0f, 87.0f, 88.0f, 89.0f, 90.0f,
         },
-        qScale, qOffset));
+        qScale, qOffset);
+
+    std::vector<T> actualOutput(tensorInfo.GetNumElements());
 
     std::vector<unsigned int> origin = { 0, 0, 0 };
     armnn::SplitterQueueDescriptor::ViewOrigin window(origin);
 
-    const bool subTensorsSupported = workloadFactory.SupportsSubTensors();
-
-    ARMNN_NO_DEPRECATE_WARN_BEGIN
-    std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(tensorInfo);
+    const bool subTensorsSupported = tensorHandleFactory.SupportsSubTensors();
+    std::unique_ptr<armnn::ITensorHandle> inputHandle = tensorHandleFactory.CreateTensorHandle(tensorInfo);
 
     std::unique_ptr<armnn::ITensorHandle> outputHandle =
         subTensorsSupported ?
-            workloadFactory.CreateSubTensorHandle(*inputHandle, tensorInfo.GetShape(), origin.data()) :
-            workloadFactory.CreateTensorHandle(tensorInfo);
-    ARMNN_NO_DEPRECATE_WARN_END
+        tensorHandleFactory.CreateSubTensorHandle(*inputHandle, tensorInfo.GetShape(), origin.data()) :
+        tensorHandleFactory.CreateTensorHandle(tensorInfo);
 
     armnn::SplitterQueueDescriptor data;
     armnn::WorkloadInfo info;
@@ -308,76 +309,103 @@ LayerTestResult<T, 3> CopyViaSplitterTestImpl(
 
     data.m_ViewOrigins.push_back(window);
 
-    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateSplitter(data, info);
+    std::unique_ptr<armnn::IWorkload> workload = workloadFactory.CreateWorkload(armnn::LayerType::Splitter,
+                                                                                data,
+                                                                                info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), input.data());
 
     workload->Execute();
 
-    LayerTestResult<T, 3> ret(tensorInfo);
-    CopyDataFromITensorHandle(&ret.output[0][0][0], outputHandle.get());
-    ret.outputExpected = input;
+    CopyDataFromITensorHandle(actualOutput.data(), outputHandle.get());
 
-    return ret;
+    return LayerTestResult<T, 3>(actualOutput,
+                                 input,
+                                 outputHandle->GetShape(),
+                                 tensorInfo.GetShape());
 }
 
 } // anonymous namespace
 
 std::vector<LayerTestResult<float,3>> SplitterFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return SplitterTestCommon<armnn::DataType::Float32>(workloadFactory, memoryManager);
+    return SplitterTestCommon<armnn::DataType::Float32>(workloadFactory, memoryManager, tensorHandleFactory);
 }
 
 std::vector<LayerTestResult<armnn::Half,3>> SplitterFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return SplitterTestCommon<armnn::DataType::Float16>(workloadFactory, memoryManager);
+    return SplitterTestCommon<armnn::DataType::Float16>(workloadFactory, memoryManager, tensorHandleFactory);
 }
 
 std::vector<LayerTestResult<uint8_t,3>> SplitterUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return SplitterTestCommon<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, 1.0f, 0);
+    return SplitterTestCommon<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, tensorHandleFactory, 1.0f, 0);
 }
 
 std::vector<LayerTestResult<int16_t,3>> SplitterInt16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return SplitterTestCommon<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, 1.0f, 0);
+    return SplitterTestCommon<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, tensorHandleFactory, 1.0f, 0);
 }
 
 LayerTestResult<float, 3> CopyViaSplitterFloat32Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return CopyViaSplitterTestImpl<armnn::DataType::Float32>(workloadFactory, memoryManager, 0.0f, 0);
+    return CopyViaSplitterTestImpl<armnn::DataType::Float32>(workloadFactory,
+                                                             memoryManager,
+                                                             tensorHandleFactory,
+                                                             0.0f,
+                                                             0);
 }
 
 LayerTestResult<armnn::Half, 3> CopyViaSplitterFloat16Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return CopyViaSplitterTestImpl<armnn::DataType::Float16>(workloadFactory, memoryManager, 0.0f, 0);
+    return CopyViaSplitterTestImpl<armnn::DataType::Float16>(workloadFactory,
+                                                             memoryManager,
+                                                             tensorHandleFactory,
+                                                             0.0f,
+                                                             0);
 }
 
 LayerTestResult<uint8_t, 3> CopyViaSplitterUint8Test(
     armnn::IWorkloadFactory& workloadFactory,
-    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+    const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+    const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return CopyViaSplitterTestImpl<armnn::DataType::QAsymmU8>(workloadFactory, memoryManager, 1.0f, 0);
+    return CopyViaSplitterTestImpl<armnn::DataType::QAsymmU8>(workloadFactory,
+                                                              memoryManager,
+                                                              tensorHandleFactory,
+                                                              1.0f,
+                                                              0);
 }
 
 LayerTestResult<int16_t, 3> CopyViaSplitterInt16Test(
         armnn::IWorkloadFactory& workloadFactory,
-        const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager)
+        const armnn::IBackendInternal::IMemoryManagerSharedPtr& memoryManager,
+        const armnn::ITensorHandleFactory& tensorHandleFactory)
 {
-    return CopyViaSplitterTestImpl<armnn::DataType::QSymmS16>(workloadFactory, memoryManager, 1.0f, 0);
+    return CopyViaSplitterTestImpl<armnn::DataType::QSymmS16>(workloadFactory,
+                                                              memoryManager,
+                                                              tensorHandleFactory,
+                                                              1.0f,
+                                                              0);
 }
