@@ -66,6 +66,13 @@ void OpenClTimer::Start()
             // Store the Kernel info for later GetMeasurements() call
             m_Kernels.emplace_back(ss.str(), customEvent);
 
+            if(event != nullptr)
+            {
+                //return cl_event from the intercepted call
+                clRetainEvent(customEvent);
+                *event = customEvent;
+            }
+
             return retVal;
         };
 
@@ -78,6 +85,11 @@ void OpenClTimer::Stop()
     CLSymbols::get().clEnqueueNDRangeKernel_ptr = m_OriginalEnqueueFunction;
 }
 
+bool OpenClTimer::HasKernelMeasurements() const
+{
+    return m_Kernels.size() > 0;
+}
+
 std::vector<Measurement> OpenClTimer::GetMeasurements() const
 {
     std::vector<Measurement> measurements;
