@@ -7,22 +7,21 @@
 
 #include "ClWorkloadFactoryHelper.hpp"
 
-#include <test/TensorHelpers.hpp>
+#include <armnnTestUtils/TensorHelpers.hpp>
 
-#include <backendsCommon/CpuTensorHandle.hpp>
-#include <backendsCommon/WorkloadFactory.hpp>
+#include <armnn/backends/TensorHandle.hpp>
+#include <armnn/backends/WorkloadFactory.hpp>
 
 #include <cl/ClContextControl.hpp>
 #include <cl/ClWorkloadFactory.hpp>
 #include <cl/OpenClTimer.hpp>
 
-#include <backendsCommon/test/TensorCopyUtils.hpp>
-#include <backendsCommon/test/WorkloadTestUtils.hpp>
+#include <armnnTestUtils/TensorCopyUtils.hpp>
+#include <armnnTestUtils/WorkloadTestUtils.hpp>
 
 #include <arm_compute/runtime/CL/CLScheduler.h>
 
-#include <boost/format.hpp>
-#include <boost/test/unit_test.hpp>
+#include <doctest/doctest.h>
 
 #include <iostream>
 
@@ -33,17 +32,16 @@ struct OpenClFixture
     // Initialising ClContextControl to ensure OpenCL is loaded correctly for each test case.
     // NOTE: Profiling needs to be enabled in ClContextControl to be able to obtain execution
     // times from OpenClTimer.
-    OpenClFixture() : m_ClContextControl(nullptr, true) {}
+    OpenClFixture() : m_ClContextControl(nullptr, nullptr, true) {}
     ~OpenClFixture() {}
 
     ClContextControl m_ClContextControl;
 };
 
-BOOST_FIXTURE_TEST_SUITE(OpenClTimerBatchNorm, OpenClFixture)
-using FactoryType = ClWorkloadFactory;
-
-BOOST_AUTO_TEST_CASE(OpenClTimerBatchNorm)
+TEST_CASE_FIXTURE(OpenClFixture, "OpenClTimerBatchNorm")
 {
+//using FactoryType = ClWorkloadFactory;
+
     auto memoryManager = ClWorkloadFactoryHelper::GetMemoryManager();
     ClWorkloadFactory workloadFactory = ClWorkloadFactoryHelper::GetFactory(memoryManager);
 
@@ -56,22 +54,22 @@ BOOST_AUTO_TEST_CASE(OpenClTimerBatchNorm)
     TensorInfo outputTensorInfo({num, channels, height, width}, DataType::Float32);
     TensorInfo tensorInfo({channels}, DataType::Float32);
 
-    auto input = MakeTensor<float, 4>(inputTensorInfo,
-        {
-             1.f, 4.f,
-             4.f, 2.f,
-             1.f, 6.f,
+    std::vector<float> input =
+    {
+         1.f, 4.f,
+         4.f, 2.f,
+         1.f, 6.f,
 
-             1.f, 1.f,
-             4.f, 1.f,
-            -2.f, 4.f
-        });
+         1.f, 1.f,
+         4.f, 1.f,
+        -2.f, 4.f
+    };
 
     // these values are per-channel of the input
-    auto mean     = MakeTensor<float, 1>(tensorInfo, { 3.f, -2.f });
-    auto variance = MakeTensor<float, 1>(tensorInfo, { 4.f,  9.f });
-    auto beta     = MakeTensor<float, 1>(tensorInfo, { 3.f,  2.f });
-    auto gamma    = MakeTensor<float, 1>(tensorInfo, { 2.f,  1.f });
+    std::vector<float> mean     = { 3.f, -2.f };
+    std::vector<float> variance = { 4.f,  9.f };
+    std::vector<float> beta     = { 3.f,  2.f };
+    std::vector<float> gamma    = { 2.f,  1.f };
 
     ARMNN_NO_DEPRECATE_WARN_BEGIN
     std::unique_ptr<ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
@@ -80,15 +78,15 @@ BOOST_AUTO_TEST_CASE(OpenClTimerBatchNorm)
 
     BatchNormalizationQueueDescriptor data;
     WorkloadInfo info;
-    ScopedCpuTensorHandle meanTensor(tensorInfo);
-    ScopedCpuTensorHandle varianceTensor(tensorInfo);
-    ScopedCpuTensorHandle betaTensor(tensorInfo);
-    ScopedCpuTensorHandle gammaTensor(tensorInfo);
+    ScopedTensorHandle meanTensor(tensorInfo);
+    ScopedTensorHandle varianceTensor(tensorInfo);
+    ScopedTensorHandle betaTensor(tensorInfo);
+    ScopedTensorHandle gammaTensor(tensorInfo);
 
-    AllocateAndCopyDataToITensorHandle(&meanTensor, &mean[0]);
-    AllocateAndCopyDataToITensorHandle(&varianceTensor, &variance[0]);
-    AllocateAndCopyDataToITensorHandle(&betaTensor, &beta[0]);
-    AllocateAndCopyDataToITensorHandle(&gammaTensor, &gamma[0]);
+    AllocateAndCopyDataToITensorHandle(&meanTensor, mean.data());
+    AllocateAndCopyDataToITensorHandle(&varianceTensor, variance.data());
+    AllocateAndCopyDataToITensorHandle(&betaTensor, beta.data());
+    AllocateAndCopyDataToITensorHandle(&gammaTensor, gamma.data());
 
     AddInputToWorkload(data, info, inputTensorInfo, inputHandle.get());
     AddOutputToWorkload(data, info, outputTensorInfo, outputHandle.get());
@@ -101,16 +99,16 @@ BOOST_AUTO_TEST_CASE(OpenClTimerBatchNorm)
     // for each channel:
     // substract mean, divide by standard deviation (with an epsilon to avoid div by 0)
     // multiply by gamma and add beta
-    std::unique_ptr<IWorkload> workload = workloadFactory.CreateBatchNormalization(data, info);
+    std::unique_ptr<IWorkload> workload = workloadFactory.CreateWorkload(LayerType::BatchNormalization, data, info);
 
     inputHandle->Allocate();
     outputHandle->Allocate();
 
-    CopyDataToITensorHandle(inputHandle.get(), &input[0][0][0][0]);
+    CopyDataToITensorHandle(inputHandle.get(), input.data());
 
     OpenClTimer openClTimer;
 
-    BOOST_CHECK_EQUAL(openClTimer.GetName(), "OpenClKernelTimer");
+    CHECK_EQ(openClTimer.GetName(), "OpenClKernelTimer");
 
     //Start the timer
     openClTimer.Start();
@@ -121,15 +119,13 @@ BOOST_AUTO_TEST_CASE(OpenClTimerBatchNorm)
     //Stop the timer
     openClTimer.Stop();
 
-    BOOST_CHECK_EQUAL(openClTimer.GetMeasurements().size(), 1);
+    CHECK_EQ(openClTimer.GetMeasurements().size(), 1);
 
-    BOOST_CHECK_EQUAL(openClTimer.GetMeasurements().front().m_Name,
+    CHECK_EQ(openClTimer.GetMeasurements().front().m_Name,
                       "OpenClKernelTimer/0: batchnormalization_layer_nchw GWS[1,3,2]");
 
-    BOOST_CHECK(openClTimer.GetMeasurements().front().m_Value > 0);
+    CHECK(openClTimer.GetMeasurements().front().m_Value > 0);
 
 }
 
-BOOST_AUTO_TEST_SUITE_END()
-
 #endif //aarch64 or x86_64
