@@ -12,7 +12,7 @@
 #include <arm_compute/runtime/CL/functions/CLSoftmaxLayer.h>
 
 
-#include <backendsCommon/Workload.hpp>
+#include "ClBaseWorkload.hpp"
 
 namespace armnn
 {
@@ -21,11 +21,12 @@ arm_compute::Status ClLogSoftmaxWorkloadValidate(const TensorInfo& input,
                                                  const TensorInfo& output,
                                                  const LogSoftmaxDescriptor& descriptor);
 
-class ClLogSoftmaxWorkload : public BaseWorkload<LogSoftmaxQueueDescriptor>
+class ClLogSoftmaxWorkload : public ClBaseWorkload<LogSoftmaxQueueDescriptor>
 {
 public:
     ClLogSoftmaxWorkload(const LogSoftmaxQueueDescriptor& descriptor, const WorkloadInfo& info,
-                         std::shared_ptr<arm_compute::MemoryManagerOnDemand>& memoryManager);
+                         std::shared_ptr<arm_compute::MemoryManagerOnDemand>& memoryManager,
+                         const arm_compute::CLCompileContext& clCompileContext);
     void Execute() const override;
 
 private:
