@@ -1,12 +1,12 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
-#include <backendsCommon/WorkloadData.hpp>
+#include "ClBaseWorkload.hpp"
+#include <armnn/backends/WorkloadData.hpp>
 
 #include <armnn/TypesUtils.hpp>
 #include <arm_compute/runtime/CL/functions/CLPermute.h>
@@ -20,16 +20,12 @@ arm_compute::Status ClPermuteWorkloadValidate(const TensorInfo& input,
                                               const TensorInfo& output,
                                               const PermuteDescriptor& descriptor);
 
-class ClPermuteWorkload : public BaseWorkload<PermuteQueueDescriptor>
+class ClPermuteWorkload : public ClBaseWorkload<PermuteQueueDescriptor>
 {
 public:
-    static const std::string& GetName()
-    {
-        static const std::string name = std::string("ClPermuteWorkload");
-        return name;
-    }
-
-    ClPermuteWorkload(const PermuteQueueDescriptor& descriptor, const WorkloadInfo& info);
+    ClPermuteWorkload(const PermuteQueueDescriptor& descriptor,
+                      const WorkloadInfo& info,
+                      const arm_compute::CLCompileContext& clCompileContext);
     void Execute() const override;
 
 private:
