@@ -1,5 +1,5 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -14,9 +14,17 @@ namespace armnn
 {
 using namespace armcomputetensorutils;
 
-ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const WorkloadInfo &info)
-    : BaseWorkload<QLstmQueueDescriptor>(descriptor, info)
+ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor& descriptor,
+                                 const WorkloadInfo& info,
+                                 const arm_compute::CLCompileContext& clCompileContext)
+    : ClBaseWorkload<QLstmQueueDescriptor>(descriptor, info)
 {
+    // Report Profiling Details
+    ARMNN_REPORT_PROFILING_WORKLOAD_DESC("ClQLstmWorkload_Construct",
+                                         descriptor.m_Parameters,
+                                         info,
+                                         this->GetGuid());
+
     arm_compute::LSTMParams<arm_compute::ICLTensor> qLstmParams;
 
     // Mandatory params
@@ -104,6 +112,7 @@ ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const W
         m_OutputLayerNormWeightsTensor = std::make_unique<arm_compute::CLTensor>();
         BuildArmComputeTensor(*m_OutputLayerNormWeightsTensor, m_Data.m_OutputLayerNormWeights->GetTensorInfo());
 
+        // Set layer norm params
         qLstmParams.set_layer_normalization_params(
             m_Data.m_InputLayerNormWeights != nullptr ? m_InputLayerNormWeightsTensor.get() : nullptr,
             m_ForgetLayerNormWeightsTensor.get(),
@@ -122,17 +131,18 @@ ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const W
         m_InputGateBiasTensor = std::make_unique<arm_compute::CLTensor>();
         BuildArmComputeTensor(*m_InputGateBiasTensor, m_Data.m_InputGateBias->GetTensorInfo());
 
+        // Set CIFG params
         qLstmParams.set_cifg_params(
             m_InputToInputWeightsTensor.get(),
             m_RecurrentToInputWeightsTensor.get(),
-            m_Data.m_CellToInputWeights      != nullptr ? m_CellToInputWeightsTensor.get()      : nullptr,
+            m_Data.m_CellToInputWeights != nullptr ? m_CellToInputWeightsTensor.get() : nullptr,
             m_InputGateBiasTensor.get());
     }
 
     // Input/Output tensors
     const arm_compute::ICLTensor& input         = static_cast<IClTensorHandle*>(m_Data.m_Inputs[0])->GetTensor();
-    const arm_compute::ICLTensor& outputStateIn = static_cast<IClTensorHandle*>(m_Data.m_Inputs[1])->GetTensor();
-    arm_compute::ICLTensor& cellStateIn         = static_cast<IClTensorHandle*>(m_Data.m_Inputs[2])->GetTensor();
+    arm_compute::ICLTensor&       outputStateIn = static_cast<IClTensorHandle*>(m_Data.m_Inputs[1])->GetTensor();
+    arm_compute::ICLTensor&       cellStateIn   = static_cast<IClTensorHandle*>(m_Data.m_Inputs[2])->GetTensor();
 
     arm_compute::ICLTensor& outputStateOut = static_cast<IClTensorHandle*>(m_Data.m_Outputs[0])->GetTensor();
     arm_compute::ICLTensor& cellStateOut   = static_cast<IClTensorHandle*>(m_Data.m_Outputs[1])->GetTensor();
@@ -148,24 +158,29 @@ ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const W
                                         m_Data.m_Parameters.m_CellIntermediateScale,
                                         m_Data.m_Parameters.m_OutputIntermediateScale);
 
-    m_QLstmLayer.configure(&input,
-                           m_InputToForgetWeightsTensor.get(),
-                           m_InputToCellWeightsTensor.get(),
-                           m_InputToOutputWeightsTensor.get(),
-                           m_RecurrentToForgetWeightsTensor.get(),
-                           m_RecurrentToCellWeightsTensor.get(),
-                           m_RecurrentToOutputWeightsTensor.get(),
-                           m_ForgetGateBiasTensor.get(),
-                           m_CellBiasTensor.get(),
-                           m_OutputGateBiasTensor.get(),
-                           &cellStateIn,
-                           &outputStateIn,
-                           &cellStateOut,
-                           &outputStateOut,
-                           &output,
-                           qLstmParams);
+    {
+        ARMNN_SCOPED_PROFILING_EVENT_CL_NAME_GUID("ClQLstmWorkload_configure");
+        // QLSTM CL configure
+        m_QLstmLayer.configure(clCompileContext,
+                               &input,
+                               m_InputToForgetWeightsTensor.get(),
+                               m_InputToCellWeightsTensor.get(),
+                               m_InputToOutputWeightsTensor.get(),
+                               m_RecurrentToForgetWeightsTensor.get(),
+                               m_RecurrentToCellWeightsTensor.get(),
+                               m_RecurrentToOutputWeightsTensor.get(),
+                               m_ForgetGateBiasTensor.get(),
+                               m_CellBiasTensor.get(),
+                               m_OutputGateBiasTensor.get(),
+                               &cellStateIn,
+                               &outputStateIn,
+                               &cellStateOut,
+                               &outputStateOut,
+                               &output,
+                               qLstmParams);
+    }
 
-    // InitializeArmComputeTensorData for mandatory params
+    // Initialise ACL tensor data for mandatory params
     InitializeArmComputeClTensorData(*m_InputToForgetWeightsTensor, m_Data.m_InputToForgetWeights);
     InitializeArmComputeClTensorData(*m_InputToCellWeightsTensor,   m_Data.m_InputToCellWeights);
     InitializeArmComputeClTensorData(*m_InputToOutputWeightsTensor, m_Data.m_InputToOutputWeights);
@@ -178,6 +193,7 @@ ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const W
     InitializeArmComputeClTensorData(*m_CellBiasTensor,       m_Data.m_CellBias);
     InitializeArmComputeClTensorData(*m_OutputGateBiasTensor, m_Data.m_OutputGateBias);
 
+    // Initialise ACL tensor data for optional params
     if (!m_Data.m_Parameters.m_CifgEnabled)
     {
         InitializeArmComputeClTensorData(*m_InputToInputWeightsTensor,     m_Data.m_InputToInputWeights);
@@ -224,6 +240,7 @@ ClQLstmWorkload::ClQLstmWorkload(const QLstmQueueDescriptor &descriptor, const W
 
 void ClQLstmWorkload::Execute() const
 {
+    ARMNN_SCOPED_PROFILING_EVENT_CL_NAME_GUID("ClQuantizedLstmWorkload_Execute");
     m_QLstmLayer.run();
 }
 
@@ -238,7 +255,7 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
 {
     arm_compute::LSTMParams<arm_compute::ITensorInfo> aclParamsInfo;
 
-    // The inputs and outputs
+    // Input/Output tensor info
     const arm_compute::TensorInfo aclInputInfo         = BuildArmComputeTensorInfo(input);
     const arm_compute::TensorInfo aclOutputStateInInfo = BuildArmComputeTensorInfo(outputStateIn);
     const arm_compute::TensorInfo aclCellStateInInfo   = BuildArmComputeTensorInfo(cellStateIn);
@@ -270,18 +287,22 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
     // Optional tensor info
     arm_compute::TensorInfo aclInputToInputWeightsInfo;
     arm_compute::TensorInfo aclRecurrentToInputWeightsInfo;
+
     arm_compute::TensorInfo aclCellToInputWeightsInfo;
     arm_compute::TensorInfo aclCellToForgetWeightsInfo;
     arm_compute::TensorInfo aclCellToOutputWeightsInfo;
+
     arm_compute::TensorInfo aclInputGateBiasInfo;
+
     arm_compute::TensorInfo aclProjectionWeightsInfo;
     arm_compute::TensorInfo aclProjectionBiasInfo;
+
     arm_compute::TensorInfo aclInputLayerNormWeightsInfo;
     arm_compute::TensorInfo aclForgetLayerNormWeightsInfo;
     arm_compute::TensorInfo aclCellLayerNormWeightsInfo;
     arm_compute::TensorInfo aclOutputLayerNormWeightsInfo;
 
-
+    // Create tensor info for optional params if they are enabled
     if (descriptor.m_PeepholeEnabled)
     {
         if (!descriptor.m_CifgEnabled)
@@ -292,6 +313,7 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
         aclCellToForgetWeightsInfo = BuildArmComputeTensorInfo(paramsInfo.GetCellToForgetWeights());
         aclCellToOutputWeightsInfo = BuildArmComputeTensorInfo(paramsInfo.GetCellToOutputWeights());
 
+        // Set peephole params info
         aclParamsInfo.set_peephole_params(&aclCellToForgetWeightsInfo,
                                           &aclCellToOutputWeightsInfo);
     }
@@ -305,6 +327,7 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
             aclProjectionBiasInfo = BuildArmComputeTensorInfo(paramsInfo.GetProjectionBias());
         }
 
+        // Set projection params info
         aclParamsInfo.set_projection_params(
             &aclProjectionWeightsInfo,
             paramsInfo.m_ProjectionBias != nullptr ? &aclProjectionBiasInfo : nullptr);
@@ -321,6 +344,7 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
         aclCellLayerNormWeightsInfo   = BuildArmComputeTensorInfo(paramsInfo.GetCellLayerNormWeights());
         aclOutputLayerNormWeightsInfo = BuildArmComputeTensorInfo(paramsInfo.GetOutputLayerNormWeights());
 
+        // Set layer norm params info
         aclParamsInfo.set_layer_normalization_params(
             paramsInfo.m_InputLayerNormWeights != nullptr ? &aclInputLayerNormWeightsInfo : nullptr,
             &aclForgetLayerNormWeightsInfo,
@@ -334,14 +358,15 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
         aclRecurrentToInputWeightsInfo = BuildArmComputeTensorInfo(paramsInfo.GetRecurrentToInputWeights());
         aclInputGateBiasInfo           = BuildArmComputeTensorInfo(paramsInfo.GetInputGateBias());
 
-
+        // Set CIFG params info
         aclParamsInfo.set_cifg_params(
             &aclInputToInputWeightsInfo,
             &aclRecurrentToInputWeightsInfo,
-            paramsInfo.m_CellToInputWeights      != nullptr ? &aclCellToInputWeightsInfo      : nullptr,
+            paramsInfo.m_CellToInputWeights != nullptr ? &aclCellToInputWeightsInfo : nullptr,
             &aclInputGateBiasInfo);
     }
 
+    // Set scalar descriptor params
     aclParamsInfo.set_cell_clip_params(descriptor.m_CellClip);
     aclParamsInfo.set_projection_clip_params(descriptor.m_ProjectionClip);
     aclParamsInfo.set_hidden_state_params(descriptor.m_HiddenStateZeroPoint, descriptor.m_HiddenStateScale);
@@ -350,6 +375,7 @@ arm_compute::Status ClQLstmWorkloadValidate(const TensorInfo& input,
                                           descriptor.m_CellIntermediateScale,
                                           descriptor.m_OutputIntermediateScale);
 
+    // QLSTM CL validate
     return arm_compute::CLQLSTMLayer::validate(&aclInputInfo,
                                                &aclInputToForgetWeightsInfo,
                                                &aclInputToCellWeightsInfo,
