@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -10,7 +10,7 @@
 #include <aclCommon/ArmComputeUtils.hpp>
 #include <aclCommon/ArmComputeTensorUtils.hpp>
 
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/backends/TensorHandle.hpp>
 
 #include <cl/ClTensorHandle.hpp>
 
@@ -46,9 +46,17 @@ arm_compute::Status ClResizeWorkloadValidate(const TensorInfo& input,
                                                                        descriptor.m_AlignCorners));
 }
 
-ClResizeWorkload::ClResizeWorkload(const ResizeQueueDescriptor& descriptor, const WorkloadInfo& info) :
-    BaseWorkload<ResizeQueueDescriptor>(descriptor, info)
+ClResizeWorkload::ClResizeWorkload(const ResizeQueueDescriptor& descriptor,
+                                   const WorkloadInfo& info,
+                                   const arm_compute::CLCompileContext& clCompileContext)
+  : ClBaseWorkload<ResizeQueueDescriptor>(descriptor, info)
 {
+    // Report Profiling Details
+    ARMNN_REPORT_PROFILING_WORKLOAD_DESC("ClResizeWorkload_Construct",
+                                         descriptor.m_Parameters,
+                                         info,
+                                         this->GetGuid());
+
     m_Data.ValidateInputsOutputs("ClResizeWorkload", 1, 1);
 
     arm_compute::ICLTensor& input  = static_cast<IClTensorHandle*>(m_Data.m_Inputs[0])->GetTensor();
@@ -65,20 +73,24 @@ ClResizeWorkload::ClResizeWorkload(const ResizeQueueDescriptor& descriptor, cons
                                                  ? arm_compute::SamplingPolicy::CENTER
                                                  : arm_compute::SamplingPolicy::TOP_LEFT;
 
-    m_ResizeLayer.configure(&input,
-                            &output,
-                            arm_compute::ScaleKernelInfo(aclInterpolationPolicy,
-                                                         arm_compute::BorderMode::REPLICATE,
-                                                         arm_compute::PixelValue(0.f),
-                                                         samplingPolicy,
-                                                         true,
-                                                         descriptor.m_Parameters.m_AlignCorners));
+    {
+        ARMNN_SCOPED_PROFILING_EVENT_CL_NAME_GUID("ClResizeWorkload_configure");
+        m_ResizeLayer.configure(clCompileContext,
+                                &input,
+                                &output,
+                                arm_compute::ScaleKernelInfo(aclInterpolationPolicy,
+                                                             arm_compute::BorderMode::REPLICATE,
+                                                             arm_compute::PixelValue(0.f),
+                                                             samplingPolicy,
+                                                             true,
+                                                             descriptor.m_Parameters.m_AlignCorners));
+    }
 
 };
 
 void ClResizeWorkload::Execute() const
 {
-    ARMNN_SCOPED_PROFILING_EVENT_CL("ClResizeWorkload_Execute");
+    ARMNN_SCOPED_PROFILING_EVENT_CL_NAME_GUID("ClResizeWorkload_Execute");
     RunClFunction(m_ResizeLayer, CHECK_LOCATION());
 }
 
