@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "ClBaseWorkload.hpp"
 
 #include <arm_compute/runtime/CL/functions/CLScale.h>
 
@@ -16,10 +16,12 @@ arm_compute::Status ClResizeWorkloadValidate(const TensorInfo& input,
                                              const TensorInfo& output,
                                              const ResizeDescriptor& descriptor);
 
-class ClResizeWorkload : public BaseWorkload<ResizeQueueDescriptor>
+class ClResizeWorkload : public ClBaseWorkload<ResizeQueueDescriptor>
 {
 public:
-    ClResizeWorkload(const ResizeQueueDescriptor& descriptor, const WorkloadInfo& info);
+    ClResizeWorkload(const ResizeQueueDescriptor& descriptor,
+                     const WorkloadInfo& info,
+                     const arm_compute::CLCompileContext& clCompileContext);
     void Execute() const override;
 
 private:
