@@ -1,5 +1,5 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -11,7 +11,7 @@
 #include <arm_compute/runtime/MemoryManagerOnDemand.h>
 #include <arm_compute/runtime/CL/functions/CLSoftmaxLayer.h>
 
-#include <backendsCommon/Workload.hpp>
+#include "ClBaseWorkload.hpp"
 
 namespace armnn
 {
@@ -20,11 +20,13 @@ arm_compute::Status ClSoftmaxWorkloadValidate(const TensorInfo& input,
                                               const TensorInfo& output,
                                               const SoftmaxDescriptor& descriptor);
 
-class ClSoftmaxWorkload : public BaseWorkload<SoftmaxQueueDescriptor>
+class ClSoftmaxWorkload : public ClBaseWorkload<SoftmaxQueueDescriptor>
 {
 public:
-    ClSoftmaxWorkload(const SoftmaxQueueDescriptor& descriptor, const WorkloadInfo& info,
-                      std::shared_ptr<arm_compute::MemoryManagerOnDemand>& memoryManager);
+    ClSoftmaxWorkload(const SoftmaxQueueDescriptor& descriptor,
+                      const WorkloadInfo& info,
+                      std::shared_ptr<arm_compute::MemoryManagerOnDemand>& memoryManager,
+                      const arm_compute::CLCompileContext& clCompileContext);
     void Execute() const override;
 
 private:
