@@ -27,7 +27,6 @@ const std::set<armnn::LayerType> paddingRequiredLayers {
     LayerType::Pooling2d,
     LayerType::Quantize,
     LayerType::QuantizedLstm,
-    LayerType::Resize,
     LayerType::Stack,
     LayerType::TransposeConvolution2d
 };
@@ -61,6 +60,8 @@ public:
 
     const FactoryId& GetId() const override;
 
+    bool SupportsInPlaceComputation() const override;
+
     bool SupportsSubTensors() const override;
 
     MemorySourceFlags GetExportFlags() const override;
