@@ -7,11 +7,10 @@
 #include "NeonInterceptorScheduler.hpp"
 
 #include <armnn/utility/Assert.hpp>
+#include <armnn/utility/PolymorphicDowncast.hpp>
 
 #include <memory>
 
-#include <boost/format.hpp>
-
 namespace armnn
 {
 namespace
@@ -31,7 +30,7 @@ void NeonTimer::Start()
     {
         // Keep the real schedule and add NeonInterceptorScheduler as an interceptor
         m_RealScheduler  = &arm_compute::Scheduler::get();
-        arm_compute::Scheduler::set(std::static_pointer_cast<arm_compute::IScheduler>(g_Interceptor));
+        arm_compute::Scheduler::set(armnn::PolymorphicPointerDowncast<arm_compute::IScheduler>(g_Interceptor));
     }
 }
 
@@ -43,6 +42,11 @@ void NeonTimer::Stop()
     m_RealScheduler = nullptr;
 }
 
+bool NeonTimer::HasKernelMeasurements() const
+{
+    return m_Kernels.size() > 0;
+}
+
 std::vector<Measurement> NeonTimer::GetMeasurements() const
 {
     std::vector<Measurement> measurements = m_Kernels;
