@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 
 #include <arm_compute/core/Error.h>
 #include <arm_compute/runtime/NEON/functions/NEElementwiseUnaryLayer.h>
@@ -15,7 +15,7 @@ namespace armnn
 
 arm_compute::Status NeonAbsWorkloadValidate(const TensorInfo& input, const TensorInfo& output);
 
-class NeonAbsWorkload : public BaseWorkload<AbsQueueDescriptor>
+class NeonAbsWorkload : public NeonBaseWorkload<AbsQueueDescriptor>
 {
 public:
     NeonAbsWorkload(const AbsQueueDescriptor& descriptor, const WorkloadInfo& info);
