@@ -1,10 +1,12 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
+#include "NeonBaseWorkload.hpp"
+
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 #include <arm_compute/runtime/NEON/functions/NEElementwiseOperations.h>
@@ -17,7 +19,7 @@ arm_compute::Status NeonComparisonWorkloadValidate(const TensorInfo& input0,
                                                    const TensorInfo& output,
                                                    const ComparisonDescriptor& descriptor);
 
-class NeonComparisonWorkload : public BaseWorkload<ComparisonQueueDescriptor>
+class NeonComparisonWorkload : public NeonBaseWorkload<ComparisonQueueDescriptor>
 {
 public:
     NeonComparisonWorkload(const ComparisonQueueDescriptor& descriptor, const WorkloadInfo& info);
