@@ -1,17 +1,19 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
+#include "NeonBaseWorkload.hpp"
+
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 namespace armnn
 {
 arm_compute::Status NeonConstantWorkloadValidate(const TensorInfo& output);
 
-class NeonConstantWorkload : public BaseWorkload<ConstantQueueDescriptor>
+class NeonConstantWorkload : public NeonBaseWorkload<ConstantQueueDescriptor>
 {
 public:
     NeonConstantWorkload(const ConstantQueueDescriptor& descriptor, const WorkloadInfo& info);
