@@ -1,10 +1,12 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
+#include "NeonBaseWorkload.hpp"
+
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 #include <arm_compute/runtime/NEON/functions/NEElementwiseOperations.h>
@@ -13,10 +15,11 @@ namespace armnn
 {
 
 arm_compute::Status NeonDivisionWorkloadValidate(const TensorInfo& input0,
-                                                const TensorInfo& input1,
-                                                const TensorInfo& output);
+                                                 const TensorInfo& input1,
+                                                 const TensorInfo& output,
+                                                 const ActivationDescriptor* activationDescriptor = nullptr);
 
-class NeonDivisionWorkload : public BaseWorkload<DivisionQueueDescriptor>
+class NeonDivisionWorkload : public NeonBaseWorkload<DivisionQueueDescriptor>
 {
 public:
     NeonDivisionWorkload(const DivisionQueueDescriptor& descriptor, const WorkloadInfo& info);
