@@ -1,11 +1,11 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 #include <arm_compute/core/Error.h>
 #include <arm_compute/runtime/NEON/functions/NEElementwiseUnaryLayer.h>
 
@@ -14,7 +14,7 @@ namespace armnn
 
 arm_compute::Status NeonExpWorkloadValidate(const TensorInfo& input, const TensorInfo& output);
 
-class NeonExpWorkload : public BaseWorkload<ElementwiseUnaryQueueDescriptor>
+class NeonExpWorkload : public NeonBaseWorkload<ElementwiseUnaryQueueDescriptor>
 {
 public:
     NeonExpWorkload(const ElementwiseUnaryQueueDescriptor& descriptor, const WorkloadInfo& info);
