@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017,2022 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 
 #include <arm_compute/core/Error.h>
 #include <arm_compute/runtime/IFunction.h>
@@ -20,23 +20,25 @@ namespace armnn
 arm_compute::Status NeonFullyConnectedWorkloadValidate(const TensorInfo& input,
                                                        const TensorInfo& output,
                                                        const TensorInfo& weights,
-                                                       const TensorInfo& biases,
-                                                       const FullyConnectedDescriptor& descriptor);
+                                                       const Optional<TensorInfo>& biases,
+                                                       const FullyConnectedDescriptor& descriptor,
+                                                       const ActivationDescriptor* activationDescriptor = nullptr);
 
-class NeonFullyConnectedWorkload : public BaseWorkload<FullyConnectedQueueDescriptor>
+class NeonFullyConnectedWorkload : public NeonBaseWorkload<FullyConnectedQueueDescriptor>
 {
 public:
     NeonFullyConnectedWorkload(const FullyConnectedQueueDescriptor& descriptor, const WorkloadInfo& info,
                                std::shared_ptr<arm_compute::MemoryManagerOnDemand>& memoryManager);
+
     virtual void Execute() const override;
 
 private:
     std::unique_ptr<arm_compute::IFunction> m_FullyConnectedLayer;
-
-    std::unique_ptr<arm_compute::Tensor> m_WeightsTensor;
-    std::unique_ptr<arm_compute::Tensor> m_BiasesTensor;
-
-    void FreeUnusedTensors();
+    mutable std::unique_ptr<arm_compute::Tensor> m_WeightsTensor;
+    mutable std::unique_ptr<arm_compute::Tensor> m_BiasesTensor;
+    TensorInfo m_WeightsTensorInfo;
+    TensorInfo m_BiasesTensorInfo;
+    mutable bool prepared = false;
 };
 
 } //namespace armnn
