@@ -1,10 +1,12 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
+#include "NeonBaseWorkload.hpp"
+
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 #include <arm_compute/runtime/NEON/functions/NEElementwiseOperations.h>
@@ -16,7 +18,7 @@ arm_compute::Status NeonMaximumWorkloadValidate(const TensorInfo& input0,
                                                 const TensorInfo& input1,
                                                 const TensorInfo& output);
 
-class NeonMaximumWorkload : public BaseWorkload<MaximumQueueDescriptor>
+class NeonMaximumWorkload : public NeonBaseWorkload<MaximumQueueDescriptor>
 {
 public:
     NeonMaximumWorkload(const MaximumQueueDescriptor& descriptor, const WorkloadInfo& info);
