@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 
 #include <arm_compute/runtime/NEON/functions/NEReduceMean.h>
 
@@ -14,9 +14,9 @@ namespace armnn
 
 arm_compute::Status NeonMeanWorkloadValidate(const TensorInfo& input,
                                              const TensorInfo& output,
-                                             const MeanDescriptor& desc);
+                                             const MeanDescriptor& descriptor);
 
-class NeonMeanWorkload : public BaseWorkload<MeanQueueDescriptor>
+class NeonMeanWorkload : public NeonBaseWorkload<MeanQueueDescriptor>
 {
 public:
     NeonMeanWorkload(const MeanQueueDescriptor& descriptor, const WorkloadInfo& info);
