@@ -1,12 +1,12 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017-2018,2021-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
-#include <backendsCommon/WorkloadData.hpp>
+#include "NeonBaseWorkload.hpp"
+#include <armnn/backends/WorkloadData.hpp>
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 #include <armnn/TypesUtils.hpp>
@@ -19,15 +19,9 @@ namespace armnn
 arm_compute::Status NeonPermuteWorkloadValidate(const TensorInfo& input, const TensorInfo& output,
                                                 const PermuteDescriptor& descriptor);
 
-class NeonPermuteWorkload : public BaseWorkload<PermuteQueueDescriptor>
+class NeonPermuteWorkload : public NeonBaseWorkload<PermuteQueueDescriptor>
 {
 public:
-    static const std::string& GetName()
-    {
-        static const std::string name = std::string("NeonPermuteWorkload");
-        return name;
-    }
-
     NeonPermuteWorkload(const PermuteQueueDescriptor& descriptor, const WorkloadInfo& info);
     void Execute() const override;
 
