@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -10,7 +10,7 @@
 #include <aclCommon/ArmComputeUtils.hpp>
 #include <aclCommon/ArmComputeTensorUtils.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/backends/TensorHandle.hpp>
 
 #include <neon/NeonTensorHandle.hpp>
 
@@ -36,21 +36,29 @@ arm_compute::Status NeonResizeWorkloadValidate(const TensorInfo& input,
     arm_compute::SamplingPolicy samplingPolicy = descriptor.m_HalfPixelCenters ? arm_compute::SamplingPolicy::CENTER :
                                                                                  arm_compute::SamplingPolicy::TOP_LEFT;
 
+    bool usePadding = false;
+
     return arm_compute::NEScale::validate(&aclInputInfo,
                                           &aclOutputInfo,
                                           arm_compute::ScaleKernelInfo(aclInterpolationPolicy,
                                                                        arm_compute::BorderMode::REPLICATE,
                                                                        arm_compute::PixelValue(0.f),
                                                                        samplingPolicy,
-                                                                       true,
+                                                                       usePadding,
                                                                        descriptor.m_AlignCorners));
 
 }
 
 NeonResizeWorkload::NeonResizeWorkload(const ResizeQueueDescriptor& descriptor,
                                                        const WorkloadInfo& info)
-    : BaseWorkload<ResizeQueueDescriptor>(descriptor, info)
+    : NeonBaseWorkload<ResizeQueueDescriptor>(descriptor, info)
 {
+    // Report Profiling Details
+    ARMNN_REPORT_PROFILING_WORKLOAD_DESC("NeonResizeWorkload_Construct",
+                                         descriptor.m_Parameters,
+                                         info,
+                                         this->GetGuid());
+
     m_Data.ValidateInputsOutputs("NeonResizeWorkload", 1, 1);
 
     arm_compute::ITensor& input = PolymorphicDowncast<IAclTensorHandle*>(m_Data.m_Inputs[0])->GetTensor();
@@ -67,19 +75,21 @@ NeonResizeWorkload::NeonResizeWorkload(const ResizeQueueDescriptor& descriptor,
                                                  ? arm_compute::SamplingPolicy::CENTER
                                                  : arm_compute::SamplingPolicy::TOP_LEFT;
 
+    bool usePadding = false;
+
     m_ResizeLayer.configure(&input,
                             &output,
                             arm_compute::ScaleKernelInfo(aclInterpolationPolicy,
                                                          arm_compute::BorderMode::REPLICATE,
                                                          arm_compute::PixelValue(0.f),
                                                          samplingPolicy,
-                                                         true,
+                                                         usePadding,
                                                          descriptor.m_Parameters.m_AlignCorners));
 };
 
 void NeonResizeWorkload::Execute() const
 {
-    ARMNN_SCOPED_PROFILING_EVENT_NEON("NeonResizeWorkload_Execute");
+    ARMNN_SCOPED_PROFILING_EVENT_NEON_NAME_GUID("NeonResizeWorkload_Execute");
     m_ResizeLayer.run();
 }
 
