@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 
 #include <arm_compute/runtime/NEON/functions/NEScale.h>
 
@@ -16,7 +16,7 @@ arm_compute::Status NeonResizeWorkloadValidate(const TensorInfo& input,
                                                const TensorInfo& output,
                                                const ResizeDescriptor& descriptor);
 
-class NeonResizeWorkload : public BaseWorkload<ResizeQueueDescriptor>
+class NeonResizeWorkload : public NeonBaseWorkload<ResizeQueueDescriptor>
 {
 public:
     NeonResizeWorkload(const ResizeQueueDescriptor& descriptor, const WorkloadInfo& info);
