@@ -1,17 +1,16 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "NeonStackWorkload.hpp"
 #include "NeonWorkloadUtils.hpp"
 
 #include <aclCommon/ArmComputeTensorUtils.hpp>
+#include <armnn/utility/NumericCast.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
+#include <armnn/backends/TensorHandle.hpp>
 #include <neon/NeonTensorHandle.hpp>
 
-#include <boost/numeric/conversion/cast.hpp>
-
 namespace armnn
 {
 using namespace armcomputetensorutils;
@@ -20,8 +19,8 @@ namespace
 {
 int CalcAxis(const unsigned int axis, const unsigned int inputDimensions)
 {
-    const int intAxis = boost::numeric_cast<int>(axis);
-    return boost::numeric_cast<int>(inputDimensions) - intAxis;
+    const int intAxis = armnn::numeric_cast<int>(axis);
+    return armnn::numeric_cast<int>(inputDimensions) - intAxis;
 }
 } //namespace
 
@@ -48,8 +47,14 @@ arm_compute::Status NeonStackWorkloadValidate(const std::vector<const TensorInfo
 }
 
 NeonStackWorkload::NeonStackWorkload(const StackQueueDescriptor& descriptor, const WorkloadInfo& info)
-: BaseWorkload<StackQueueDescriptor>(descriptor, info)
+: NeonBaseWorkload<StackQueueDescriptor>(descriptor, info)
 {
+    // Report Profiling Details
+    ARMNN_REPORT_PROFILING_WORKLOAD_DESC("NeonStackWorkload_Construct",
+                                         descriptor.m_Parameters,
+                                         info,
+                                         this->GetGuid());
+
     std::vector<arm_compute::ITensor*> aclInputs;
     for (auto input : m_Data.m_Inputs)
     {
@@ -68,7 +73,7 @@ void NeonStackWorkload::Execute() const
 {
     if (m_Layer)
     {
-        ARMNN_SCOPED_PROFILING_EVENT_NEON("NeonStackWorkload_Execute");
+        ARMNN_SCOPED_PROFILING_EVENT_NEON_NAME_GUID("NeonStackWorkload_Execute");
         m_Layer->run();
     }
 }
