@@ -1,11 +1,11 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
+#include "NeonBaseWorkload.hpp"
 
 #include <arm_compute/core/Error.h>
 #include <arm_compute/runtime/IFunction.h>
@@ -21,7 +21,7 @@ arm_compute::Status NeonStridedSliceWorkloadValidate(const TensorInfo& input,
                                                      const TensorInfo& output,
                                                      const StridedSliceDescriptor& descriptor);
 
-class NeonStridedSliceWorkload : public BaseWorkload<StridedSliceQueueDescriptor>
+class NeonStridedSliceWorkload : public NeonBaseWorkload<StridedSliceQueueDescriptor>
 {
 public:
     NeonStridedSliceWorkload(const StridedSliceQueueDescriptor& descriptor, const WorkloadInfo& info);
