@@ -1,12 +1,12 @@
 //
-// Copyright © 2020 Arm Ltd. All rights reserved.
+// Copyright © 2020-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #pragma once
 
-#include <backendsCommon/Workload.hpp>
-#include <backendsCommon/WorkloadData.hpp>
+#include "NeonBaseWorkload.hpp"
+#include <armnn/backends/WorkloadData.hpp>
 #include <neon/workloads/NeonWorkloadUtils.hpp>
 
 #include <armnn/TypesUtils.hpp>
@@ -19,15 +19,9 @@ namespace armnn
 arm_compute::Status NeonTransposeWorkloadValidate(const TensorInfo& input, const TensorInfo& output,
                                                   const TransposeDescriptor& descriptor);
 
-class NeonTransposeWorkload : public BaseWorkload<TransposeQueueDescriptor>
+class NeonTransposeWorkload : public NeonBaseWorkload<TransposeQueueDescriptor>
 {
 public:
-    static const std::string& GetName()
-    {
-        static const std::string name = std::string("NeonTransposeWorkload");
-        return name;
-    }
-
     NeonTransposeWorkload(const TransposeQueueDescriptor& descriptor, const WorkloadInfo& info);
     void Execute() const override;
 
