@@ -48,7 +48,7 @@ std::unique_ptr<ITensorHandle> RefTensorHandleFactory::CreateTensorHandle(const
     }
     else
     {
-        return std::make_unique<RefTensorHandle>(tensorInfo, m_ImportFlags);
+        return std::make_unique<RefTensorHandle>(tensorInfo);
     }
 }
 
@@ -63,7 +63,7 @@ std::unique_ptr<ITensorHandle> RefTensorHandleFactory::CreateTensorHandle(const
     }
     else
     {
-        return std::make_unique<RefTensorHandle>(tensorInfo, m_ImportFlags);
+        return std::make_unique<RefTensorHandle>(tensorInfo);
     }
 }
 
@@ -87,4 +87,4 @@ MemorySourceFlags RefTensorHandleFactory::GetImportFlags() const
     return m_ImportFlags;
 }
 
-} // namespace armnn
\ No newline at end of file
+} // namespace armnn
