@@ -5,6 +5,8 @@
 
 #include "Dequantize.hpp"
 
+#include <armnn/utility/IgnoreUnused.hpp>
+
 namespace armnn
 {
 
@@ -13,7 +15,8 @@ void Dequantize(Decoder<float>& inputDecoder,
                 const TensorInfo& inputInfo,
                 const TensorInfo& outputInfo)
 {
-    BOOST_ASSERT(inputInfo.GetNumElements() == outputInfo.GetNumElements());
+    IgnoreUnused(outputInfo);
+    ARMNN_ASSERT(inputInfo.GetNumElements() == outputInfo.GetNumElements());
     for (unsigned int i = 0; i < inputInfo.GetNumElements(); i++)
     {
         // inputDecoder.Get() dequantizes the data element from whatever
