@@ -5,6 +5,8 @@
 
 #include "FullyConnected.hpp"
 
+#include <armnn/utility/Assert.hpp>
+
 #include "RefWorkloadUtils.hpp"
 
 namespace armnn
@@ -14,8 +16,9 @@ void FullyConnected(const TensorShape& rInputShape,
                     Decoder<float>& rInputDecoder,
                     const TensorShape& rOutputShape,
                     Encoder<float>& rOutputEncoder,
+                    const TensorShape& rWeightsShape,
                     Decoder<float>& rWeightDecoder,
-                    Decoder<float>& rBiasDecoder,
+                    Decoder<float>* pBiasDecoder,
                     const bool biasEnabled,
                     const unsigned int K,
                     const bool transposeWeights)
@@ -23,6 +26,15 @@ void FullyConnected(const TensorShape& rInputShape,
     // Perform FullyConnected implementation
     unsigned int outputSize = rOutputShape[1];
 
+    const std::vector<float> decodedInputs = rInputDecoder.DecodeTensor(rInputShape);
+    const std::vector<float> decodedWeights = rWeightDecoder.DecodeTensor(rWeightsShape);
+
+    const TensorShape biasShape{outputSize};
+
+    ARMNN_ASSERT(!biasEnabled || pBiasDecoder != nullptr);
+    const std::vector<float> decodedBiases = biasEnabled ? pBiasDecoder->DecodeTensor(biasShape) : std::vector<float>();
+
+
     for (unsigned int n = 0; n < rInputShape[0]; n++)
     {
         for (unsigned int channelOutput = 0; channelOutput < outputSize; channelOutput++)
@@ -34,23 +46,19 @@ void FullyConnected(const TensorShape& rInputShape,
                 float weight;
                 if (transposeWeights)
                 {
-                    rWeightDecoder[channelOutput * K + channelInput];
-                    weight = rWeightDecoder.Get();
+                    weight = decodedWeights[channelOutput * K + channelInput];
                 }
                 else
                 {
-                    rWeightDecoder[channelInput * outputSize + channelOutput];
-                    weight = rWeightDecoder.Get();
+                    weight = decodedWeights[channelInput * outputSize + channelOutput];
                 }
 
-                rInputDecoder[n * K + channelInput];
-                outval += weight * rInputDecoder.Get();
+                outval += weight * decodedInputs[n * K + channelInput];
             }
 
             if (biasEnabled)
             {
-                rBiasDecoder[channelOutput];
-                outval += rBiasDecoder.Get();
+                outval += decodedBiases[channelOutput];
             }
 
             rOutputEncoder[n * outputSize + channelOutput];
