@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2019-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -11,8 +11,7 @@
 #include <Profiling.hpp>
 
 #include <armnnUtils/DataLayoutIndexed.hpp>
-
-#include <boost/numeric/conversion/cast.hpp>
+#include <armnn/utility/NumericCast.hpp>
 
 #include <cmath>
 
@@ -23,42 +22,53 @@ namespace armnn
 RefL2NormalizationWorkload::RefL2NormalizationWorkload(
         const L2NormalizationQueueDescriptor& descriptor,
         const WorkloadInfo& info)
-    : BaseWorkload<L2NormalizationQueueDescriptor>(descriptor, info) {}
+    : RefBaseWorkload<L2NormalizationQueueDescriptor>(descriptor, info) {}
 
 void RefL2NormalizationWorkload::Execute() const
 {
-    ARMNN_SCOPED_PROFILING_EVENT(Compute::CpuRef, "RefL2NormalizationWorkload_Execute");
+    Execute(m_Data.m_Inputs, m_Data.m_Outputs);
+}
 
-    const TensorInfo& inputInfo = GetTensorInfo(m_Data.m_Inputs[0]);
-    const TensorInfo& outputInfo = GetTensorInfo(m_Data.m_Outputs[0]);
+void RefL2NormalizationWorkload::ExecuteAsync(ExecutionData& executionData)
+{
+    WorkingMemDescriptor* workingMemDescriptor = static_cast<WorkingMemDescriptor*>(executionData.m_Data);
+    Execute(workingMemDescriptor->m_Inputs, workingMemDescriptor->m_Outputs);
+}
 
-    auto inputDecoder  = MakeDecoder<float>(inputInfo, m_Data.m_Inputs[0]->Map());
-    auto outputEncoder = MakeEncoder<float>(outputInfo, m_Data.m_Outputs[0]->Map());
+void RefL2NormalizationWorkload::Execute(std::vector<ITensorHandle*> inputs, std::vector<ITensorHandle*> outputs) const
+{
+    ARMNN_SCOPED_PROFILING_EVENT_REF_NAME_GUID("RefL2NormalizationWorkload_Execute");
+
+    const TensorInfo& inputInfo = GetTensorInfo(inputs[0]);
+    const TensorInfo& outputInfo = GetTensorInfo(outputs[0]);
+
+    auto inputDecoder  = MakeDecoder<float>(inputInfo, inputs[0]->Map());
+    auto outputEncoder = MakeEncoder<float>(outputInfo, outputs[0]->Map());
 
     DataLayoutIndexed dataLayout(m_Data.m_Parameters.m_DataLayout);
 
     const TensorShape& shape = inputInfo.GetShape();
     unsigned int paddedShapeArray[4];
-    const int idxShift = 4 - boost::numeric_cast<int>(shape.GetNumDimensions());
+    const int idxShift = 4 - armnn::numeric_cast<int>(shape.GetNumDimensions());
 
     const unsigned int batches = (idxShift == 0) ? shape[0] : 1;
     paddedShapeArray[0] = batches;
 
-    const int channelsIdx = boost::numeric_cast<int>(dataLayout.GetChannelsIndex());
+    const int channelsIdx = armnn::numeric_cast<int>(dataLayout.GetChannelsIndex());
     const unsigned int channels = (channelsIdx - idxShift >= 0)
-                                  ? shape[boost::numeric_cast<unsigned int>(channelsIdx - idxShift)]
+                                  ? shape[armnn::numeric_cast<unsigned int>(channelsIdx - idxShift)]
                                   : 1;
     paddedShapeArray[channelsIdx] = channels;
 
-    const int heightIdx = boost::numeric_cast<int>(dataLayout.GetHeightIndex());
+    const int heightIdx = armnn::numeric_cast<int>(dataLayout.GetHeightIndex());
     const unsigned int height = (heightIdx - idxShift >= 0)
-                                ? shape[boost::numeric_cast<unsigned int>(heightIdx - idxShift)]
+                                ? shape[armnn::numeric_cast<unsigned int>(heightIdx - idxShift)]
                                 : 1;
     paddedShapeArray[heightIdx] = height;
 
-    const int widthIdx = boost::numeric_cast<int>(dataLayout.GetWidthIndex());
+    const int widthIdx = armnn::numeric_cast<int>(dataLayout.GetWidthIndex());
     const unsigned int width = (widthIdx - idxShift >= 0)
-                               ? shape[boost::numeric_cast<unsigned int>(widthIdx - idxShift)]
+                               ? shape[armnn::numeric_cast<unsigned int>(widthIdx - idxShift)]
                                : 1;
     paddedShapeArray[widthIdx] = width;
 
