@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017-2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -8,11 +8,10 @@
 #include <armnn/Logging.hpp>
 #include <armnn/Tensor.hpp>
 #include <armnnUtils/DataLayoutIndexed.hpp>
+#include <armnn/utility/NumericCast.hpp>
 
 #include <Profiling.hpp>
 
-#include <boost/numeric/conversion/cast.hpp>
-
 #include "RefWorkloadUtils.hpp"
 #include "Decoders.hpp"
 #include "Encoders.hpp"
@@ -37,7 +36,7 @@ void NormalizeWithinUingLbr(Decoder<float>&    inputData,
     const unsigned int rows = tensorShape[2];
     const unsigned int cols = tensorShape[3];
 
-    int radius = boost::numeric_cast<int>(norm_size / 2u); /* Strong Assumption on rounding Mode */
+    int radius = armnn::numeric_cast<int>(norm_size / 2u); /* Strong Assumption on rounding Mode */
 
     for (unsigned int n = 0; n < batchSize; n++)
     {
@@ -52,23 +51,23 @@ void NormalizeWithinUingLbr(Decoder<float>&    inputData,
                     {
                         for (int x = -radius; x <= radius; x++)
                         {
-                            int i = boost::numeric_cast<int>(w) + x;
-                            int j = boost::numeric_cast<int>(h) + y;
+                            int i = armnn::numeric_cast<int>(w) + x;
+                            int j = armnn::numeric_cast<int>(h) + y;
 
-                            if ((i < 0) || (i >= boost::numeric_cast<int>(cols)))
+                            if ((i < 0) || (i >= armnn::numeric_cast<int>(cols)))
                             {
                                 continue;
                             }
 
-                            if ((j < 0) || (j >= boost::numeric_cast<int>(rows)))
+                            if ((j < 0) || (j >= armnn::numeric_cast<int>(rows)))
                             {
                                 continue;
                             }
 
                             unsigned int inputIndex = n * cols * rows * depth +
                                                       c * cols * rows +
-                                                      boost::numeric_cast<unsigned int>(j) * cols +
-                                                      boost::numeric_cast<unsigned int>(i);
+                                                      armnn::numeric_cast<unsigned int>(j) * cols +
+                                                      armnn::numeric_cast<unsigned int>(i);
                             inputData[inputIndex];
                             float inval = inputData.Get();
 
@@ -106,7 +105,7 @@ void NormalizeAcrossUingLbr(Decoder<float>&    inputData,
     const unsigned int rows      = tensorShape[dataLayoutIndexed.GetHeightIndex()];
     const unsigned int cols      = tensorShape[dataLayoutIndexed.GetWidthIndex()];
 
-    int radius = boost::numeric_cast<int>(norm_size / 2u); /* Strong Assumption on rounding Mode */
+    int radius = armnn::numeric_cast<int>(norm_size / 2u); /* Strong Assumption on rounding Mode */
 
     for (unsigned int n = 0; n < batchSize; n++)
     {
@@ -119,16 +118,16 @@ void NormalizeAcrossUingLbr(Decoder<float>&    inputData,
                     float accumulated_scale = 0.0;
                     for (int z = -radius; z <= radius; z++)
                     {
-                        int k = boost::numeric_cast<int>(c) + z;
+                        int k = armnn::numeric_cast<int>(c) + z;
 
-                        if ((k < 0) || (k >= boost::numeric_cast<int>(depth)))
+                        if ((k < 0) || (k >= armnn::numeric_cast<int>(depth)))
                         {
                             continue;
                         }
 
                         unsigned inputIndex = dataLayoutIndexed.GetIndex(tensorShape,
                                                                          n,
-                                                                         boost::numeric_cast<unsigned int>(k),
+                                                                         armnn::numeric_cast<unsigned int>(k),
                                                                          h,
                                                                          w);
 
@@ -159,17 +158,28 @@ namespace armnn
 
 RefNormalizationWorkload::RefNormalizationWorkload(const NormalizationQueueDescriptor& descriptor,
                                                    const WorkloadInfo& info)
-    : BaseWorkload(descriptor, info)
+    : RefBaseWorkload(descriptor, info)
 {}
 
 void RefNormalizationWorkload::Execute() const
 {
-    ARMNN_SCOPED_PROFILING_EVENT(Compute::CpuRef, "RefNormalizationWorkload_Execute");
+    Execute(m_Data.m_Inputs, m_Data.m_Outputs);
+}
 
-    const TensorInfo& inputInfo = GetTensorInfo(m_Data.m_Inputs[0]);
+void RefNormalizationWorkload::ExecuteAsync(ExecutionData& executionData)
+{
+    WorkingMemDescriptor* workingMemDescriptor = static_cast<WorkingMemDescriptor*>(executionData.m_Data);
+    Execute(workingMemDescriptor->m_Inputs, workingMemDescriptor->m_Outputs);
+}
 
-    auto inputDecoder  = MakeDecoder<float>(inputInfo, m_Data.m_Inputs[0]->Map());
-    auto outputEncoder = MakeEncoder<float>(inputInfo, m_Data.m_Outputs[0]->Map());
+void RefNormalizationWorkload::Execute(std::vector<ITensorHandle*> inputs, std::vector<ITensorHandle*> outputs) const
+{
+    ARMNN_SCOPED_PROFILING_EVENT_REF_NAME_GUID("RefNormalizationWorkload_Execute");
+
+    const TensorInfo& inputInfo = GetTensorInfo(inputs[0]);
+
+    auto inputDecoder  = MakeDecoder<float>(inputInfo, inputs[0]->Map());
+    auto outputEncoder = MakeEncoder<float>(inputInfo, outputs[0]->Map());
 
     if (NormalizationAlgorithmMethod::LocalBrightness == m_Data.m_Parameters.m_NormMethodType)
     {
