@@ -8,13 +8,15 @@
 #include "Encoders.hpp"
 #include "Decoders.hpp"
 
-#include <backendsCommon/WorkloadData.hpp>
+#include <armnn/backends/WorkloadData.hpp>
 
 namespace armnn
 {
 
 void Stack (const StackQueueDescriptor&                   data,
             std::vector<std::unique_ptr<Decoder<float>>>& inputs,
-            Encoder<float>&                               output);
+            Encoder<float>&                               output,
+            const TensorInfo&                             inputInfo,
+            const TensorInfo&                             outputInfo);
 
 } // namespace armnn
