@@ -5,14 +5,14 @@
 
 #pragma once
 
-#include <armnn/profiling/ILocalPacketHandler.hpp>
+#include <client/include/ILocalPacketHandler.hpp>
 
 #include <common/include/Packet.hpp>
 
-namespace armnn
+namespace arm
 {
 
-namespace profiling
+namespace pipe
 {
 
 class PrintPacketHeaderHandler : public ILocalPacketHandler
@@ -22,6 +22,6 @@ class PrintPacketHeaderHandler : public ILocalPacketHandler
     virtual void HandlePacket(const arm::pipe::Packet& packet);
 };
 
-} // namespace profiling
+} // namespace pipe
 
-} // namespace armnn
+} // namespace arm
