@@ -3,24 +3,28 @@
 // SPDX-License-Identifier: MIT
 //
 
-#include "../ProfilingConnectionDumpToFileDecorator.hpp"
-#include <Filesystem.hpp>
+#include <client/src/ProfilingConnectionDumpToFileDecorator.hpp>
+
 #include <Runtime.hpp>
-#include <armnn/utility/IgnoreUnused.hpp>
+
+#include <armnnUtils/Filesystem.hpp>
+
+#include <common/include/IgnoreUnused.hpp>
+#include <common/include/NumericCast.hpp>
+
 
 #include <fstream>
 #include <sstream>
 
-#include <boost/numeric/conversion/cast.hpp>
-#include <boost/test/unit_test.hpp>
+#include <doctest/doctest.h>
 
-using namespace armnn::profiling;
+using namespace arm::pipe;
 
 namespace
 {
 
 const std::vector<char> g_Data       = { 'd', 'u', 'm', 'm', 'y' };
-const uint32_t          g_DataLength = boost::numeric_cast<uint32_t>(g_Data.size());
+const uint32_t          g_DataLength = arm::pipe::numeric_cast<uint32_t>(g_Data.size());
 const unsigned char*    g_DataPtr    = reinterpret_cast<const unsigned char*>(g_Data.data());
 
 class DummyProfilingConnection : public IProfilingConnection
@@ -32,7 +36,7 @@ public:
     {
         // populate packet data and construct packet
         std::memcpy(m_PacketData.get(), g_DataPtr, g_DataLength);
-        m_Packet = std::make_unique<arm::pipe::Packet>(0u, g_DataLength, m_PacketData);
+        m_Packet = std::make_unique<Packet>(0u, g_DataLength, m_PacketData);
     }
 
     ~DummyProfilingConnection() = default;
@@ -49,21 +53,21 @@ public:
 
     bool WritePacket(const unsigned char* buffer, uint32_t length) override
     {
-        armnn::IgnoreUnused(buffer);
-        armnn::IgnoreUnused(length);
+        arm::pipe::IgnoreUnused(buffer);
+        arm::pipe::IgnoreUnused(length);
         return true;
     }
 
-    arm::pipe::Packet ReadPacket(uint32_t timeout) override
+    Packet ReadPacket(uint32_t timeout) override
     {
-        armnn::IgnoreUnused(timeout);
+        arm::pipe::IgnoreUnused(timeout);
         return std::move(*m_Packet);
     }
 
 private:
     bool m_Open;
     std::unique_ptr<unsigned char[]> m_PacketData;
-    std::unique_ptr<arm::pipe::Packet> m_Packet;
+    std::unique_ptr<Packet> m_Packet;
 };
 
 std::vector<char> ReadDumpFile(const std::string& dumpFileName)
@@ -74,39 +78,39 @@ std::vector<char> ReadDumpFile(const std::string& dumpFileName)
 
 } // anonymous namespace
 
-BOOST_AUTO_TEST_SUITE(ProfilingConnectionDumpToFileDecoratorTests)
-
-BOOST_AUTO_TEST_CASE(DumpIncomingInvalidFile)
+TEST_SUITE("ProfilingConnectionDumpToFileDecoratorTests")
 {
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+TEST_CASE("DumpIncomingInvalidFile")
+{
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = "/";
     options.m_OutgoingCaptureFile =  "";
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, false);
-    BOOST_CHECK_THROW(decorator.ReadPacket(0), armnn::RuntimeException);
+    CHECK_THROWS_AS(decorator.ReadPacket(0), arm::pipe::ProfilingException);
 }
 
-BOOST_AUTO_TEST_CASE(DumpIncomingInvalidFileIgnoreErrors)
+TEST_CASE("DumpIncomingInvalidFileIgnoreErrors")
 {
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = "/";
     options.m_OutgoingCaptureFile =  "";
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, true);
-    BOOST_CHECK_NO_THROW(decorator.ReadPacket(0));
+    CHECK_NOTHROW(decorator.ReadPacket(0));
 }
 
-BOOST_AUTO_TEST_CASE(DumpIncomingValidFile)
+TEST_CASE("DumpIncomingValidFile")
 {
     fs::path fileName = armnnUtils::Filesystem::NamedTempFile("Armnn-DumpIncomingValidFileTest-TempFile");
 
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = fileName.string();
     options.m_OutgoingCaptureFile =  "";
 
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, false);
 
     // NOTE: unique_ptr is needed here because operator=() is deleted for Packet
-    std::unique_ptr<arm::pipe::Packet> packet;
-    BOOST_CHECK_NO_THROW(packet = std::make_unique<arm::pipe::Packet>(decorator.ReadPacket(0)));
+    std::unique_ptr<Packet> packet;
+    CHECK_NOTHROW(packet = std::make_unique<Packet>(decorator.ReadPacket(0)));
 
     decorator.Close();
 
@@ -116,45 +120,45 @@ BOOST_AUTO_TEST_CASE(DumpIncomingValidFile)
     // check if the data read back from the dump file matches the original
     constexpr unsigned int bytesToSkip = 2u * sizeof(uint32_t); // skip header and packet length
     int diff = std::strncmp(data.data() + bytesToSkip, packetData, g_DataLength);
-    BOOST_CHECK(diff == 0);
+    CHECK(diff == 0);
     fs::remove(fileName);
 }
 
-BOOST_AUTO_TEST_CASE(DumpOutgoingInvalidFile)
+TEST_CASE("DumpOutgoingInvalidFile")
 {
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = "";
     options.m_OutgoingCaptureFile = "/";
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, false);
-    BOOST_CHECK_THROW(decorator.WritePacket(g_DataPtr, g_DataLength), armnn::RuntimeException);
+    CHECK_THROWS_AS(decorator.WritePacket(g_DataPtr, g_DataLength), arm::pipe::ProfilingException);
 }
 
-BOOST_AUTO_TEST_CASE(DumpOutgoingInvalidFileIgnoreErrors)
+TEST_CASE("DumpOutgoingInvalidFileIgnoreErrors")
 {
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = "";
     options.m_OutgoingCaptureFile = "/";
 
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, true);
-    BOOST_CHECK_NO_THROW(decorator.WritePacket(g_DataPtr, g_DataLength));
+    CHECK_NOTHROW(decorator.WritePacket(g_DataPtr, g_DataLength));
 
     bool success = decorator.WritePacket(g_DataPtr, g_DataLength);
-    BOOST_CHECK(!success);
+    CHECK(!success);
 }
 
-BOOST_AUTO_TEST_CASE(DumpOutgoingValidFile)
+TEST_CASE("DumpOutgoingValidFile")
 {
     fs::path fileName = armnnUtils::Filesystem::NamedTempFile("Armnn-DumpOutgoingValidFileTest-TempFile");
 
-    armnn::Runtime::CreationOptions::ExternalProfilingOptions options;
+    ProfilingOptions options;
     options.m_IncomingCaptureFile = "";
     options.m_OutgoingCaptureFile = fileName.string();
 
     ProfilingConnectionDumpToFileDecorator decorator(std::make_unique<DummyProfilingConnection>(), options, false);
 
     bool success = false;
-    BOOST_CHECK_NO_THROW(success = decorator.WritePacket(g_DataPtr, g_DataLength));
-    BOOST_CHECK(success);
+    CHECK_NOTHROW(success = decorator.WritePacket(g_DataPtr, g_DataLength));
+    CHECK(success);
 
     decorator.Close();
 
@@ -162,8 +166,8 @@ BOOST_AUTO_TEST_CASE(DumpOutgoingValidFile)
 
     // check if the data read back from the dump file matches the original
     int diff = std::strncmp(data.data(), g_Data.data(), g_DataLength);
-    BOOST_CHECK(diff == 0);
+    CHECK(diff == 0);
     fs::remove(fileName);
 }
 
-BOOST_AUTO_TEST_SUITE_END()
+}
