@@ -5,32 +5,35 @@
 
 #pragma once
 
-#include <Holder.hpp>
-#include <IProfilingConnectionFactory.hpp>
-#include <IProfilingServiceStatus.hpp>
-#include <ProfilingService.hpp>
-#include <ProfilingGuidGenerator.hpp>
-#include <ProfilingUtils.hpp>
-#include <SendCounterPacket.hpp>
-#include <SendThread.hpp>
+#include <client/src/IProfilingConnectionFactory.hpp>
+#include <client/src/ProfilingService.hpp>
+#include <client/src/ProfilingUtils.hpp>
+#include <client/src/SendCounterPacket.hpp>
+#include <client/src/SendThread.hpp>
 
-#include <armnn/Exceptions.hpp>
-#include <armnn/Optional.hpp>
-#include <armnn/Conversion.hpp>
-#include <armnn/utility/Assert.hpp>
-#include <armnn/utility/IgnoreUnused.hpp>
+#include <armnn/BackendId.hpp>
+#include <armnn/profiling/ArmNNProfiling.hpp>
 
-#include <boost/numeric/conversion/cast.hpp>
+#include <client/include/Holder.hpp>
+#include <client/include/IProfilingServiceStatus.hpp>
+
+#include <common/include/Assert.hpp>
+#include <common/include/CommonProfilingUtils.hpp>
+#include <common/include/IgnoreUnused.hpp>
+#include <common/include/NumericCast.hpp>
+#include <common/include/Optional.hpp>
+#include <common/include/ProfilingException.hpp>
+#include <common/include/ProfilingGuidGenerator.hpp>
 
 #include <atomic>
 #include <condition_variable>
 #include <mutex>
 #include <thread>
 
-namespace armnn
+namespace arm
 {
 
-namespace profiling
+namespace pipe
 {
 
 class MockProfilingConnection : public IProfilingConnection
@@ -131,7 +134,7 @@ public:
 
     arm::pipe::Packet ReadPacket(uint32_t timeout) override
     {
-        IgnoreUnused(timeout);
+        arm::pipe::IgnoreUnused(timeout);
 
         // Simulate a delay in the reading process. The default timeout is way too long.
         std::this_thread::sleep_for(std::chrono::milliseconds(5));
@@ -163,9 +166,9 @@ private:
 class MockProfilingConnectionFactory : public IProfilingConnectionFactory
 {
 public:
-    IProfilingConnectionPtr GetProfilingConnection(const ExternalProfilingOptions& options) const override
+    IProfilingConnectionPtr GetProfilingConnection(const ProfilingOptions& options) const override
     {
-        IgnoreUnused(options);
+        arm::pipe::IgnoreUnused(options);
         return std::make_unique<MockProfilingConnection>();
     }
 };
@@ -294,8 +297,8 @@ public:
         reservedSize = 0;
         if (requestedSize > m_MaxBufferSize)
         {
-            throw armnn::InvalidArgumentException("The maximum buffer size that can be requested is [" +
-                                                  std::to_string(m_MaxBufferSize) + "] bytes");
+            throw arm::pipe::InvalidArgumentException("The maximum buffer size that can be requested is [" +
+                                                      std::to_string(m_MaxBufferSize) + "] bytes");
         }
         reservedSize = requestedSize;
         return std::make_unique<MockPacketBuffer>(requestedSize);
@@ -404,7 +407,7 @@ public:
 
     void SendCounterDirectoryPacket(const ICounterDirectory& counterDirectory) override
     {
-        IgnoreUnused(counterDirectory);
+        arm::pipe::IgnoreUnused(counterDirectory);
 
         std::string message("SendCounterDirectoryPacket");
         unsigned int reserved = 0;
@@ -416,7 +419,7 @@ public:
     void SendPeriodicCounterCapturePacket(uint64_t timestamp,
                                           const std::vector<CounterValue>& values) override
     {
-        IgnoreUnused(timestamp, values);
+        arm::pipe::IgnoreUnused(timestamp, values);
 
         std::string message("SendPeriodicCounterCapturePacket");
         unsigned int reserved = 0;
@@ -428,7 +431,7 @@ public:
     void SendPeriodicCounterSelectionPacket(uint32_t capturePeriod,
                                             const std::vector<uint16_t>& selectedCounterIds) override
     {
-        IgnoreUnused(capturePeriod, selectedCounterIds);
+        arm::pipe::IgnoreUnused(capturePeriod, selectedCounterIds);
 
         std::string message("SendPeriodicCounterSelectionPacket");
         unsigned int reserved = 0;
@@ -452,11 +455,11 @@ public:
     {
         // Create the category
         CategoryPtr category = std::make_unique<Category>(categoryName);
-        ARMNN_ASSERT(category);
+        ARM_PIPE_ASSERT(category);
 
         // Get the raw category pointer
         const Category* categoryPtr = category.get();
-        ARMNN_ASSERT(categoryPtr);
+        ARM_PIPE_ASSERT(categoryPtr);
 
         // Register the category
         m_Categories.insert(std::move(category));
@@ -472,11 +475,11 @@ public:
 
         // Create the device
         DevicePtr device = std::make_unique<Device>(deviceUid, deviceName, cores);
-        ARMNN_ASSERT(device);
+        ARM_PIPE_ASSERT(device);
 
         // Get the raw device pointer
         const Device* devicePtr = device.get();
-        ARMNN_ASSERT(devicePtr);
+        ARM_PIPE_ASSERT(devicePtr);
 
         // Register the device
         m_Devices.insert(std::make_pair(deviceUid, std::move(device)));
@@ -493,11 +496,11 @@ public:
 
         // Create the counter set
         CounterSetPtr counterSet = std::make_unique<CounterSet>(counterSetUid, counterSetName, count);
-        ARMNN_ASSERT(counterSet);
+        ARM_PIPE_ASSERT(counterSet);
 
         // Get the raw counter set pointer
         const CounterSet* counterSetPtr = counterSet.get();
-        ARMNN_ASSERT(counterSetPtr);
+        ARM_PIPE_ASSERT(counterSetPtr);
 
         // Register the counter set
         m_CounterSets.insert(std::make_pair(counterSetUid, std::move(counterSet)));
@@ -505,7 +508,7 @@ public:
         return counterSetPtr;
     }
 
-    const Counter* RegisterCounter(const BackendId& backendId,
+    const Counter* RegisterCounter(const std::string& backendId,
                                    const uint16_t uid,
                                    const std::string& parentCategoryName,
                                    uint16_t counterClass,
@@ -513,12 +516,12 @@ public:
                                    double multiplier,
                                    const std::string& name,
                                    const std::string& description,
-                                   const armnn::Optional<std::string>& units = armnn::EmptyOptional(),
-                                   const armnn::Optional<uint16_t>& numberOfCores = armnn::EmptyOptional(),
-                                   const armnn::Optional<uint16_t>& deviceUid = armnn::EmptyOptional(),
-                                   const armnn::Optional<uint16_t>& counterSetUid = armnn::EmptyOptional())
+                                   const arm::pipe::Optional<std::string>& units = arm::pipe::EmptyOptional(),
+                                   const arm::pipe::Optional<uint16_t>& numberOfCores = arm::pipe::EmptyOptional(),
+                                   const arm::pipe::Optional<uint16_t>& deviceUid = arm::pipe::EmptyOptional(),
+                                   const arm::pipe::Optional<uint16_t>& counterSetUid = arm::pipe::EmptyOptional())
     {
-        IgnoreUnused(backendId);
+        arm::pipe::IgnoreUnused(backendId);
 
         // Get the number of cores from the argument only
         uint16_t deviceCores = numberOfCores.has_value() ? numberOfCores.value() : 0;
@@ -531,7 +534,7 @@ public:
 
         // Get the counter UIDs and calculate the max counter UID
         std::vector<uint16_t> counterUids = GetNextCounterUids(uid, deviceCores);
-        ARMNN_ASSERT(!counterUids.empty());
+        ARM_PIPE_ASSERT(!counterUids.empty());
         uint16_t maxCounterUid = deviceCores <= 1 ? counterUids.front() : counterUids.back();
 
         // Get the counter units
@@ -549,18 +552,18 @@ public:
                                                        unitsValue,
                                                        deviceUidValue,
                                                        counterSetUidValue);
-        ARMNN_ASSERT(counter);
+        ARM_PIPE_ASSERT(counter);
 
         // Get the raw counter pointer
         const Counter* counterPtr = counter.get();
-        ARMNN_ASSERT(counterPtr);
+        ARM_PIPE_ASSERT(counterPtr);
 
         // Process multiple counters if necessary
         for (uint16_t counterUid : counterUids)
         {
             // Connect the counter to the parent category
             Category* parentCategory = const_cast<Category*>(GetCategory(parentCategoryName));
-            ARMNN_ASSERT(parentCategory);
+            ARM_PIPE_ASSERT(parentCategory);
             parentCategory->m_Counters.push_back(counterUid);
 
             // Register the counter
@@ -571,10 +574,10 @@ public:
     }
 
     // Getters for counts
-    uint16_t GetCategoryCount()   const override { return boost::numeric_cast<uint16_t>(m_Categories.size());  }
-    uint16_t GetDeviceCount()     const override { return boost::numeric_cast<uint16_t>(m_Devices.size());     }
-    uint16_t GetCounterSetCount() const override { return boost::numeric_cast<uint16_t>(m_CounterSets.size()); }
-    uint16_t GetCounterCount()    const override { return boost::numeric_cast<uint16_t>(m_Counters.size());    }
+    uint16_t GetCategoryCount()   const override { return arm::pipe::numeric_cast<uint16_t>(m_Categories.size());  }
+    uint16_t GetDeviceCount()     const override { return arm::pipe::numeric_cast<uint16_t>(m_Devices.size());     }
+    uint16_t GetCounterSetCount() const override { return arm::pipe::numeric_cast<uint16_t>(m_CounterSets.size()); }
+    uint16_t GetCounterCount()    const override { return arm::pipe::numeric_cast<uint16_t>(m_Counters.size());    }
 
     // Getters for collections
     const Categories&  GetCategories()  const override { return m_Categories;  }
@@ -587,7 +590,7 @@ public:
     {
         auto it = std::find_if(m_Categories.begin(), m_Categories.end(), [&name](const CategoryPtr& category)
         {
-            ARMNN_ASSERT(category);
+            ARM_PIPE_ASSERT(category);
 
             return category->m_Name == name;
         });
@@ -602,19 +605,19 @@ public:
 
     const Device* GetDevice(uint16_t uid) const override
     {
-        IgnoreUnused(uid);
+        arm::pipe::IgnoreUnused(uid);
         return nullptr; // Not used by the unit tests
     }
 
     const CounterSet* GetCounterSet(uint16_t uid) const override
     {
-        IgnoreUnused(uid);
+        arm::pipe::IgnoreUnused(uid);
         return nullptr; // Not used by the unit tests
     }
 
     const Counter* GetCounter(uint16_t uid) const override
     {
-        IgnoreUnused(uid);
+        arm::pipe::IgnoreUnused(uid);
         return nullptr; // Not used by the unit tests
     }
 
@@ -628,10 +631,20 @@ private:
 class MockProfilingService : public ProfilingService
 {
 public:
-    MockProfilingService(MockBufferManager& mockBufferManager,
+    MockProfilingService(uint16_t maxGlobalCounterId,
+                         IInitialiseProfilingService& initialiser,
+                         MockBufferManager& mockBufferManager,
                          bool isProfilingEnabled,
                          const CaptureData& captureData) :
-        m_SendCounterPacket(mockBufferManager),
+        ProfilingService(maxGlobalCounterId,
+                         initialiser,
+                         arm::pipe::ARMNN_SOFTWARE_INFO,
+                         arm::pipe::ARMNN_SOFTWARE_VERSION,
+                         arm::pipe::ARMNN_HARDWARE_VERSION),
+        m_SendCounterPacket(mockBufferManager,
+                            arm::pipe::ARMNN_SOFTWARE_INFO,
+                            arm::pipe::ARMNN_SOFTWARE_VERSION,
+                            arm::pipe::ARMNN_HARDWARE_VERSION),
         m_IsProfilingEnabled(isProfilingEnabled),
         m_CaptureData(captureData)
     {}
@@ -676,7 +689,7 @@ public:
 
     void RegisterMapping(uint16_t globalCounterId,
                          uint16_t backendCounterId,
-                         const armnn::BackendId& backendId)
+                         const std::string& backendId)
     {
         m_CounterMapping.RegisterMapping(globalCounterId, backendCounterId, backendId);
     }
@@ -698,9 +711,9 @@ class MockProfilingServiceStatus : public IProfilingServiceStatus
 {
 public:
     void NotifyProfilingServiceActive() override {}
-    void WaitForProfilingServiceActivation(unsigned int timeout) override { IgnoreUnused(timeout); }
+    void WaitForProfilingServiceActivation(unsigned int timeout) override { arm::pipe::IgnoreUnused(timeout); }
 };
 
-} // namespace profiling
+} // namespace pipe
 
-} // namespace armnn
+} // namespace arm
