@@ -7,66 +7,27 @@
 
 #include "ProfilingMocks.hpp"
 
-#include <armnn/Logging.hpp>
 #include <armnn/utility/PolymorphicDowncast.hpp>
 
-#include <IProfilingConnection.hpp>
-#include <ProfilingService.hpp>
+#include <client/src/IProfilingConnection.hpp>
+#include <client/src/ProfilingService.hpp>
+
+#include <armnn/profiling/ArmNNProfiling.hpp>
 
 #include <common/include/CommandHandlerFunctor.hpp>
+#include <common/include/Logging.hpp>
 
-
-#include <boost/test/unit_test.hpp>
+#include <doctest/doctest.h>
 
 #include <chrono>
 #include <thread>
 
-namespace armnn
+namespace arm
 {
 
-namespace profiling
+namespace pipe
 {
 
-struct LogLevelSwapper
-{
-public:
-    LogLevelSwapper(armnn::LogSeverity severity)
-    {
-        // Set the new log level
-        armnn::ConfigureLogging(true, true, severity);
-    }
-    ~LogLevelSwapper()
-    {
-        // The default log level for unit tests is "Fatal"
-        armnn::ConfigureLogging(true, true, armnn::LogSeverity::Fatal);
-    }
-};
-
-struct StreamRedirector
-{
-public:
-    StreamRedirector(std::ostream& stream, std::streambuf* newStreamBuffer)
-        : m_Stream(stream)
-        , m_BackupBuffer(m_Stream.rdbuf(newStreamBuffer))
-    {}
-
-    ~StreamRedirector() { CancelRedirect(); }
-
-    void CancelRedirect()
-    {
-        // Only cancel the redirect once.
-        if (m_BackupBuffer != nullptr )
-        {
-            m_Stream.rdbuf(m_BackupBuffer);
-            m_BackupBuffer = nullptr;
-        }
-    }
-
-private:
-    std::ostream& m_Stream;
-    std::streambuf* m_BackupBuffer;
-};
-
 class TestProfilingConnectionBase : public IProfilingConnection
 {
 public:
@@ -79,7 +40,7 @@ public:
 
     bool WritePacket(const unsigned char* buffer, uint32_t length) override
     {
-        IgnoreUnused(buffer, length);
+        arm::pipe::IgnoreUnused(buffer, length);
 
         return false;
     }
@@ -96,7 +57,7 @@ public:
         else
         {
             std::this_thread::sleep_for(std::chrono::milliseconds(timeout));
-            throw armnn::TimeoutException("Simulate a timeout error\n");
+            throw arm::pipe::TimeoutException("Simulate a timeout error\n");
         }
     }
 
@@ -117,7 +78,7 @@ public:
         {
             std::this_thread::sleep_for(std::chrono::milliseconds(timeout));
             ++m_ReadRequests;
-            throw armnn::TimeoutException("Simulate a timeout error\n");
+            throw arm::pipe::TimeoutException("Simulate a timeout error\n");
         }
 
         return arm::pipe::Packet(65536);
@@ -141,9 +102,9 @@ public:
 
     arm::pipe::Packet ReadPacket(uint32_t timeout) override
     {
-        IgnoreUnused(timeout);
+        arm::pipe::IgnoreUnused(timeout);
         ++m_ReadRequests;
-        throw armnn::Exception("Simulate a non-timeout error");
+        throw arm::pipe::ProfilingException("Simulate a non-timeout error");
     }
 
     int ReadCalledCount()
@@ -160,7 +121,7 @@ class TestProfilingConnectionBadAckPacket : public TestProfilingConnectionBase
 public:
     arm::pipe::Packet ReadPacket(uint32_t timeout) override
     {
-        IgnoreUnused(timeout);
+        arm::pipe::IgnoreUnused(timeout);
         // Connection Acknowledged Packet header (word 0, word 1 is always zero):
         // 26:31 [6]  packet_family: Control Packet Family, value 0b000000
         // 16:25 [10] packet_id: Packet identifier, value 0b0000000001
@@ -183,7 +144,7 @@ public:
 
     void operator()(const arm::pipe::Packet& packet) override
     {
-        IgnoreUnused(packet);
+        arm::pipe::IgnoreUnused(packet);
         m_Count++;
     }
 
@@ -206,22 +167,28 @@ class SwapProfilingConnectionFactoryHelper : public ProfilingService
 public:
     using MockProfilingConnectionFactoryPtr = std::unique_ptr<MockProfilingConnectionFactory>;
 
-    SwapProfilingConnectionFactoryHelper(armnn::profiling::ProfilingService& profilingService)
-        : ProfilingService()
+    SwapProfilingConnectionFactoryHelper(uint16_t maxGlobalCounterId,
+                                         IInitialiseProfilingService& initialiser,
+                                         ProfilingService& profilingService)
+        : ProfilingService(maxGlobalCounterId,
+                           initialiser,
+                           arm::pipe::ARMNN_SOFTWARE_INFO,
+                           arm::pipe::ARMNN_SOFTWARE_VERSION,
+                           arm::pipe::ARMNN_HARDWARE_VERSION)
         , m_ProfilingService(profilingService)
         , m_MockProfilingConnectionFactory(new MockProfilingConnectionFactory())
         , m_BackupProfilingConnectionFactory(nullptr)
 
     {
-        BOOST_CHECK(m_MockProfilingConnectionFactory);
+        CHECK(m_MockProfilingConnectionFactory);
         SwapProfilingConnectionFactory(m_ProfilingService,
                                        m_MockProfilingConnectionFactory.get(),
                                        m_BackupProfilingConnectionFactory);
-        BOOST_CHECK(m_BackupProfilingConnectionFactory);
+        CHECK(m_BackupProfilingConnectionFactory);
     }
     ~SwapProfilingConnectionFactoryHelper()
     {
-        BOOST_CHECK(m_BackupProfilingConnectionFactory);
+        CHECK(m_BackupProfilingConnectionFactory);
         IProfilingConnectionFactory* temp = nullptr;
         SwapProfilingConnectionFactory(m_ProfilingService,
                                        m_BackupProfilingConnectionFactory,
@@ -231,7 +198,7 @@ public:
     MockProfilingConnection* GetMockProfilingConnection()
     {
         IProfilingConnection* profilingConnection = GetProfilingConnection(m_ProfilingService);
-        return PolymorphicDowncast<MockProfilingConnection*>(profilingConnection);
+        return armnn::PolymorphicDowncast<MockProfilingConnection*>(profilingConnection);
     }
 
     void ForceTransitionToState(ProfilingState newState)
@@ -272,11 +239,11 @@ public:
     }
 
 private:
-    armnn::profiling::ProfilingService& m_ProfilingService;
+    ProfilingService& m_ProfilingService;
     MockProfilingConnectionFactoryPtr m_MockProfilingConnectionFactory;
     IProfilingConnectionFactory* m_BackupProfilingConnectionFactory;
 };
 
-} // namespace profiling
+} // namespace pipe
 
-} // namespace armnn
+} // namespace arm
