@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017, 2023 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
@@ -11,7 +11,10 @@
 #include <armnn/TypesUtils.hpp>
 #include <armnn/utility/IgnoreUnused.hpp>
 
-#include <boost/program_options.hpp>
+#include <armnnUtils/TContainer.hpp>
+
+#include <cxxopts/cxxopts.hpp>
+#include <fmt/format.h>
 
 
 namespace armnn
@@ -25,7 +28,7 @@ inline std::istream& operator>>(std::istream& in, armnn::Compute& compute)
     if (compute == armnn::Compute::Undefined)
     {
         in.setstate(std::ios_base::failbit);
-        throw boost::program_options::validation_error(boost::program_options::validation_error::invalid_option_value);
+        throw cxxopts::exceptions::exception(fmt::format("Unrecognised compute device: {}", token));
     }
     return in;
 }
@@ -38,7 +41,7 @@ inline std::istream& operator>>(std::istream& in, armnn::BackendId& backend)
     if (compute == armnn::Compute::Undefined)
     {
         in.setstate(std::ios_base::failbit);
-        throw boost::program_options::validation_error(boost::program_options::validation_error::invalid_option_value);
+        throw cxxopts::exceptions::exception(fmt::format("Unrecognised compute device: {}", token));
     }
     backend = compute;
     return in;
@@ -92,9 +95,9 @@ class IInferenceTestCaseProvider
 public:
     virtual ~IInferenceTestCaseProvider() {}
 
-    virtual void AddCommandLineOptions(boost::program_options::options_description& options)
+    virtual void AddCommandLineOptions(cxxopts::Options& options, std::vector<std::string>& required)
     {
-        IgnoreUnused(options);
+        IgnoreUnused(options, required);
     };
     virtual bool ProcessCommandLineOptions(const InferenceTestOptions &commonOptions)
     {
@@ -109,11 +112,10 @@ template <typename TModel>
 class InferenceModelTestCase : public IInferenceTestCase
 {
 public:
-    using TContainer = boost::variant<std::vector<float>, std::vector<int>, std::vector<unsigned char>>;
 
     InferenceModelTestCase(TModel& model,
                            unsigned int testCaseId,
-                           const std::vector<TContainer>& inputs,
+                           const std::vector<armnnUtils::TContainer>& inputs,
                            const std::vector<unsigned int>& outputSizes)
         : m_Model(model)
         , m_TestCaseId(testCaseId)
@@ -136,13 +138,13 @@ public:
 
 protected:
     unsigned int GetTestCaseId() const { return m_TestCaseId; }
-    const std::vector<TContainer>& GetOutputs() const { return m_Outputs; }
+    const std::vector<armnnUtils::TContainer>& GetOutputs() const { return m_Outputs; }
 
 private:
-    TModel&                 m_Model;
-    unsigned int            m_TestCaseId;
-    std::vector<TContainer> m_Inputs;
-    std::vector<TContainer> m_Outputs;
+    TModel&                         m_Model;
+    unsigned int                    m_TestCaseId;
+    std::vector<armnnUtils::TContainer>  m_Inputs;
+    std::vector<armnnUtils::TContainer>  m_Outputs;
 };
 
 template <typename TTestCaseDatabase, typename TModel>
@@ -180,7 +182,7 @@ public:
     template <typename TConstructDatabaseCallable, typename TConstructModelCallable>
     ClassifierTestCaseProvider(TConstructDatabaseCallable constructDatabase, TConstructModelCallable constructModel);
 
-    virtual void AddCommandLineOptions(boost::program_options::options_description& options) override;
+    virtual void AddCommandLineOptions(cxxopts::Options& options, std::vector<std::string>& required) override;
     virtual bool ProcessCommandLineOptions(const InferenceTestOptions &commonOptions) override;
     virtual std::unique_ptr<IInferenceTestCase> GetTestCase(unsigned int testCaseId) override;
     virtual bool OnInferenceTestFinished() override;
