@@ -9,14 +9,12 @@
 
 #include <armnn/utility/Assert.hpp>
 #include <armnn/utility/IgnoreUnused.hpp>
+#include <armnnUtils/FloatingPointComparison.hpp>
 
 #include <algorithm>
 #include <array>
 #include <utility>
 
-#include <boost/multi_array.hpp>
-#include <boost/test/tools/floating_point_comparison.hpp>
-
 constexpr size_t YoloOutputSize = 1470;
 
 template <typename Model>
@@ -27,7 +25,6 @@ public:
         unsigned int testCaseId,
         YoloTestCaseData& testCaseData)
      : InferenceModelTestCase<Model>(model, testCaseId, { std::move(testCaseData.m_InputImage) }, { YoloOutputSize })
-     , m_FloatComparer(boost::math::fpc::percent_tolerance(1.0f))
      , m_TopObjectDetections(std::move(testCaseData.m_TopObjectDetections))
     {
     }
@@ -36,24 +33,23 @@ public:
     {
         armnn::IgnoreUnused(options);
 
-        using Boost3dArray = boost::multi_array<float, 3>;
-
-        const std::vector<float>& output = boost::get<std::vector<float>>(this->GetOutputs()[0]);
+        const std::vector<float>& output = mapbox::util::get<std::vector<float>>(this->GetOutputs()[0]);
         ARMNN_ASSERT(output.size() == YoloOutputSize);
 
-        constexpr Boost3dArray::index gridSize = 7;
-        constexpr Boost3dArray::index numClasses = 20;
-        constexpr Boost3dArray::index numScales = 2;
+        constexpr unsigned int gridSize = 7;
+        constexpr unsigned int numClasses = 20;
+        constexpr unsigned int numScales = 2;
 
         const float* outputPtr =  output.data();
 
         // Range 0-980. Class probabilities. 7x7x20
-        Boost3dArray classProbabilities(boost::extents[gridSize][gridSize][numClasses]);
-        for (Boost3dArray::index y = 0; y < gridSize; ++y)
+        vector<vector<vector<float>>> classProbabilities(gridSize, vector<vector<float>>(gridSize,
+                                                         vector<float>(numClasses)));
+        for (unsigned int y = 0; y < gridSize; ++y)
         {
-            for (Boost3dArray::index x = 0; x < gridSize; ++x)
+            for (unsigned int x = 0; x < gridSize; ++x)
             {
-                for (Boost3dArray::index c = 0; c < numClasses; ++c)
+                for (unsigned int c = 0; c < numClasses; ++c)
                 {
                     classProbabilities[y][x][c] = *outputPtr++;
                 }
@@ -61,12 +57,12 @@ public:
         }
 
         // Range 980-1078. Scales. 7x7x2
-        Boost3dArray scales(boost::extents[gridSize][gridSize][numScales]);
-        for (Boost3dArray::index y = 0; y < gridSize; ++y)
+        vector<vector<vector<float>>> scales(gridSize, vector<vector<float>>(gridSize, vector<float>(numScales)));
+        for (unsigned int y = 0; y < gridSize; ++y)
         {
-            for (Boost3dArray::index x = 0; x < gridSize; ++x)
+            for (unsigned int x = 0; x < gridSize; ++x)
             {
-                for (Boost3dArray::index s = 0; s < numScales; ++s)
+                for (unsigned int s = 0; s < numScales; ++s)
                 {
                     scales[y][x][s] = *outputPtr++;
                 }
@@ -77,12 +73,13 @@ public:
         constexpr float imageWidthAsFloat = static_cast<float>(YoloImageWidth);
         constexpr float imageHeightAsFloat = static_cast<float>(YoloImageHeight);
 
-        boost::multi_array<float, 4> boxes(boost::extents[gridSize][gridSize][numScales][4]);
-        for (Boost3dArray::index y = 0; y < gridSize; ++y)
+        vector<vector<vector<vector<float>>>> boxes(gridSize, vector<vector<vector<float>>>
+            (gridSize, vector<vector<float>>(numScales, vector<float>(4))));
+        for (unsigned int y = 0; y < gridSize; ++y)
         {
-            for (Boost3dArray::index x = 0; x < gridSize; ++x)
+            for (unsigned int x = 0; x < gridSize; ++x)
             {
-                for (Boost3dArray::index s = 0; s < numScales; ++s)
+                for (unsigned int s = 0; s < numScales; ++s)
                 {
                     float bx = *outputPtr++;
                     float by = *outputPtr++;
@@ -101,13 +98,13 @@ public:
         std::vector<YoloDetectedObject> detectedObjects;
         detectedObjects.reserve(gridSize * gridSize * numScales * numClasses);
 
-        for (Boost3dArray::index y = 0; y < gridSize; ++y)
+        for (unsigned int y = 0; y < gridSize; ++y)
         {
-            for (Boost3dArray::index x = 0; x < gridSize; ++x)
+            for (unsigned int x = 0; x < gridSize; ++x)
             {
-                for (Boost3dArray::index s = 0; s < numScales; ++s)
+                for (unsigned int s = 0; s < numScales; ++s)
                 {
-                    for (Boost3dArray::index c = 0; c < numClasses; ++c)
+                    for (unsigned int c = 0; c < numClasses; ++c)
                     {
                         // Resolved confidence: class probabilities * scales.
                         const float confidence = classProbabilities[y][x][c] * scales[y][x][s];
@@ -155,11 +152,11 @@ public:
                 return TestCaseResult::Failed;
             }
 
-            if (!m_FloatComparer(detectedObject.m_Box.m_X, expectedDetection.m_Box.m_X) ||
-                !m_FloatComparer(detectedObject.m_Box.m_Y, expectedDetection.m_Box.m_Y) ||
-                !m_FloatComparer(detectedObject.m_Box.m_W, expectedDetection.m_Box.m_W) ||
-                !m_FloatComparer(detectedObject.m_Box.m_H, expectedDetection.m_Box.m_H) ||
-                !m_FloatComparer(detectedObject.m_Confidence, expectedDetection.m_Confidence))
+            if (!armnnUtils::within_percentage_tolerance(detectedObject.m_Box.m_X, expectedDetection.m_Box.m_X) ||
+                !armnnUtils::within_percentage_tolerance(detectedObject.m_Box.m_Y, expectedDetection.m_Box.m_Y) ||
+                !armnnUtils::within_percentage_tolerance(detectedObject.m_Box.m_W, expectedDetection.m_Box.m_W) ||
+                !armnnUtils::within_percentage_tolerance(detectedObject.m_Box.m_H, expectedDetection.m_Box.m_H) ||
+                !armnnUtils::within_percentage_tolerance(detectedObject.m_Confidence, expectedDetection.m_Confidence))
             {
                 ARMNN_LOG(error) << "Detected bounding box for test case " << this->GetTestCaseId() <<
                     " is incorrect";
@@ -173,7 +170,6 @@ public:
     }
 
 private:
-    boost::math::fpc::close_at_tolerance<float> m_FloatComparer;
     std::vector<YoloDetectedObject> m_TopObjectDetections;
 };
 
@@ -187,18 +183,17 @@ public:
     {
     }
 
-    virtual void AddCommandLineOptions(boost::program_options::options_description& options) override
+    virtual void AddCommandLineOptions(cxxopts::Options& options, std::vector<std::string>& required) override
     {
-        namespace po = boost::program_options;
+        options
+            .allow_unrecognised_options()
+            .add_options()
+                ("d,data-dir", "Path to directory containing test data", cxxopts::value<std::string>(m_DataDir));
 
-        options.add_options()
-            ("data-dir,d", po::value<std::string>(&m_DataDir)->required(),
-                "Path to directory containing test data");
-
-        Model::AddCommandLineOptions(options, m_ModelCommandLineOptions);
+        Model::AddCommandLineOptions(options, m_ModelCommandLineOptions, required);
     }
 
-    virtual bool ProcessCommandLineOptions(const InferenceTestOptions &commonOptions) override
+    virtual bool ProcessCommandLineOptions(const InferenceTestOptions& commonOptions) override
     {
         if (!ValidateDirectory(m_DataDir))
         {
