@@ -1,10 +1,11 @@
 //
-// Copyright © 2019 Arm Ltd. All rights reserved.
+// Copyright © 2019 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
+#pragma once
 
-#include "../../armnn/src/profiling/CommandHandlerFunctor.hpp"
-#include "../../armnn/src/profiling/Packet.hpp"
+#include <common/include/CommandHandlerFunctor.hpp>
+#include <common/include/Packet.hpp>
 
 #include <vector>
 
@@ -14,9 +15,7 @@ namespace armnn
 namespace gatordmock
 {
 
-#pragma once
-
-class PeriodicCounterSelectionResponseHandler : public profiling::CommandHandlerFunctor
+class PeriodicCounterSelectionResponseHandler : public arm::pipe::CommandHandlerFunctor
 {
 
 public:
@@ -34,7 +33,7 @@ public:
         , m_QuietOperation(quietOperation)
     {}
 
-    void operator()(const armnn::profiling::Packet& packet) override;
+    void operator()(const arm::pipe::Packet& packet) override;
 
 private:
     bool m_QuietOperation;
