@@ -2,6 +2,7 @@
 //
 // Copyright (c) 2012 - present, Victor Zverovich
 // All rights reserved.
+// SPDX-License-Identifier: MIT
 //
 // For the license information refer to format.h.
 
@@ -668,7 +669,7 @@ template <typename T> class buffer {
         size_(sz),
         capacity_(cap) {}
 
-  ~buffer() = default;
+  virtual ~buffer() = default;
 
   /** Sets the buffer data and capacity. */
   void set(T* buf_data, size_t buf_capacity) FMT_NOEXCEPT {
